<?php
require_once 'config.php';
yetkili_mi();

// İşlem (Borç) ID'sini al ve doğrula
if (!isset($_GET['id']) || !($borc_id = filter_input(INPUT_GET, 'id', FILTER_VALIDATE_INT))) {
    $_SESSION['hata'] = "Geçersiz İşlem ID.";
    header("Location: index.php"); // Ana sayfaya yönlendir
    exit();
}

$sayfa_baslik = "İşlem Detayı";
$borc = null; // İşlem verisini tutacak değişken
$ilgili_hareketler = []; // İlgili ödeme/tahsilatları tutacak dizi

// İşlem bilgilerini ve ilişkili verileri çek
try {
    // Ana İşlem Bilgisi
    $stmt_borc = $db->prepare("
        SELECT b.*, c.ad_soyad as cari_ad_soyad, k.kategori_adi
        FROM borclar b
        JOIN cariler c ON b.cari_id = c.id
        LEFT JOIN kategoriler k ON b.kategori_id = k.id
        WHERE b.id = ?
    ");
    $stmt_borc->execute([$borc_id]);
    $borc = $stmt_borc->fetch(PDO::FETCH_ASSOC);

    if (!$borc) {
        $_SESSION['hata'] = "Detayı görüntülenecek işlem bulunamadı.";
        header("Location: index.php"); // Ana sayfaya yönlendir
        exit();
    }

    $sayfa_baslik .= " (#{$borc['id']} - " . ($borc['tur'] == 'satis' ? 'Satış' : 'Alış') . ")";

    // Bu İşleme Ait Ödeme/Tahsilat Hareketleri
    $stmt_hareketler = $db->prepare("
        SELECT hh.*, h.hesap_adi
        FROM hesap_hareketleri hh
        JOIN hesaplar h ON hh.hesap_id = h.id
        WHERE hh.borc_id = ?
        ORDER BY hh.tarih ASC -- Eskiden yeniye sırala
    ");
    $stmt_hareketler->execute([$borc_id]);
    $ilgili_hareketler = $stmt_hareketler->fetchAll(PDO::FETCH_ASSOC);

    // Kalan tutarı hesapla
    $kalan_tutar = $borc['tutar'] - $borc['odenen_tutar'];


} catch (PDOException $e) {
    error_log("Borç Detay (ID: {$borc_id}) Hatası: " . $e->getMessage());
    $_SESSION['hata'] = "İşlem detayları alınırken bir hata oluştu.";
     // Hata durumunda $borc null olabilir, HTML'de kontrol edilecek.
     $borc = null;
}

$csrf_token = csrf_token_olustur(); // Silme işlemi için
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= temizle($sayfa_baslik) ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
    <style>
        .dl-horizontal dt { float: left; width: 160px; overflow: hidden; clear: left; text-align: right; text-overflow: ellipsis; white-space: nowrap; font-weight: bold; margin-bottom: 0.5rem;}
        .dl-horizontal dd { margin-left: 180px; margin-bottom: 0.5rem;}
        .badge-odendi { background-color: var(--bs-success); }
        .badge-kismen { background-color: var(--bs-warning); color: #000 !important; }
        .badge-odenmedi { background-color: var(--bs-danger); }
    </style>
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container mt-4">
        <?php if ($borc): // İşlem bulunduysa ?>
        <div class="d-flex justify-content-between align-items-center mb-3">
             <h2 class="mb-0">
                <i class="bi <?= $borc['tur'] == 'satis' ? 'bi-receipt text-danger' : 'bi-cart-check text-success' ?> me-2"></i>
                <?= temizle($sayfa_baslik) ?>
            </h2>
             <div>
                 <a href="<?= $_SERVER['HTTP_REFERER'] ?? ($borc['tur'] == 'satis' ? 'satis.php' : 'alis.php') ?>" class="btn btn-sm btn-outline-secondary">
                     <i class="bi bi-arrow-left"></i> Geri Dön
                 </a>
             </div>
        </div>
        <hr>

        <div class="row g-4">
            <div class="col-md-7">
                <div class="card shadow-sm">
                    <div class="card-header">
                       <i class="bi bi-info-circle-fill me-2"></i> İşlem Bilgileri
                    </div>
                    <div class="card-body">
                         <dl class="dl-horizontal">
                            <dt>İşlem ID:</dt>
                            <dd>#<?= $borc['id'] ?></dd>

                            <dt>İşlem Türü:</dt>
                            <dd><?= ($borc['tur'] == 'satis' ? '<span class="badge bg-danger">Satış</span>' : '<span class="badge bg-success">Alış</span>') ?></dd>

                            <dt>Cari:</dt>
                            <dd><a href="cari_detay.php?id=<?= $borc['cari_id'] ?>"><?= temizle($borc['cari_ad_soyad']) ?></a></dd>

                            <dt>Kategori:</dt>
                            <dd><?= $borc['kategori_adi'] ? temizle($borc['kategori_adi']) : '-' ?></dd>

                            <dt>İşlem Tarihi:</dt>
                            <dd><?= date('d.m.Y', strtotime($borc['tarih'])) ?></dd>

                            <dt>Vade Tarihi:</dt>
                            <dd><?= $borc['vade_tarihi'] ? date('d.m.Y', strtotime($borc['vade_tarihi'])) : 'Belirtilmemiş' ?></dd>

                             <dt>Açıklama:</dt>
                            <dd><?= $borc['aciklama'] ? nl2br(temizle($borc['aciklama'])) : '-' ?></dd>
                        </dl>
                    </div>
                </div>
            </div>

             <div class="col-md-5">
                <div class="card shadow-sm mb-4">
                     <div class="card-header">
                       <i class="bi bi-currency-lira me-2"></i> Ödeme Durumu
                    </div>
                    <div class="card-body">
                        <dl class="dl-horizontal">
                            <dt>Toplam Tutar:</dt>
                            <dd><?= number_format($borc['tutar'], 2, ',', '.') ?> ₺</dd>

                            <dt>Ödenen Tutar:</dt>
                            <dd class="text-success"><?= number_format($borc['odenen_tutar'], 2, ',', '.') ?> ₺</dd>

                             <dt>Kalan Tutar:</dt>
                             <dd class="fw-bold <?= $kalan_tutar > 0.01 ? 'text-danger' : 'text-success' ?>">
                                <?= number_format($kalan_tutar, 2, ',', '.') ?> ₺
                            </dd>

                            <dt>Durum:</dt>
                            <dd>
                                <?php
                                    $durum_class = 'badge-secondary';
                                    if ($borc['durum'] == 'odendi') $durum_class = 'badge-odendi';
                                    elseif ($borc['durum'] == 'kismen_odendi') $durum_class = 'badge-kismen';
                                    elseif ($borc['durum'] == 'odenmedi') $durum_class = 'badge-odenmedi';
                                ?>
                                <span class="badge <?= $durum_class ?>">
                                    <?= ucfirst(str_replace('_', ' ', $borc['durum'])) ?>
                                </span>
                            </dd>
                        </dl>
                    </div>
                </div>
                 <div class="card shadow-sm">
                     <div class="card-header">
                        <i class="bi bi-lightning-charge me-2"></i> İşlemler
                    </div>
                    <div class="card-body d-grid gap-2">
                        <?php if ($borc['durum'] != 'odendi'): // Henüz tam ödenmediyse ödeme/tahsilat yapma linki ?>
                            <?php if ($borc['tur'] == 'satis'): // Satışsa Tahsilat Yap ?>
                                <a href="odeme_al.php?borc_id=<?= $borc['id'] ?>&cari_id=<?= $borc['cari_id'] ?>" class="btn btn-success">
                                    <i class="bi bi-arrow-down-circle me-1"></i> Bu Satışa Tahsilat Ekle
                                </a>
                            <?php else: // Alışsa Ödeme Yap ?>
                                <a href="odeme_yap.php?borc_id=<?= $borc['id'] ?>&cari_id=<?= $borc['cari_id'] ?>" class="btn btn-danger">
                                    <i class="bi bi-arrow-up-circle me-1"></i> Bu Alışa Ödeme Ekle
                                </a>
                            <?php endif; ?>
                        <?php endif; ?>

                         <a href="borc_duzenle.php?id=<?= $borc['id'] ?>" class="btn btn-outline-warning">
                            <i class="bi bi-pencil me-1"></i> Bu İşlemi Düzenle
                        </a>
                         <a href="borc_sil.php?id=<?= $borc['id'] ?>&csrf_token=<?= $csrf_token ?>"
                            class="btn btn-outline-danger"
                            onclick="return confirm('Bu işlemi silmek istediğinize emin misiniz? Bu işlem geri alınamaz ve ilgili cari bakiye güncellemeleri tersine çevrilir. İlişkili ödeme/tahsilat kayıtları silinmez ancak bağlantısı kopar.')">
                             <i class="bi bi-trash me-1"></i> Bu İşlemi Sil
                         </a>
                    </div>
                </div>
            </div>
        </div>

        <div class="card shadow-sm mt-4">
            <div class="card-header">
                <i class="bi bi-list-ol me-2"></i> Bu İşlemle İlgili Hesap Hareketleri (Ödemeler/Tahsilatlar)
            </div>
             <div class="card-body p-0">
                <?php if (empty($ilgili_hareketler)): ?>
                    <p class="text-muted p-3">Bu işlemle doğrudan ilişkili bir ödeme veya tahsilat kaydı bulunmamaktadır.</p>
                <?php else: ?>
                <div class="table-responsive">
                    <table class="table table-striped table-hover table-sm mb-0">
                         <thead class="table-light">
                            <tr>
                                <th>Tarih</th>
                                <th>Hesap</th>
                                <th>Tür</th>
                                <th class="text-end">Tutar</th>
                                <th>Açıklama</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach($ilgili_hareketler as $hareket): ?>
                            <tr>
                                <td><?= date('d.m.Y H:i', strtotime($hareket['tarih'])) ?></td>
                                <td><?= temizle($hareket['hesap_adi']) ?></td>
                                <td>
                                     <?php if ($hareket['tur'] == 'giris'): ?>
                                        <span class="badge bg-success">Giriş</span>
                                    <?php elseif ($hareket['tur'] == 'cikis'): ?>
                                        <span class="badge bg-danger">Çıkış</span>
                                    <?php endif; ?>
                                </td>
                                <td class="text-end fw-bold <?= $hareket['tur'] == 'giris' ? 'text-success' : 'text-danger' ?>">
                                     <?= $hareket['tur'] == 'giris' ? '+' : '-' ?>
                                    <?= number_format($hareket['tutar'], 2, ',', '.') ?> ₺
                                </td>
                                <td><?= temizle($hareket['aciklama']) ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
                <?php endif; ?>
            </div>
        </div>


        <?php else: // İşlem bulunamadıysa ?>
            <div class="alert alert-danger">
                Detayı görüntülenecek işlem bulunamadı veya yüklenirken bir hata oluştu.
                <a href="index.php" class="alert-link ms-2">Ana Sayfaya Dön</a>
            </div>
        <?php endif; ?>
    </div>

	<?php include("footer.php"); ?>
	
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>