<?php
require_once 'config.php';
yetkili_mi();

if(!isset($_GET['id']) || !($borc_id = filter_input(INPUT_GET, 'id', FILTER_VALIDATE_INT))) {
    $_SESSION['hata'] = "Geçersiz İşlem ID.";
    header("Location: index.php"); // Ana sayfaya yönlendir
    exit();
}

$sayfa_baslik = "İşlem Düzenle";

// İşlem bilgilerini getir
try {
    $stmt = $db->prepare("
        SELECT b.*, c.ad_soyad, k.kategori_adi
        FROM borclar b
        JOIN cariler c ON b.cari_id = c.id
        LEFT JOIN kategoriler k ON b.kategori_id = k.id
        WHERE b.id = ?
    ");
    $stmt->execute([$borc_id]);
    $borc = $stmt->fetch();

    if(!$borc) {
        $_SESSION['hata'] = "Düzenlenecek işlem bulunamadı.";
        header("Location: index.php"); // Ana sayfaya yönlendir
        exit();
    }

    // Düzenleme için kategorileri ve carileri al (opsiyonel, eğer değiştirilecekse)
    $kategoriler = $db->query("SELECT id, kategori_adi FROM kategoriler ORDER BY kategori_adi")->fetchAll();
    $cariler = $db->query("SELECT id, ad_soyad FROM cariler ORDER BY ad_soyad")->fetchAll();


} catch(PDOException $e) {
    error_log("İşlem düzenleme sayfası (veri çekme) hatası: " . $e->getMessage());
    $_SESSION['hata'] = "Veriler alınırken hata oluştu.";
    $borc = null; // Hata durumunda formu gösterme
    $kategoriler = [];
    $cariler = [];
}


// Form gönderildiğinde
if($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['guncelle'])) {
    if (!csrf_token_dogrula($_POST['csrf_token'] ?? '')) {
         $_SESSION['hata'] = "Geçersiz form gönderimi!";
         header("Location: borc_duzenle.php?id=" . $borc_id);
         exit();
     }

     if (!$borc) { // Eğer ilk veri çekmede hata olduysa, tekrar kontrol et
         $_SESSION['hata'] = "İşlem bilgileri yüklenemediği için güncelleme yapılamıyor.";
         header("Location: index.php");
         exit();
     }

    // Form verilerini al
    $yeni_cari_id = filter_input(INPUT_POST, 'cari_id', FILTER_VALIDATE_INT);
    $yeni_kategori_id = filter_input(INPUT_POST, 'kategori_id', FILTER_VALIDATE_INT);
    $yeni_tutar_str = str_replace(',', '.', $_POST['tutar'] ?? '0');
    $yeni_tutar = filter_var($yeni_tutar_str, FILTER_VALIDATE_FLOAT);
    $yeni_aciklama = temizle($_POST['aciklama'] ?? '');
    $yeni_tarih = filter_input(INPUT_POST, 'tarih', FILTER_SANITIZE_SPECIAL_CHARS);
    $yeni_vade_tarihi = filter_input(INPUT_POST, 'vade_tarihi', FILTER_SANITIZE_SPECIAL_CHARS);
    $yeni_vade_tarihi = empty($yeni_vade_tarihi) ? null : $yeni_vade_tarihi;


     // Veri doğrulama
     $hatalar = [];
     if (empty($yeni_cari_id)) $hatalar[] = "Cari seçimi zorunludur.";
     if (empty($yeni_kategori_id)) $hatalar[] = "Kategori seçimi zorunludur.";
     if ($yeni_tutar === false || $yeni_tutar <= 0) $hatalar[] = "Geçerli bir tutar giriniz.";
     if (empty($yeni_tarih) || !preg_match("/^\d{4}-\d{2}-\d{2}$/", $yeni_tarih)) $hatalar[] = "Geçerli bir işlem tarihi giriniz.";
     if (!empty($yeni_vade_tarihi) && !preg_match("/^\d{4}-\d{2}-\d{2}$/", $yeni_vade_tarihi)) {
        $hatalar[] = "Geçerli bir vade tarihi giriniz veya boş bırakınız.";
     }


    if (empty($hatalar)) {
        try {
            $db->beginTransaction();

            // 1. Eski Cari Bakiyesini Düzelt (Eski tutarı tersine çevir)
            $eski_borc_degisim = 0.0;
            $eski_alacak_degisim = 0.0;
            if ($borc['tur'] == 'satis') {
                $eski_borc_degisim = -$borc['tutar']; // Borcu azalt
            } elseif ($borc['tur'] == 'alis') {
                $eski_alacak_degisim = -$borc['tutar']; // Alacağı azalt
            }
            if (!cariBakiyeGuncelle($db, $borc['cari_id'], $eski_borc_degisim, $eski_alacak_degisim)) {
                throw new Exception("Eski cari bakiyesi güncellenemedi.");
            }

             // 2. Eğer cari değiştiyse, yeni cariye de eski işlemi tersine çevirerek başla (opsiyonel, genellikle cari değiştirilmez)
             // Şimdilik cari değiştirme varsayımıyla devam etmiyoruz, sadece tutar/tarih değişikliği

            // 3. Yeni Cari Bakiyesini Güncelle (Yeni tutarı ekle)
             $yeni_borc_degisim = 0.0;
             $yeni_alacak_degisim = 0.0;
             if ($borc['tur'] == 'satis') {
                 $yeni_borc_degisim = $yeni_tutar; // Borcu artır
             } elseif ($borc['tur'] == 'alis') {
                 $yeni_alacak_degisim = $yeni_tutar; // Alacağı artır
             }
             // Eğer cari değiştiyse $yeni_cari_id kullanılmalı
             if (!cariBakiyeGuncelle($db, $yeni_cari_id, $yeni_borc_degisim, $yeni_alacak_degisim)) {
                 throw new Exception("Yeni cari bakiyesi güncellenemedi.");
             }


            // 4. Borç (işlem) kaydını güncelle
            $stmt_update = $db->prepare("UPDATE borclar SET
                                            cari_id = ?,
                                            kategori_id = ?,
                                            tutar = ?,
                                            aciklama = ?,
                                            tarih = ?,
                                            vade_tarihi = ?
                                        WHERE id = ?");
            $stmt_update->execute([
                $yeni_cari_id,
                $yeni_kategori_id,
                $yeni_tutar,
                $yeni_aciklama,
                $yeni_tarih,
                $yeni_vade_tarihi,
                $borc_id
            ]);

             // 5. İlişkili hesap hareketini güncellemek gerekebilir (eğer varsa ve tutar değiştiyse)
             // Bu adım karmaşıklığı artırır, şimdilik atlandı.

            $db->commit();
            $_SESSION['mesaj'] = "İşlem başarıyla güncellendi!";
            header("Location: cari_detay.php?id=" . $yeni_cari_id); // Güncellenen cariye git
            exit();
        } catch(Exception $e) {
            $db->rollBack();
             error_log("İşlem güncelleme hatası (ID: {$borc_id}): " . $e->getMessage());
            $_SESSION['hata'] = "Güncelleme sırasında bir hata oluştu: " . $e->getMessage();
             // Hata durumunda formu tekrar aynı bilgilerle doldurmak için $borc'u POST verisiyle güncelleyebiliriz.
             $borc['cari_id'] = $yeni_cari_id;
             $borc['kategori_id'] = $yeni_kategori_id;
             $borc['tutar'] = $yeni_tutar;
             $borc['aciklama'] = $yeni_aciklama;
             $borc['tarih'] = $yeni_tarih;
             $borc['vade_tarihi'] = $yeni_vade_tarihi;
        }
     } else {
         $_SESSION['form_hatalari_borc_duzenle'] = $hatalar;
         // Form verilerini tekrar doldurmak için $borc'u güncelleyelim
         $borc['cari_id'] = $yeni_cari_id;
         $borc['kategori_id'] = $yeni_kategori_id;
         $borc['tutar'] = $yeni_tutar;
         $borc['aciklama'] = $yeni_aciklama;
         $borc['tarih'] = $yeni_tarih;
         $borc['vade_tarihi'] = $yeni_vade_tarihi;
     }
}

$csrf_token = csrf_token_olustur();
$form_hatalari = $_SESSION['form_hatalari_borc_duzenle'] ?? [];
unset($_SESSION['form_hatalari_borc_duzenle']);

?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= $sayfa_baslik ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container mt-4">
        <?php if ($borc): // İşlem bulunduysa formu göster ?>
         <h2><i class="bi bi-pencil-square me-2"></i><?= $sayfa_baslik ?>: <?= $borc['tur'] == 'satis' ? 'Satış' : 'Alış' ?> (#<?= $borc['id'] ?>)</h2>
         <hr>

         <?php if (!empty($form_hatalari)): ?>
             <div class="alert alert-danger alert-dismissible fade show" role="alert">
                <strong><i class="bi bi-exclamation-triangle-fill me-2"></i> Lütfen hataları düzeltin:</strong>
                <ul>
                    <?php foreach ($form_hatalari as $hata): ?>
                        <li><?= htmlspecialchars($hata) ?></li>
                    <?php endforeach; ?>
                </ul>
                 <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <form method="post">
             <input type="hidden" name="csrf_token" value="<?= $csrf_token ?>">
             <div class="card shadow-sm">
                 <div class="card-body">
                     <div class="row g-3">
                         <div class="col-md-6">
                            <label for="cari_id" class="form-label">Cari <span class="text-danger">*</span></label>
                             <select class="form-select" id="cari_id" name="cari_id" required>
                                <option value="">-- Cari Seçin --</option>
                                <?php foreach ($cariler as $cari_item): ?>
                                    <option value="<?= $cari_item['id'] ?>" <?= ($borc['cari_id'] == $cari_item['id']) ? 'selected' : '' ?>>
                                        <?= temizle($cari_item['ad_soyad']) ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                         </div>
                         <div class="col-md-6">
                            <label for="kategori_id" class="form-label">Kategori <span class="text-danger">*</span></label>
                            <select class="form-select" id="kategori_id" name="kategori_id" required>
                                <option value="">-- Kategori Seçin --</option>
                                <?php foreach ($kategoriler as $kategori): ?>
                                     <option value="<?= $kategori['id'] ?>" <?= ($borc['kategori_id'] == $kategori['id']) ? 'selected' : '' ?>>
                                        <?= temizle($kategori['kategori_adi']) ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="col-md-4">
                            <label for="tutar" class="form-label">Tutar (₺) <span class="text-danger">*</span></label>
                            <input type="text" inputmode="decimal" class="form-control" id="tutar" name="tutar" required
                                   value="<?= number_format($borc['tutar'], 2, ',', '') ?>"> <?php // Virgül ile göster ?>
                        </div>
                         <div class="col-md-4">
                            <label for="tarih" class="form-label">İşlem Tarihi <span class="text-danger">*</span></label>
                            <input type="date" class="form-control" id="tarih" name="tarih" required
                                   value="<?= htmlspecialchars($borc['tarih'], ENT_QUOTES) ?>">
                        </div>
                        <div class="col-md-4">
                            <label for="vade_tarihi" class="form-label">Vade Tarihi</label>
                            <input type="date" class="form-control" id="vade_tarihi" name="vade_tarihi"
                                   value="<?= htmlspecialchars($borc['vade_tarihi'] ?? '', ENT_QUOTES) ?>">
                        </div>
                         <div class="col-12">
                            <label for="aciklama" class="form-label">Açıklama</label>
                            <textarea class="form-control" id="aciklama" name="aciklama" rows="3"><?= htmlspecialchars($borc['aciklama'] ?? '', ENT_QUOTES) ?></textarea>
                        </div>
                         <div class="col-12 d-flex justify-content-between">
                             <a href="cari_detay.php?id=<?= $borc['cari_id'] ?>" class="btn btn-secondary">
                                 <i class="bi bi-x-circle me-1"></i> İptal
                             </a>
                            <button type="submit" name="guncelle" class="btn btn-primary">
                                <i class="bi bi-save me-1"></i> Değişiklikleri Kaydet
                            </button>
                        </div>
                    </div>
                 </div>
             </div>
         </form>

        <?php else: // İşlem bulunamadıysa ?>
            <div class="alert alert-danger">
                Düzenlenecek işlem bulunamadı veya yüklenirken bir hata oluştu.
                <a href="index.php" class="alert-link ms-2">Ana Sayfaya Dön</a>
            </div>
        <?php endif; ?>
    </div>

	<?php include("footer.php"); ?>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>