<?php
require_once 'config.php';
yetkili_mi();

$sayfa_baslik = "Cari Detay";

if (!isset($_GET['id']) || !($cari_id = filter_input(INPUT_GET, 'id', FILTER_VALIDATE_INT))) {
    $_SESSION['hata'] = "Geçersiz Cari ID.";
    header("Location: cariler.php");
    exit();
}

// Cari bilgilerini ve bakiye bilgilerini getir
try {
    $stmt = $db->prepare("
        SELECT c.*, g.grup_adi
        FROM cariler c
        LEFT JOIN cari_gruplari g ON c.grup_id = g.id
        WHERE c.id = ?
    ");
    $stmt->execute([$cari_id]);
    $cari = $stmt->fetch();

    if (!$cari) {
        $_SESSION['hata'] = "Cari bulunamadı.";
        header("Location: cariler.php");
        exit();
    }

    // Cari Hesap Hareketleri (Satışlar, Alışlar, Ödemeler, Tahsilatlar)
    // Bu sorgu cari ekstresi için daha detaylı olmalı, şimdilik satış/alışları ve hesap hareketlerini ayrı alalım

    // Satışları (Müşteriye yapılan)
    $satislar_stmt = $db->prepare("
        SELECT b.*, k.kategori_adi
        FROM borclar b
        LEFT JOIN kategoriler k ON b.kategori_id = k.id
        WHERE b.cari_id = ? AND b.tur = 'satis'
        ORDER BY b.tarih DESC, b.id DESC
    ");
    $satislar_stmt->execute([$cari_id]);
    $satislar = $satislar_stmt->fetchAll();

    // Alışları (Tedarikçiden yapılan)
    $alislar_stmt = $db->prepare("
        SELECT b.*, k.kategori_adi
        FROM borclar b
        LEFT JOIN kategoriler k ON b.kategori_id = k.id
        WHERE b.cari_id = ? AND b.tur = 'alis'
        ORDER BY b.tarih DESC, b.id DESC
    ");
    $alislar_stmt->execute([$cari_id]);
    $alislar = $alislar_stmt->fetchAll();

    // Hesap Hareketleri (Ödemeler/Tahsilatlar)
    $hareketler_stmt = $db->prepare("
        SELECT hh.*, h.hesap_adi
        FROM hesap_hareketleri hh
        LEFT JOIN hesaplar h ON hh.hesap_id = h.id
        WHERE hh.cari_id = ? AND hh.tur != 'transfer' -- Transferler hariç
        ORDER BY hh.tarih DESC, hh.id DESC
    ");
    $hareketler_stmt->execute([$cari_id]);
    $hareketler = $hareketler_stmt->fetchAll();

    // Bakiye Hesaplama (güvenlik için tekrar hesapla)
    $hesaplanan_bakiye = ($cari['toplam_alacak'] ?? 0.0) - ($cari['toplam_borc'] ?? 0.0);


} catch (PDOException $e) {
    error_log("Cari detay hatası (ID: {$cari_id}): " . $e->getMessage());
    $_SESSION['hata'] = "Cari detayları alınırken bir veritabanı hatası oluştu.";
     // Hata durumunda boş diziler
     $cari = $cari ?? null; // Cari null olabilir
     $satislar = [];
     $alislar = [];
     $hareketler = [];
     $hesaplanan_bakiye = 0.0;
}

$csrf_token = csrf_token_olustur(); // Silme işlemleri için

?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= $sayfa_baslik ?> - <?= $cari ? temizle($cari['ad_soyad']) : '' ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
    <style>
        .detail-card { border-radius: 0.5rem; }
        .summary-list .list-group-item { border: none; padding: 0.75rem 1rem; }
        .bakiye-pozitif { color: #198754; font-weight: bold; }
        .bakiye-negatif { color: #dc3545; font-weight: bold; }
        .table th { background-color: #f8f9fa; }
    </style>
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container mt-4">
        <?php if ($cari): // Cari bulunduysa göster ?>
        <div class="d-flex justify-content-between align-items-center mb-3 flex-wrap">
            <h2 class="fw-bold mb-0"><i class="bi bi-person-badge me-2"></i> <?= temizle($cari['ad_soyad']) ?></h2>
            <div>
                 <span class="badge bg-secondary fs-6 me-2"><?= temizle($cari['grup_adi']) ?></span>
                 <span class="badge <?= $hesaplanan_bakiye >= 0 ? 'bg-success' : 'bg-danger' ?> fs-5">
                     Bakiye: <?= number_format($hesaplanan_bakiye, 2, ',', '.') ?> ₺
                 </span>
            </div>
        </div>
         <a href="cariler.php" class="btn btn-sm btn-outline-secondary mb-3">
             <i class="bi bi-arrow-left"></i> Cari Listesine Dön
         </a>
        <hr class="mb-4">

        <div class="row g-4">
            <div class="col-lg-4">
                 <div class="card detail-card shadow-sm mb-4">
                    <div class="card-body">
                        <h5 class="card-title text-primary mb-3"><i class="bi bi-info-circle me-2"></i>Cari Bilgileri</h5>
                        <p class="mb-2">
                            <strong><i class="bi bi-telephone text-muted me-2"></i> Telefon:</strong>
                            <span class="text-muted"><?= $cari['telefon'] ? temizle($cari['telefon']) : '-' ?></span>
                        </p>
                        <p class="mb-1"><strong><i class="bi bi-geo-alt text-muted me-2"></i> Adres:</strong>
                        <i><?= $cari['adres'] ? nl2br(temizle($cari['adres'])) : '-' ?></i></p>
                        <a href="cari_duzenle.php?id=<?= $cari['id'] ?>" class="btn btn-outline-warning w-100">
                            <i class="bi bi-pencil me-1"></i> Bilgileri Düzenle
                        </a>
                    </div>
                </div>
                 <div class="card detail-card shadow-sm">
                    <div class="card-body">
                         <h5 class="card-title text-success mb-3"><i class="bi bi-lightning-charge me-2"></i>Hızlı İşlemler</h5>
                        <div class="d-grid gap-2">
                            <a href="satis.php?cari_id=<?= $cari['id'] ?>" class="btn btn-primary">
                                <i class="bi bi-cart-plus me-1"></i> Yeni Satış
                            </a>
                             <a href="alis.php?cari_id=<?= $cari['id'] ?>" class="btn btn-info text-white"> <?php // Renk değiştirildi ?>
                                <i class="bi bi-bag-plus me-1"></i> Yeni Alış
                            </a>
                             <a href="odeme_al.php?cari_id=<?= $cari['id'] ?>" class="btn btn-success">
                                <i class="bi bi-arrow-down-circle me-1"></i> Ödeme Al
                            </a>
                             <a href="odeme_yap.php?cari_id=<?= $cari['id'] ?>" class="btn btn-danger">
                                <i class="bi bi-arrow-up-circle me-1"></i> Ödeme Yap
                            </a>
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-lg-8">
                 <div class="card detail-card shadow-sm">
                     <div class="card-header">
                         <h5 class="mb-0"><i class="bi bi-list-ul me-2"></i>İşlem Geçmişi</h5>
                     </div>
                    <div class="card-body p-0">
                        <ul class="nav nav-tabs nav-fill mb-0" id="myTab" role="tablist">
                          <li class="nav-item" role="presentation">
                            <button class="nav-link active" id="satislar-tab" data-bs-toggle="tab" data-bs-target="#satislar" type="button" role="tab" aria-controls="satislar" aria-selected="true">
                                Satışlar (Borçları) <span class="badge bg-danger rounded-pill"><?= count($satislar) ?></span>
                            </button>
                          </li>
                          <li class="nav-item" role="presentation">
                            <button class="nav-link" id="alislar-tab" data-bs-toggle="tab" data-bs-target="#alislar" type="button" role="tab" aria-controls="alislar" aria-selected="false">
                                Alışlar (Alacakları) <span class="badge bg-success rounded-pill"><?= count($alislar) ?></span>
                            </button>
                          </li>
                           <li class="nav-item" role="presentation">
                            <button class="nav-link" id="odemeler-tab" data-bs-toggle="tab" data-bs-target="#odemeler" type="button" role="tab" aria-controls="odemeler" aria-selected="false">
                                Ödemeler / Tahsilatlar <span class="badge bg-secondary rounded-pill"><?= count($hareketler) ?></span>
                            </button>
                          </li>
                        </ul>
                        <div class="tab-content p-3" id="myTabContent">
                          <div class="tab-pane fade show active" id="satislar" role="tabpanel" aria-labelledby="satislar-tab">
                              <h6 class="text-danger mb-3">Müşterinin Borçları (Yapılan Satışlar)</h6>
                              <?php if (empty($satislar)): ?>
                                  <p class="text-muted">Bu cariye ait satış kaydı bulunmamaktadır.</p>
                              <?php else: ?>
                                <div class="table-responsive">
                                    <table class="table table-sm table-hover">
                                        <thead>
                                            <tr>
                                                <th>Tarih</th>
                                                <th>Açıklama</th>
                                                <th>Kategori</th>
                                                <th class="text-end">Tutar</th>
                                                <th>Vade</th>
                                                <th>İşlem</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach($satislar as $satis): ?>
                                            <tr>
                                                <td><?= date('d.m.Y', strtotime($satis['tarih'])) ?></td>
                                                <td><?= temizle($satis['aciklama']) ?></td>
                                                <td><?= temizle($satis['kategori_adi']) ?></td>
                                                <td class="text-end text-danger"><?= number_format($satis['tutar'], 2, ',', '.') ?> ₺</td>
                                                <td><?= $satis['vade_tarihi'] ? date('d.m.Y', strtotime($satis['vade_tarihi'])) : '-' ?></td>
                                                 <td>
                                                     <a href="borc_duzenle.php?id=<?= $satis['id'] ?>" class="btn btn-xs btn-outline-warning" title="Düzenle"><i class="bi bi-pencil"></i></a>
                                                     <a href="borc_sil.php?id=<?= $satis['id'] ?>&csrf_token=<?= $csrf_token ?>"
                                                        class="btn btn-xs btn-outline-danger" title="Sil"
                                                        onclick="return confirm('Bu işlemi silmek istediğinize emin misiniz? Bu işlem geri alınamaz ve ilgili bakiye güncellemeleri tersine çevrilir.')">
                                                         <i class="bi bi-trash"></i>
                                                     </a>
                                                 </td>
                                            </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                              <?php endif; ?>
                          </div>
                          <div class="tab-pane fade" id="alislar" role="tabpanel" aria-labelledby="alislar-tab">
                              <h6 class="text-success mb-3">Tedarikçinin Alacakları (Yapılan Alışlar)</h6>
                               <?php if (empty($alislar)): ?>
                                  <p class="text-muted">Bu cariden alış kaydı bulunmamaktadır.</p>
                              <?php else: ?>
                                <div class="table-responsive">
                                    <table class="table table-sm table-hover">
                                        <thead>
                                            <tr>
                                                <th>Tarih</th>
                                                <th>Açıklama</th>
                                                <th>Kategori</th>
                                                <th class="text-end">Tutar</th>
                                                <th>Vade</th>
                                                 <th>İşlem</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach($alislar as $alis): ?>
                                            <tr>
                                                <td><?= date('d.m.Y', strtotime($alis['tarih'])) ?></td>
                                                <td><?= temizle($alis['aciklama']) ?></td>
                                                <td><?= temizle($alis['kategori_adi']) ?></td>
                                                <td class="text-end text-success"><?= number_format($alis['tutar'], 2, ',', '.') ?> ₺</td>
                                                <td><?= $alis['vade_tarihi'] ? date('d.m.Y', strtotime($alis['vade_tarihi'])) : '-' ?></td>
                                                <td>
                                                    <a href="borc_duzenle.php?id=<?= $alis['id'] ?>" class="btn btn-xs btn-outline-warning" title="Düzenle"><i class="bi bi-pencil"></i></a>
                                                     <a href="borc_sil.php?id=<?= $alis['id'] ?>&csrf_token=<?= $csrf_token ?>"
                                                        class="btn btn-xs btn-outline-danger" title="Sil"
                                                        onclick="return confirm('Bu işlemi silmek istediğinize emin misiniz? Bu işlem geri alınamaz ve ilgili bakiye güncellemeleri tersine çevrilir.')">
                                                         <i class="bi bi-trash"></i>
                                                     </a>
                                                </td>
                                            </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                              <?php endif; ?>
                          </div>
                           <div class="tab-pane fade" id="odemeler" role="tabpanel" aria-labelledby="odemeler-tab">
                                <h6 class="text-secondary mb-3">Yapılan Ödemeler ve Alınan Tahsilatlar</h6>
                                <?php if (empty($hareketler)): ?>
                                    <p class="text-muted">Bu cari ile ilgili ödeme veya tahsilat kaydı bulunmamaktadır.</p>
                                <?php else: ?>
                                <div class="table-responsive">
                                    <table class="table table-sm table-hover">
                                        <thead>
                                            <tr>
                                                <th>Tarih</th>
                                                <th>Tür</th>
                                                <th>Hesap</th>
                                                <th>Açıklama</th>
                                                <th class="text-end">Tutar</th>
                                                <th>İşlem</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach($hareketler as $hareket): ?>
                                            <tr>
                                                <td><?= date('d.m.Y H:i', strtotime($hareket['tarih'])) ?></td>
                                                <td>
                                                    <?php if ($hareket['tur'] == 'giris'): ?>
                                                        <span class="badge bg-success">Tahsilat</span>
                                                    <?php elseif ($hareket['tur'] == 'cikis'): ?>
                                                         <span class="badge bg-danger">Ödeme</span>
                                                    <?php else: ?>
                                                         <span class="badge bg-secondary"><?= ucfirst($hareket['tur']) ?></span>
                                                    <?php endif; ?>
                                                </td>
                                                <td><?= temizle($hareket['hesap_adi']) ?></td>
                                                <td><?= temizle($hareket['aciklama']) ?></td>
                                                <td class="text-end <?= $hareket['tur'] == 'giris' ? 'text-success' : 'text-danger' ?>">
                                                    <?= number_format($hareket['tutar'], 2, ',', '.') ?> ₺
                                                </td>
                                                 <td>
                                                     <?php /* Hesap hareketi silme/düzenleme genellikle risklidir, dikkatli olunmalı */ ?>
                                                      <a href="hesap_hareketi_sil.php?id=<?= $hareket['id'] ?>&csrf_token=<?= $csrf_token ?>"
                                                        class="btn btn-xs btn-outline-danger" title="Sil"
                                                        onclick="return confirm('Bu hesap hareketini silmek istediğinize emin misiniz? Bu işlem ilgili hesap ve cari bakiyelerini GÜNCELLEMEZ, sadece kaydı siler ve tutarsızlığa yol açabilir! Emin misiniz?')">
                                                         <i class="bi bi-trash"></i>
                                                     </a>
                                                 </td>
                                            </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                               <?php endif; ?>
                           </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <?php else: // Cari bulunamadıysa ?>
             <div class="alert alert-danger">
                 <i class="bi bi-exclamation-triangle-fill me-2"></i> Belirtilen cari bulunamadı veya detayları alınırken bir hata oluştu.
                 <a href="cariler.php" class="alert-link ms-2">Cari Listesine Dön</a>
             </div>
        <?php endif; ?>
    </div>

	<?php include("footer.php"); ?>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>