<?php
require_once 'config.php';
yetkili_mi();

$sayfa_baslik = "Cari Ekstre";

// Cari ID'sini al
$cari_id = filter_input(INPUT_GET, 'id', FILTER_VALIDATE_INT);
$secili_cari = null;
$ekstre = [];
$baslangic_bakiye = 0.0;
$donem_ici_borc = 0.0;
$donem_ici_alacak = 0.0;

// Filtreleme
$filtre_baslangic = filter_input(INPUT_GET, 'baslangic', FILTER_SANITIZE_SPECIAL_CHARS);
$filtre_bitis = filter_input(INPUT_GET, 'bitis', FILTER_SANITIZE_SPECIAL_CHARS);

if (!$filtre_baslangic || !preg_match("/^\d{4}-\d{2}-\d{2}$/", $filtre_baslangic)) {
    $filtre_baslangic = date('Y-m-01');
}
if (!$filtre_bitis || !preg_match("/^\d{4}-\d{2}-\d{2}$/", $filtre_bitis)) {
    $filtre_bitis = date('Y-m-d');
}


if ($cari_id) {
    try {
        // Cari bilgilerini al
        $stmt_cari = $db->prepare("SELECT * FROM cariler WHERE id = ?");
        $stmt_cari->execute([$cari_id]);
        $secili_cari = $stmt_cari->fetch();

        if ($secili_cari) {
             $sayfa_baslik .= " - " . temizle($secili_cari['ad_soyad']);

             // 1. Dönem Başı Bakiyeyi Hesapla
             // Dönem başından ÖNCEKİ tüm işlemlerin net etkisi
             $sql_devir_borc = "SELECT SUM(tutar) FROM borclar WHERE cari_id = :cari_id AND tur = 'satis' AND tarih < :baslangic";
             $stmt_devir_borc = $db->prepare($sql_devir_borc);
             $stmt_devir_borc->execute([':cari_id' => $cari_id, ':baslangic' => $filtre_baslangic]);
             $devir_borc = $stmt_devir_borc->fetchColumn() ?: 0.0;

             $sql_devir_alacak = "SELECT SUM(tutar) FROM borclar WHERE cari_id = :cari_id AND tur = 'alis' AND tarih < :baslangic";
             $stmt_devir_alacak = $db->prepare($sql_devir_alacak);
             $stmt_devir_alacak->execute([':cari_id' => $cari_id, ':baslangic' => $filtre_baslangic]);
             $devir_alacak = $stmt_devir_alacak->fetchColumn() ?: 0.0;

             $sql_devir_tahsilat = "SELECT SUM(tutar) FROM hesap_hareketleri WHERE cari_id = :cari_id AND tur = 'giris' AND DATE(tarih) < :baslangic";
             $stmt_devir_tahsilat = $db->prepare($sql_devir_tahsilat);
             $stmt_devir_tahsilat->execute([':cari_id' => $cari_id, ':baslangic' => $filtre_baslangic]);
             $devir_tahsilat = $stmt_devir_tahsilat->fetchColumn() ?: 0.0; // Müşteriden alınan para (müşteri borcunu azaltır)

             $sql_devir_odeme = "SELECT SUM(tutar) FROM hesap_hareketleri WHERE cari_id = :cari_id AND tur = 'cikis' AND DATE(tarih) < :baslangic";
             $stmt_devir_odeme = $db->prepare($sql_devir_odeme);
             $stmt_devir_odeme->execute([':cari_id' => $cari_id, ':baslangic' => $filtre_baslangic]);
             $devir_odeme = $stmt_devir_odeme->fetchColumn() ?: 0.0; // Tedarikçiye yapılan ödeme (bizim borcumuzu azaltır)

             // Başlangıç Bakiyesi: (Bizim Borçlarımız + Müşteri Ödemeleri) - (Müşteri Borçları + Bizim Ödemelerimiz)
             // Bakiye = (Toplam Alacak Hareketleri) - (Toplam Borç Hareketleri)
             // Bakiye = (devir_alacak + devir_tahsilat) - (devir_borc + devir_odeme) YANLIŞ
             // Bakiye = Cari'nin alacağı - Cari'nin borcu
             // Bakiye = (Bizim Borcumuz[Alış] - Bizim Yaptığımız Ödeme) - (Müşteri Borcu[Satış] - Müşteriden Alınan Tahsilat)
             // Başlangıç Bakiyesi = (devir_alacak - devir_odeme) - (devir_borc - devir_tahsilat)
             $baslangic_bakiye = ($devir_alacak - $devir_odeme) - ($devir_borc - $devir_tahsilat);


             // 2. Dönem İçi Hareketleri Çek ve Birleştir
             $params_donem = [
                 ':cari_id' => $cari_id,
                 ':baslangic' => $filtre_baslangic,
                 ':bitis' => $filtre_bitis . ' 23:59:59' // Bitiş tarihinin sonunu al
             ];

            // Satışlar (Müşteriye borç yazılır)
            $stmt_satis = $db->prepare("SELECT id, tarih, aciklama, tutar, 'Satış' as islem_turu FROM borclar WHERE cari_id = :cari_id AND tur = 'satis' AND tarih BETWEEN :baslangic AND :bitis ORDER BY tarih ASC, id ASC");
            $stmt_satis->execute($params_donem);
            $satislar = $stmt_satis->fetchAll();

            // Alışlar (Müşteriye alacak yazılır)
            $stmt_alis = $db->prepare("SELECT id, tarih, aciklama, tutar, 'Alış' as islem_turu FROM borclar WHERE cari_id = :cari_id AND tur = 'alis' AND tarih BETWEEN :baslangic AND :bitis ORDER BY tarih ASC, id ASC");
            $stmt_alis->execute($params_donem);
            $alislar = $stmt_alis->fetchAll();

            // Tahsilatlar (Müşteri borcunu azaltır, hesaba GİRİŞ)
            $stmt_tahsilat = $db->prepare("SELECT id, tarih, aciklama, tutar, 'Tahsilat' as islem_turu FROM hesap_hareketleri WHERE cari_id = :cari_id AND tur = 'giris' AND tarih BETWEEN :baslangic AND :bitis ORDER BY tarih ASC, id ASC");
            $stmt_tahsilat->execute($params_donem);
            $tahsilatlar = $stmt_tahsilat->fetchAll();

             // Ödemeler (Bizim borcumuzu azaltır, hesaptan ÇIKIŞ)
            $stmt_odeme = $db->prepare("SELECT id, tarih, aciklama, tutar, 'Ödeme' as islem_turu FROM hesap_hareketleri WHERE cari_id = :cari_id AND tur = 'cikis' AND tarih BETWEEN :baslangic AND :bitis ORDER BY tarih ASC, id ASC");
            $stmt_odeme->execute($params_donem);
            $odemeler = $stmt_odeme->fetchAll();

            // Tüm hareketleri tek bir dizide birleştir
            $tum_hareketler = array_merge($satislar, $alislar, $tahsilatlar, $odemeler);

            // Tarihe göre sırala
            usort($tum_hareketler, function($a, $b) {
                $tarih_a = strtotime($a['tarih']);
                $tarih_b = strtotime($b['tarih']);
                 if ($tarih_a == $tarih_b) {
                     // Aynı tarihte ID'ye göre sırala (veya işlem türüne göre öncelik verilebilir)
                    return $a['id'] <=> $b['id']; // PHP 7+ spaceship operator
                 }
                return $tarih_a <=> $tarih_b;
            });

             // Ekstreyi oluştur ve bakiyeyi hesapla
             $bakiye = $baslangic_bakiye;
             foreach($tum_hareketler as $hareket) {
                 $borc_tutari = 0.0;
                 $alacak_tutari = 0.0;

                 switch ($hareket['islem_turu']) {
                     case 'Satış':
                         $borc_tutari = $hareket['tutar']; // Müşterinin borcu artar
                         $donem_ici_borc += $borc_tutari;
                         break;
                     case 'Alış':
                         $alacak_tutari = $hareket['tutar']; // Müşterinin alacağı (bizim borcumuz) artar
                          $donem_ici_alacak += $alacak_tutari;
                         break;
                     case 'Tahsilat':
                         $alacak_tutari = $hareket['tutar']; // Müşteri borcunu öder (alacak hareketi gibi)
                          $donem_ici_alacak += $alacak_tutari;
                         break;
                     case 'Ödeme':
                         $borc_tutari = $hareket['tutar']; // Biz borcumuzu öderiz (borç hareketi gibi)
                          $donem_ici_borc += $borc_tutari;
                         break;
                 }
                 // Bakiye = Önceki Bakiye + Alacak - Borç
                 $bakiye += ($alacak_tutari - $borc_tutari);

                 $ekstre[] = [
                     'tarih' => $hareket['tarih'],
                     'aciklama' => $hareket['aciklama'] . " (" . $hareket['islem_turu'] . " #" . $hareket['id'] . ")",
                     'borc' => $borc_tutari,
                     'alacak' => $alacak_tutari,
                     'bakiye' => $bakiye
                 ];
             }


        } else {
            $_SESSION['hata'] = "Belirtilen Cari ID bulunamadı.";
            // Cari listesini al (seçim için)
            $cariler = $db->query("SELECT id, ad_soyad FROM cariler ORDER BY ad_soyad")->fetchAll();
        }

    } catch (PDOException $e) {
        error_log("Cari Ekstre Hatası (ID: {$cari_id}): " . $e->getMessage());
        $_SESSION['hata'] = "Ekstre oluşturulurken bir veritabanı hatası oluştu.";
         $cariler = $db->query("SELECT id, ad_soyad FROM cariler ORDER BY ad_soyad")->fetchAll(); // Hata olsa bile carileri al
    }
} else {
     // ID yoksa, cari listesini al
     try {
         $cariler = $db->query("SELECT id, ad_soyad FROM cariler ORDER BY ad_soyad")->fetchAll();
     } catch (PDOException $e) {
         error_log("Cari Ekstre (Cari Listesi) Hatası: " . $e->getMessage());
         $_SESSION['hata'] = "Cariler yüklenirken bir hata oluştu.";
         $cariler = [];
     }
}


?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?= temizle($sayfa_baslik) ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
    <style>
        @media print {
            .no-print { display: none; }
            .table { font-size: 10pt; }
            .card-header, .card-footer { background-color: #fff !important; border: none !important;}
            h2, h5 { text-align: center; }
        }
        .table th { background-color: #f8f9fa; }
    </style>
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container mt-4">
        <div class="card shadow-sm no-print">
            <div class="card-body">
                 <h2 class="text-center mb-4"><i class="bi bi-person-lines-fill me-2"></i> Cari Ekstre</h2>
                <form method="GET" class="row g-3 justify-content-center">
                    <div class="col-md-4">
                        <label for="id" class="form-label">Cari Seçin</label>
                        <select id="id" name="id" class="form-select" required onchange="this.form.submit()">
                            <option value="">-- Cari Seçiniz --</option>
                            <?php foreach($cariler as $cari): ?>
                            <option value="<?= $cari['id'] ?>" <?= ($cari_id == $cari['id']) ? 'selected' : '' ?>>
                                <?= temizle($cari['ad_soyad']) ?>
                            </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="col-md-3">
                        <label for="baslangic" class="form-label">Başlangıç Tarihi</label>
                        <input type="date" id="baslangic" name="baslangic" class="form-control" value="<?= htmlspecialchars($filtre_baslangic) ?>">
                    </div>
                    <div class="col-md-3">
                        <label for="bitis" class="form-label">Bitiş Tarihi</label>
                        <input type="date" id="bitis" name="bitis" class="form-control" value="<?= htmlspecialchars($filtre_bitis) ?>">
                    </div>
                    <div class="col-md-2 d-flex align-items-end">
                        <button type="submit" class="btn btn-primary w-100">
                            <i class="bi bi-search"></i> Getir
                        </button>
                    </div>
                </form>
            </div>
        </div>

        <?php if ($secili_cari): ?>
        <div class="card shadow-sm mt-4">
             <div class="card-header">
                 <div class="d-flex justify-content-between align-items-center">
                     <h5 class="mb-0"><?= temizle($secili_cari['ad_soyad']) ?> - Ekstre (<?= date('d.m.Y', strtotime($filtre_baslangic)) ?> - <?= date('d.m.Y', strtotime($filtre_bitis)) ?>)</h5>
                     <div>
                         <a href="pdf_export.php?type=cari_ekstre&id=<?= $cari_id ?>&baslangic=<?= $filtre_baslangic ?>&bitis=<?= $filtre_bitis ?>" class="btn btn-sm btn-outline-primary no-print me-2">
                             <i class="bi bi-file-pdf"></i> PDF İndir
                         </a>
                         <button class="btn btn-sm btn-outline-secondary no-print" onclick="window.print();">
                             <i class="bi bi-printer"></i> Yazdır
                         </button>
                     </div>
                 </div>
             </div>
            <div class="card-body p-0">
                <div class="table-responsive">
                    <table class="table table-bordered table-striped table-sm mb-0">
                        <thead class="table-light text-center">
                            <tr>
                                <th style="width:15%;">Tarih</th>
                                <th>Açıklama</th>
                                <th style="width:15%;">Borç (+)</th>
                                <th style="width:15%;">Alacak (-)</th>
                                <th style="width:15%;">Bakiye</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr>
                                <td colspan="2" class="text-end fw-bold">Devir Bakiye (<?= date('d.m.Y', strtotime($filtre_baslangic)) ?> öncesi)</td>
                                <td class="text-end"><?php /* Devir Borç */ ?></td>
                                <td class="text-end"><?php /* Devir Alacak */ ?></td>
                                <td class="text-end fw-bold <?= $baslangic_bakiye >= 0 ? 'text-success' : 'text-danger' ?>">
                                     <?= number_format($baslangic_bakiye, 2, ',', '.') ?> ₺
                                     <span class="ms-1"><?= $baslangic_bakiye > 0 ? 'A' : ($baslangic_bakiye < 0 ? 'B' : '') ?></span>
                                </td>
                            </tr>
                            <?php if (empty($ekstre)): ?>
                                <tr>
                                    <td colspan="5" class="text-center text-muted py-3">Seçilen tarih aralığında hareket bulunamadı.</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($ekstre as $hareket): ?>
                                    <tr>
                                        <td class="text-center"><?= date('d.m.Y', strtotime($hareket['tarih'])) ?></td>
                                        <td><?= temizle($hareket['aciklama']) ?></td>
                                        <td class="text-end text-danger"><?= $hareket['borc'] > 0 ? number_format($hareket['borc'], 2, ',', '.') . ' ₺' : '-' ?></td>
                                        <td class="text-end text-success"><?= $hareket['alacak'] > 0 ? number_format($hareket['alacak'], 2, ',', '.') . ' ₺' : '-' ?></td>
                                        <td class="text-end fw-bold <?= $hareket['bakiye'] >= 0 ? 'text-success' : 'text-danger' ?>">
                                            <?= number_format($hareket['bakiye'], 2, ',', '.') ?> ₺
                                             <span class="ms-1"><?= $hareket['bakiye'] > 0 ? 'A' : ($hareket['bakiye'] < 0 ? 'B' : '') ?></span>
                                             <?php // A: Alacaklı (Biz borçluyuz), B: Borçlu (Bize borçlu) ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                             <tr class="table-light">
                                 <td colspan="2" class="text-end fw-bold">Dönem İçi Toplamlar</td>
                                 <td class="text-end fw-bold text-danger"><?= number_format($donem_ici_borc, 2, ',', '.') ?> ₺</td>
                                 <td class="text-end fw-bold text-success"><?= number_format($donem_ici_alacak, 2, ',', '.') ?> ₺</td>
                                 <td class="text-end"></td> <?php // Bakiye toplamı anlamsız ?>
                             </tr>
                             <tr class="table-secondary">
                                 <td colspan="4" class="text-end fw-bold">Son Bakiye (<?= date('d.m.Y', strtotime($filtre_bitis)) ?>)</td>
                                 <td class="text-end fw-bold <?= $bakiye >= 0 ? 'text-success' : 'text-danger' ?>">
                                     <?= number_format($bakiye, 2, ',', '.') ?> ₺
                                      <span class="ms-1"><?= $bakiye > 0 ? 'A' : ($bakiye < 0 ? 'B' : '') ?></span>
                                 </td>
                             </tr>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
        <?php elseif ($cari_id): ?>
             <div class="alert alert-warning mt-4">Seçilen cari bulunamadı veya yüklenirken bir hata oluştu.</div>
         <?php elseif (!empty($cariler)): ?>
              <div class="alert alert-info mt-4 text-center">Lütfen ekstre görüntülemek için yukarıdan bir cari seçiniz.</div>
         <?php else: ?>
              <div class="alert alert-warning mt-4 text-center">Sistemde kayıtlı cari bulunmamaktadır.</div>
         <?php endif; ?>
    </div>
	   
	 <?php include("footer.php"); ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>