<?php
require_once 'config.php';
// yetkili_mi(); // Kullanıcı yetkilendirme kontrolü istemedi.

if (!isset($_GET['id']) || !($cari_id = filter_input(INPUT_GET, 'id', FILTER_VALIDATE_INT))) {
    $_SESSION['hata'] = "Geçersiz Cari ID.";
    header("Location: " . ($_SERVER['HTTP_REFERER'] ?? 'cariler.php'));
    exit();
}

// CSRF token check
if (!isset($_GET['csrf_token']) || !csrf_token_dogrula($_GET['csrf_token'])) {
    $_SESSION['hata'] = "Geçersiz güvenlik tokeni!";
    header("Location: " . ($_SERVER['HTTP_REFERER'] ?? 'cariler.php'));
    exit();
}

try {
    $db->beginTransaction();

    // 1. Cari'ye ait hesap hareketi olup olmadığını kontrol et
    $stmt_check_hareket = $db->prepare("SELECT COUNT(*) as hareket_sayisi FROM hesap_hareketleri WHERE cari_id = :cari_id");
    $stmt_check_hareket->bindParam(':cari_id', $cari_id, PDO::PARAM_INT);
    $stmt_check_hareket->execute();
    $result = $stmt_check_hareket->fetch(PDO::FETCH_ASSOC);
    $hareket_sayisi = (int)$result['hareket_sayisi'];

    // 2. Cari bilgilerini al (ad_soyad gibi, mesaj için)
    $stmt_cari_info = $db->prepare("SELECT ad_soyad FROM cariler WHERE id = :cari_id");
    $stmt_cari_info->bindParam(':cari_id', $cari_id, PDO::PARAM_INT);
    $stmt_cari_info->execute();
    $cari_info = $stmt_cari_info->fetch(PDO::FETCH_ASSOC);
    $cari_ad_soyad = $cari_info ? htmlspecialchars($cari_info['ad_soyad'], ENT_QUOTES, 'UTF-8') : "Bilinmeyen Cari";

    if (!$cari_info) {
        throw new Exception("İşlem yapılacak cari bulunamadı.");
    }

    if ($hareket_sayisi > 0) {
        // Hesap hareketi varsa, cariyi pasif yap (aktif = 0)
        $stmt_pasiflestir = $db->prepare("UPDATE cariler SET aktif = 0 WHERE id = :cari_id");
        $stmt_pasiflestir->bindParam(':cari_id', $cari_id, PDO::PARAM_INT);
        if ($stmt_pasiflestir->execute()) {
            $_SESSION['mesaj'] = "Cari '{$cari_ad_soyad}' (ID: {$cari_id}) ilişkili hesap hareketleri bulunduğu için pasifleştirildi.";
        } else {
            throw new Exception("Cari pasifleştirilirken bir hata oluştu.");
        }
    } else {
        // Hesap hareketi yoksa, cariyi sil
        // Not: `borclar` tablosundaki ilişkili kayıtlar ON DELETE CASCADE ile silinecektir.
        // `hatirlaticilar` ve `hesap_hareketleri` (zaten yok) tablolarındaki cari_id ON DELETE SET NULL olacaktır.
        $stmt_sil_cari = $db->prepare("DELETE FROM cariler WHERE id = :cari_id");
        $stmt_sil_cari->bindParam(':cari_id', $cari_id, PDO::PARAM_INT);
        if ($stmt_sil_cari->execute()) {
            if ($stmt_sil_cari->rowCount() > 0) {
                 $_SESSION['mesaj'] = "Cari '{$cari_ad_soyad}' (ID: {$cari_id}) başarıyla silindi.";
            } else {
                 // Bu durum, cari_id'nin başta bulunamamasıyla aynı kapıya çıkar ama yine de bir kontrol.
                 throw new Exception("Silinecek cari bulunamadı veya zaten silinmiş.");
            }
        } else {
            throw new Exception("Cari silinirken bir hata oluştu.");
        }
    }

    $db->commit();

} catch (Exception $e) {
    if ($db->inTransaction()) {
        $db->rollBack();
    }
    error_log("Cari silme/pasifleştirme hatası (Cari ID: {$cari_id}): " . $e->getMessage());
    $_SESSION['hata'] = "Cari işlemi sırasında bir hata oluştu: " . htmlspecialchars($e->getMessage(), ENT_QUOTES, 'UTF-8');
}

// Kullanıcıyı yönlendir
header("Location: " . ($_SERVER['HTTP_REFERER'] ?? 'cariler.php')); // Varsayılan olarak cariler listesine yönlendir
exit();
?>
