<?php
require_once 'config.php';
yetkili_mi();

$sayfa_baslik = "Cari Yönetimi";

// Cari ekleme
if($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['cari_ekle'])) {
    if(!csrf_token_dogrula($_POST['csrf_token'] ?? '')) {
        $_SESSION['hata'] = "Geçersiz form gönderimi!";
        header("Location: cariler.php");
        exit();
    }

    $ad_soyad = temizle($_POST['ad_soyad']);
    $telefon = temizle($_POST['telefon']);
    $adres = temizle($_POST['adres']);
    $grup_id = filter_input(INPUT_POST, 'grup_id', FILTER_VALIDATE_INT);

     // Basit doğrulama
     $hatalar = [];
     if (empty($ad_soyad)) $hatalar[] = "Ad Soyad boş bırakılamaz.";
     if (empty($grup_id)) $hatalar[] = "Cari grubu seçilmelidir.";

    if (empty($hatalar)) {
        try {
            // Başlangıç bakiyeleri 0 olacak
            $stmt = $db->prepare("INSERT INTO cariler (ad_soyad, telefon, adres, grup_id, toplam_borc, toplam_alacak, bakiye, olusturulma_tarihi)
                                VALUES (?, ?, ?, ?, 0.00, 0.00, 0.00, NOW())");
            $stmt->execute([$ad_soyad, $telefon, $adres, $grup_id]);

            $_SESSION['mesaj'] = "Cari başarıyla eklendi.";
            header("Location: cariler.php");
            exit();
        } catch(PDOException $e) {
            error_log("Cari ekleme hatası: " . $e->getMessage());
             // Duplicate entry hatası kontrolü (ad_soyad unique değilse bu gereksiz)
            // if ($e->getCode() == 23000) { // Integrity constraint violation
            //     $_SESSION['hata'] = "Bu isimde bir cari zaten mevcut olabilir.";
            // } else {
                 $_SESSION['hata'] = "Cari eklenirken bir veritabanı hatası oluştu: " . $e->getMessage();
            // }
            $_SESSION['form_verileri_cari_ekle'] = $_POST; // Form verilerini sakla
            header("Location: cariler.php");
            exit();
        }
     } else {
         $_SESSION['form_hatalari_cari_ekle'] = $hatalar;
         $_SESSION['form_verileri_cari_ekle'] = $_POST;
         header("Location: cariler.php");
         exit();
     }
}

// Carileri listeleme
try {
    // Bakiye doğru hesaplanmış varsayılıyor, yoksa SUM ile hesaplamak gerekir
    $cariler = $db->query("
        SELECT c.*, g.grup_adi
        FROM cariler c
        LEFT JOIN cari_gruplari g ON c.grup_id = g.id
        ORDER BY c.ad_soyad
    ")->fetchAll(PDO::FETCH_ASSOC);

    $cari_gruplari = $db->query("SELECT * FROM cari_gruplari ORDER BY grup_adi")->fetchAll(PDO::FETCH_ASSOC);
} catch(PDOException $e) {
    error_log("Cari listeleme hatası: " . $e->getMessage());
     $_SESSION['hata'] = "Cari listesi alınırken bir hata oluştu.";
    $cariler = [];
    $cari_gruplari = [];
}

$csrf_token = csrf_token_olustur();
// Hataları ve form verilerini al (varsa)
$form_hatalari = $_SESSION['form_hatalari_cari_ekle'] ?? [];
$form_verileri = $_SESSION['form_verileri_cari_ekle'] ?? [];
unset($_SESSION['form_hatalari_cari_ekle'], $_SESSION['form_verileri_cari_ekle']);

?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= temizle($sayfa_baslik) ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container mt-4">
        <div class="d-flex justify-content-between align-items-center mb-3">
             <h2 class="mb-0"><i class="bi bi-people me-2"></i> <?= temizle($sayfa_baslik) ?></h2>
             <button class="btn btn-primary" type="button" data-bs-toggle="collapse" data-bs-target="#collapseCariEkle" aria-expanded="false" aria-controls="collapseCariEkle">
                <i class="bi bi-plus-circle me-1"></i> Yeni Cari Ekle
            </button>
        </div>
        <hr>

        <?php if (!empty($form_hatalari)): ?>
             <div class="alert alert-danger alert-dismissible fade show" role="alert">
                <strong><i class="bi bi-exclamation-triangle-fill me-2"></i> Lütfen hataları düzeltin:</strong>
                <ul>
                    <?php foreach ($form_hatalari as $hata): ?>
                        <li><?= htmlspecialchars($hata) ?></li>
                    <?php endforeach; ?>
                </ul>
                 <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <div class="collapse mb-4" id="collapseCariEkle">
            <div class="card card-body shadow-sm">
                 <h5 class="card-title mb-3"><i class="bi bi-person-plus me-2"></i>Yeni Cari Bilgileri</h5>
                 <form method="post">
                    <input type="hidden" name="csrf_token" value="<?= $csrf_token ?>">
                    <div class="row g-3">
                        <div class="col-md-6">
                            <label for="ad_soyad" class="form-label">Ad Soyad / Firma Adı <span class="text-danger">*</span></label>
                            <input type="text" class="form-control" id="ad_soyad" name="ad_soyad" required
                                    value="<?= htmlspecialchars($form_verileri['ad_soyad'] ?? '', ENT_QUOTES) ?>">
                        </div>
                        <div class="col-md-6">
                            <label for="telefon" class="form-label">Telefon</label>
                            <input type="tel" class="form-control" id="telefon" name="telefon"
                                    value="<?= htmlspecialchars($form_verileri['telefon'] ?? '', ENT_QUOTES) ?>">
                        </div>
                        <div class="col-md-6">
                            <label for="grup_id" class="form-label">Cari Grubu <span class="text-danger">*</span></label>
                            <select class="form-select" id="grup_id" name="grup_id" required>
                                <option value="">-- Grup Seçin --</option>
                                <?php foreach($cari_gruplari as $grup): ?>
                                    <option value="<?= $grup['id'] ?>" <?= (isset($form_verileri['grup_id']) && $form_verileri['grup_id'] == $grup['id']) ? 'selected' : '' ?>>
                                        <?= temizle($grup['grup_adi']) ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                         <div class="col-md-6">
                            <label for="adres" class="form-label">Adres</label>
                            <textarea class="form-control" id="adres" name="adres" rows="1"><?= htmlspecialchars($form_verileri['adres'] ?? '', ENT_QUOTES) ?></textarea>
                        </div>
                        <div class="col-12">
                             <button type="submit" name="cari_ekle" class="btn btn-success">
                                <i class="bi bi-save me-1"></i> Cariyi Kaydet
                            </button>
                             <button type="button" class="btn btn-secondary" data-bs-toggle="collapse" data-bs-target="#collapseCariEkle">İptal</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>

        <div class="card shadow-sm">
            <div class="card-header">
                <h5 class="mb-0"><i class="bi bi-list-ul me-2"></i> Cari Listesi</h5>
            </div>
            <div class="card-body p-0">
                <div class="table-responsive">
                    <table class="table table-hover table-striped mb-0"> <?php // Added table-striped ?>
                        <thead class="table-light">
                            <tr>
                                <th>Ad Soyad / Firma</th>
                                <th>Telefon</th>
                                <th>Grup</th>
                                <th class="text-end">Müşterinin Borcu</th> <?php // Bize olan borcu ?>
                                <th class="text-end">Bizim Borcumuz</th> <?php // Tedarikçiye ?>
                                <th class="text-end">Net Bakiye</th>
                                <th class="text-center">İşlemler</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($cariler)): ?>
                                <tr>
                                    <td colspan="7" class="text-center text-muted py-3">Henüz kayıtlı cari bulunmamaktadır.</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach($cariler as $cari):
                                    // Bakiye hesaplaması (DB'den geleni kullanıyoruz ama doğruluğu garanti değil)
                                    $bakiye = ($cari['toplam_alacak'] ?? 0.0) - ($cari['toplam_borc'] ?? 0.0);
                                ?>
                                <tr>
                                    <td><?= temizle($cari['ad_soyad']) ?></td>
                                    <td><?= temizle($cari['telefon']) ?: '-' ?></td>
                                    <td><span class="badge bg-secondary"><?= temizle($cari['grup_adi']) ?></span></td>
                                    <td class="text-end text-danger"><?= number_format($cari['toplam_borc'] ?? 0.0, 2, ',', '.') ?> ₺</td>
                                    <td class="text-end text-success"><?= number_format($cari['toplam_alacak'] ?? 0.0, 2, ',', '.') ?> ₺</td>
                                    <td class="text-end fw-bold <?= $bakiye >= 0 ? 'text-success' : 'text-danger' ?>">
                                        <?= number_format($bakiye, 2, ',', '.') ?> ₺
                                    </td>
                                    <td class="text-center">
                                        <a href="cari_detay.php?id=<?= $cari['id'] ?>" class="btn btn-sm btn-outline-primary" title="Detay/Ekstre"><i class="bi bi-eye"></i></a>
                                        <a href="cari_duzenle.php?id=<?= $cari['id'] ?>" class="btn btn-sm btn-outline-warning" title="Düzenle"><i class="bi bi-pencil"></i></a>
                                        <a href="cari_sil.php?id=<?= $cari['id'] ?>&csrf_token=<?= $csrf_token ?>"
                                           class="btn btn-sm btn-outline-danger" title="Sil"
                                           onclick="return confirm('Bu cariyi silmek istediğinize emin misiniz? Bu cariye ait TÜM işlemler (satış, alış, ödeme vb.) SİLİNMEZ ancak cari bilgisi kaybolur. Bu işlem önerilmez, bunun yerine cariyi pasif yapmayı düşünebilirsiniz. Yine de silmek istiyor musunuz?')">
                                            <i class="bi bi-trash"></i>
                                        </a>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>

	<?php include("footer.php"); ?>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>