<?php
// Veritabanı bağlantı bilgileri
$host = "localhost";
$dbname = "wp";
$username = "root";
$password = "";

// Hata raporlama
ini_set('display_errors', 0);
ini_set('log_errors', 1);
ini_set('error_log', __DIR__ . '/php_errors.log');
error_reporting(E_ALL);

// PDO bağlantısı
try {
    $db = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8mb4", $username, $password);
    $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    $db->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
    $db->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_ASSOC);
} catch(PDOException $e) {
    error_log("Veritabanı bağlantı hatası: " . $e->getMessage());
    die("Sistem şu anda kullanılamıyor. Lütfen daha sonra tekrar deneyin.");
}

// Oturum ayarları
session_name('ESNAF_YONETIM_SID');
session_set_cookie_params([
    'lifetime' => 86400,
    'path' => '/',
    'domain' => $_SERVER['HTTP_HOST'],
    'secure' => isset($_SERVER['HTTPS']),
    'httponly' => true,
    'samesite' => 'Strict'
]);

if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

// Güvenlik başlıkları
header("X-Frame-Options: DENY");
header("X-Content-Type-Options: nosniff");
header("Referrer-Policy: strict-origin-when-cross-origin");
header("Content-Security-Policy: default-src 'self'; script-src 'self' https://cdn.jsdelivr.net 'unsafe-inline'; style-src 'self' https://cdn.jsdelivr.net 'unsafe-inline'; font-src 'self' https://cdn.jsdelivr.net; img-src 'self' data:;");

// CSRF koruması
function csrf_token_olustur() {
    if(empty($_SESSION['csrf_token'])) {
        $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
    }
    return $_SESSION['csrf_token'];
}

function csrf_token_dogrula($token) {
    if (empty($token) || empty($_SESSION['csrf_token'])) {
        return false;
    }
    return hash_equals($_SESSION['csrf_token'], $token);
}

// Yetki kontrolü
function yetkili_mi() {
    if(!isset($_SESSION['kullanici_id'])) {
        $_SESSION['login_redirect'] = $_SERVER['REQUEST_URI'];
        header("Location: login.php");
        exit();
    }

    if(isset($_SESSION['login_time']) && (time() - $_SESSION['login_time'] > 86400)) {
        session_unset();
        session_destroy();
        header("Location: login.php?timeout=1");
        exit();
    }
    $_SESSION['login_time'] = time();

    if(!isset($_SESSION['user_agent'])) {
        $_SESSION['user_agent'] = $_SERVER['HTTP_USER_AGENT'] ?? 'unknown';
    } elseif($_SESSION['user_agent'] !== ($_SERVER['HTTP_USER_AGENT'] ?? 'unknown')) {
        session_unset();
        session_destroy();
        header("Location: login.php?hacking=1");
        exit();
    }

    if (!isset($_SESSION['last_regen']) || time() - $_SESSION['last_regen'] > 1800) {
        session_regenerate_id(true);
        $_SESSION['last_regen'] = time();
    }
}

// Veri temizleme fonksiyonları
function temizle($data) {
    if(is_array($data)) {
        return array_map('temizle', $data);
    }
    return htmlspecialchars(trim((string)$data), ENT_QUOTES | ENT_SUBSTITUTE, 'UTF-8');
}

function tamsayi($value) {
    return filter_var($value, FILTER_VALIDATE_INT);
}

function ondalik($value) {
    $value = str_replace(',', '.', (string)$value);
    return filter_var($value, FILTER_VALIDATE_FLOAT);
}

// Brute-force koruması
function brute_force_kontrol() {
    $max_deneme = 5;
    $bekleme_suresi = 300;

    if (!isset($_SESSION['login_attempts'])) {
        $_SESSION['login_attempts'] = 0;
    }
    if (!isset($_SESSION['last_attempt_time'])) {
        $_SESSION['last_attempt_time'] = 0;
    }

    if($_SESSION['login_attempts'] >= $max_deneme) {
        if(time() - $_SESSION['last_attempt_time'] < $bekleme_suresi) {
            $kalan_sure = $bekleme_suresi - (time() - $_SESSION['last_attempt_time']);
            $_SESSION['hata'] = "Çok fazla hatalı giriş denemesi. Lütfen " . ceil($kalan_sure/60) . " dakika sonra tekrar deneyin.";
            return false;
        } else {
            $_SESSION['login_attempts'] = 0;
            unset($_SESSION['last_attempt_time']);
        }
    }
    return true;
}

function brute_force_log_attempt() {
    if (!isset($_SESSION['login_attempts'])) {
        $_SESSION['login_attempts'] = 0;
    }
    $_SESSION['login_attempts']++;
    $_SESSION['last_attempt_time'] = time();
}

function brute_force_reset() {
    unset($_SESSION['login_attempts']);
    unset($_SESSION['last_attempt_time']);
}

// Yardımcı Fonksiyonlar
function hesapBakiyeGuncelle(PDO $db, int $hesap_id, float $degisim): bool {
    try {
        $stmt = $db->prepare("UPDATE hesaplar SET bakiye = bakiye + :degisim WHERE id = :hesap_id");
        $stmt->bindParam(':degisim', $degisim, PDO::PARAM_STR);
        $stmt->bindParam(':hesap_id', $hesap_id, PDO::PARAM_INT);
        return $stmt->execute();
    } catch (PDOException $e) {
        error_log("Hesap Bakiye Güncelleme Hatası (Hesap ID: {$hesap_id}): " . $e->getMessage());
        return false;
    }
}

function cariBakiyeGuncelle(PDO $db, int $cari_id, float $borc_degisim = 0.0, float $alacak_degisim = 0.0): bool {
    try {
        $sql = "UPDATE cariler SET
                    toplam_borc = toplam_borc + :borc_degisim,
                    toplam_alacak = toplam_alacak + :alacak_degisim,
                    bakiye = (toplam_alacak + :alacak_degisim_tekrar) - (toplam_borc + :borc_degisim_tekrar)
                WHERE id = :cari_id";

        $stmt = $db->prepare($sql);
        $params = [
            ':borc_degisim' => $borc_degisim,
            ':alacak_degisim' => $alacak_degisim,
            ':borc_degisim_tekrar' => $borc_degisim,
            ':alacak_degisim_tekrar' => $alacak_degisim,
            ':cari_id' => $cari_id
        ];
        return $stmt->execute($params);
    } catch (PDOException $e) {
        error_log("Cari Bakiye Güncelleme Hatası (Cari ID: {$cari_id}) - Hata: " . $e->getMessage());
        return false;
    }
}

function hesapHareketiEkle(PDO $db, int $hesap_id, string $tur, float $tutar, string $aciklama, ?int $cari_id = null, ?int $borc_id = null, ?int $baglanti_id = null): bool {
    try {
        $sql = "INSERT INTO hesap_hareketleri (hesap_id, tur, tutar, aciklama, cari_id, borc_id, baglanti_id, tarih)
                VALUES (:hesap_id, :tur, :tutar, :aciklama, :cari_id, :borc_id, :baglanti_id, NOW())";
        $stmt = $db->prepare($sql);
        $stmt->bindParam(':hesap_id', $hesap_id, PDO::PARAM_INT);
        $stmt->bindParam(':tur', $tur, PDO::PARAM_STR);
        $stmt->bindParam(':tutar', $tutar, PDO::PARAM_STR);
        $stmt->bindParam(':aciklama', $aciklama, PDO::PARAM_STR);
        $stmt->bindParam(':cari_id', $cari_id, PDO::PARAM_INT);
        $stmt->bindParam(':borc_id', $borc_id, PDO::PARAM_INT);
        $stmt->bindParam(':baglanti_id', $baglanti_id, PDO::PARAM_INT);
        return $stmt->execute();
    } catch (PDOException $e) {
        error_log("Hesap Hareketi Ekleme Hatası (Hesap ID: {$hesap_id}, Tutar: {$tutar}): " . $e->getMessage());
        return false;
    }
}

// KURULUM TAMAMLANDI - Bu satırı silmeyin!
define('KURULUM_TAMAMLANDI', true);
?>