<?php
require_once 'config.php';
// yetkili_mi(); // Kullanıcı yetkilendirme kontrolü istemedi.

if (!isset($_GET['id']) || !($hareket_id = filter_input(INPUT_GET, 'id', FILTER_VALIDATE_INT))) {
    $_SESSION['hata'] = "Geçersiz Hesap Hareketi ID.";
    header("Location: " . ($_SERVER['HTTP_REFERER'] ?? 'hesap_hareketleri.php'));
    exit();
}

// CSRF token check - borc_sil.php gibi GET parametresi olarak varsayılıyor
if (!isset($_GET['csrf_token']) || !csrf_token_dogrula($_GET['csrf_token'])) {
    $_SESSION['hata'] = "Geçersiz güvenlik tokeni!";
    header("Location: " . ($_SERVER['HTTP_REFERER'] ?? 'hesap_hareketleri.php'));
    exit();
}

try {
    $db->beginTransaction();

    // 1. Silinecek hesap hareketinin detaylarını al
    $stmt_hareket_detay = $db->prepare("SELECT hesap_id, cari_id, tur, tutar, borc_id FROM hesap_hareketleri WHERE id = :hareket_id");
    $stmt_hareket_detay->bindParam(':hareket_id', $hareket_id, PDO::PARAM_INT);
    $stmt_hareket_detay->execute();
    $hareket = $stmt_hareket_detay->fetch(PDO::FETCH_ASSOC);

    if (!$hareket) {
        throw new Exception("Silinecek hesap hareketi bulunamadı!");
    }

    $hesap_id = (int)$hareket['hesap_id'];
    $cari_id = $hareket['cari_id'] ? (int)$hareket['cari_id'] : null;
    $tur = $hareket['tur'];
    $tutar = (float)$hareket['tutar'];
    // $borc_id = $hareket['borc_id']; // borclar tablosunu güncellemek gerekirse kullanılabilir

    // 2. Hesap bakiyesini güncelle (hesaplar.bakiye)
    $hesap_degisim = 0.0;
    if ($tur == 'giris') { // Eğer bir gelir/mevduat ise, silinmesi bakiyeyi azaltır
        $hesap_degisim = -$tutar;
    } elseif ($tur == 'cikis') { // Eğer bir gider/çekim ise, silinmesi bakiyeyi artırır
        $hesap_degisim = +$tutar;
    }
    // 'transfer' veya diğer türler için özel işlem gerekirse buraya eklenebilir.

    if ($hesap_degisim != 0.0) {
        if (!hesapBakiyeGuncelle($db, $hesap_id, $hesap_degisim)) {
            throw new Exception("Hesap bakiyesi güncellenirken bir hata oluştu.");
        }
    }

    // 3. Cari bakiyesini güncelle (cariler.bakiye) eğer bir cari ilişkiliyse
    if ($cari_id) {
        $cari_borc_degisim = 0.0;
        $cari_alacak_degisim = 0.0;

        if ($tur == 'giris') {
            // Bu 'giris' muhtemelen cariden yapılan bir ödeme (tahsilat).
            // Silinmesi, cari'nin bize olan borcunu artırır.
            $cari_borc_degisim = +$tutar;
        } elseif ($tur == 'cikis') {
            // Bu 'cikis' muhtemelen cariye yapılan bir ödeme.
            // Silinmesi, bizim cariye olan borcumuzu artırır.
            $cari_alacak_degisim = +$tutar;
        }

        if (($cari_borc_degisim != 0.0 || $cari_alacak_degisim != 0.0)) {
            if (!cariBakiyeGuncelle($db, $cari_id, $cari_borc_degisim, $cari_alacak_degisim)) {
                throw new Exception("Cari bakiyesi güncellenirken bir hata oluştu.");
            }
        }
    }

    // 4. Hesap hareketi kaydını sil
    $stmt_sil_hareket = $db->prepare("DELETE FROM hesap_hareketleri WHERE id = :hareket_id");
    $stmt_sil_hareket->bindParam(':hareket_id', $hareket_id, PDO::PARAM_INT);
    if (!$stmt_sil_hareket->execute()) {
        throw new Exception("Hesap hareketi silinirken bir hata oluştu.");
    }

    $db->commit();
    $_SESSION['mesaj'] = "Hesap hareketi (#{$hareket_id}) başarıyla silindi. İlgili bakiyeler güncellendi.";

} catch (Exception $e) {
    if ($db->inTransaction()) {
        $db->rollBack();
    }
    error_log("Hesap hareketi silme hatası (ID: {$hareket_id}): " . $e->getMessage());
    $_SESSION['hata'] = "Hesap hareketi silme işlemi sırasında bir hata oluştu: " . htmlspecialchars($e->getMessage(), ENT_QUOTES, 'UTF-8');
}

// Kullanıcıyı yönlendir
header("Location: " . ($_SERVER['HTTP_REFERER'] ?? 'hesap_hareketleri.php')); // Varsayılan olarak hesap hareketleri listesine yönlendir
exit();
?>
