<?php
require_once 'config.php';
yetkili_mi();

$sayfa_baslik = "Hesap Hareketleri";

// FİLTRELEME PARAMETRELERİ
$filtre_hesap_id = filter_input(INPUT_GET, 'hesap_id', FILTER_VALIDATE_INT);
$filtre_cari_id = filter_input(INPUT_GET, 'cari_id', FILTER_VALIDATE_INT);
$filtre_baslangic = filter_input(INPUT_GET, 'baslangic', FILTER_SANITIZE_SPECIAL_CHARS);
$filtre_bitis = filter_input(INPUT_GET, 'bitis', FILTER_SANITIZE_SPECIAL_CHARS);
$filtre_tur = filter_input(INPUT_GET, 'tur', FILTER_SANITIZE_SPECIAL_CHARS); // giris, cikis, transfer

// Tarihleri doğrula veya varsayılan ata
if (!$filtre_baslangic || !preg_match("/^\d{4}-\d{2}-\d{2}$/", $filtre_baslangic)) {
    $filtre_baslangic = date('Y-m-01'); // Ay başı
}
if (!$filtre_bitis || !preg_match("/^\d{4}-\d{2}-\d{2}$/", $filtre_bitis)) {
    $filtre_bitis = date('Y-m-d'); // Bugün
}

// Diğer filtreleri temizle
$filtre_hesap_id = $filtre_hesap_id ?: null; // Boşsa null yap
$filtre_cari_id = $filtre_cari_id ?: null;
$filtre_tur = in_array($filtre_tur, ['giris', 'cikis', 'transfer']) ? $filtre_tur : null;

// Verileri Çekme
try {
    // Filtreler için WHERE koşullarını ve parametreleri oluştur
    $where_clauses = ["hh.tarih BETWEEN :baslangic AND DATE_ADD(:bitis, INTERVAL 1 DAY)"]; // Bitiş tarihini de dahil etmek için
    $params = [
        ':baslangic' => $filtre_baslangic,
        ':bitis' => $filtre_bitis
    ];

    if ($filtre_hesap_id) {
        $where_clauses[] = "hh.hesap_id = :hesap_id";
        $params[':hesap_id'] = $filtre_hesap_id;
    }
    if ($filtre_cari_id) {
        $where_clauses[] = "hh.cari_id = :cari_id";
        $params[':cari_id'] = $filtre_cari_id;
    }
     if ($filtre_tur) {
        $where_clauses[] = "hh.tur = :tur";
        $params[':tur'] = $filtre_tur;
    }

    $where_sql = implode(' AND ', $where_clauses);

    // Ana Sorgu
    $sql = "SELECT hh.*, h.hesap_adi, c.ad_soyad as cari_ad_soyad,
                   b.tur as borc_tur, b.aciklama as borc_aciklama, b.id as borc_kayit_id,
                   h_transfer.hesap_adi as transfer_hedef_hesap
            FROM hesap_hareketleri hh
            LEFT JOIN hesaplar h ON hh.hesap_id = h.id
            LEFT JOIN cariler c ON hh.cari_id = c.id
            LEFT JOIN borclar b ON hh.borc_id = b.id
            LEFT JOIN hesap_hareketleri hh_transfer ON (hh.tur = 'transfer' AND hh.baglanti_id = hh_transfer.id) -- Transferin diğer ayağını bul
            LEFT JOIN hesaplar h_transfer ON hh_transfer.hesap_id = h_transfer.id -- Diğer ayağın hesabını bul
            WHERE $where_sql
            ORDER BY hh.tarih DESC, hh.id DESC";

    $stmt = $db->prepare($sql);
    $stmt->execute($params);
    $hareketler = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Filtreleme formları için hesapları ve carileri al
    $hesaplar = $db->query("SELECT id, hesap_adi FROM hesaplar ORDER BY hesap_adi")->fetchAll();
    $cariler = $db->query("SELECT id, ad_soyad FROM cariler ORDER BY ad_soyad")->fetchAll();

} catch(PDOException $e) {
    error_log("Hesap Hareketleri Hatası: ".$e->getMessage());
    $_SESSION['hata'] = "Hesap hareketleri alınırken bir hata oluştu.";
    $hareketler = [];
    $hesaplar = [];
    $cariler = [];
}

$csrf_token = csrf_token_olustur(); // Gerekirse silme vb. işlemler için
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= temizle($sayfa_baslik) ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container mt-4">
        <div class="d-flex justify-content-between align-items-center mb-3">
            <h2 class="mb-0"><i class="bi bi-list-ol me-2"></i> <?= temizle($sayfa_baslik) ?></h2>
            <a href="pdf_export.php?type=hesap_hareketleri&hesap_id=<?= $filtre_hesap_id ?>&cari_id=<?= $filtre_cari_id ?>&baslangic=<?= $filtre_baslangic ?>&bitis=<?= $filtre_bitis ?>&tur=<?= $filtre_tur ?>" class="btn btn-sm btn-outline-primary">
                <i class="bi bi-file-pdf"></i> PDF İndir
            </a>
        </div>
        <hr>

        <div class="card shadow-sm mb-4">
             <div class="card-header">
                 <a class="text-decoration-none" data-bs-toggle="collapse" href="#collapseFilter" role="button" aria-expanded="false" aria-controls="collapseFilter">
                    <i class="bi bi-funnel me-2"></i> Filtrele
                </a>
             </div>
            <div class="collapse" id="collapseFilter">
                <div class="card-body">
                    <form method="GET" class="row g-3">
                        <div class="col-md-3">
                            <label for="baslangic" class="form-label">Başlangıç Tarihi</label>
                            <input type="date" id="baslangic" name="baslangic" class="form-control form-control-sm" value="<?= htmlspecialchars($filtre_baslangic) ?>">
                        </div>
                        <div class="col-md-3">
                            <label for="bitis" class="form-label">Bitiş Tarihi</label>
                            <input type="date" id="bitis" name="bitis" class="form-control form-control-sm" value="<?= htmlspecialchars($filtre_bitis) ?>">
                        </div>
                        <div class="col-md-3">
                            <label for="hesap_id" class="form-label">Hesap</label>
                            <select id="hesap_id" name="hesap_id" class="form-select form-select-sm">
                                <option value="">Tüm Hesaplar</option>
                                <?php foreach($hesaplar as $hesap): ?>
                                <option value="<?= $hesap['id'] ?>" <?= ($filtre_hesap_id == $hesap['id']) ? 'selected' : '' ?>>
                                    <?= temizle($hesap['hesap_adi']) ?>
                                </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                         <div class="col-md-3">
                            <label for="cari_id" class="form-label">Cari</label>
                            <select id="cari_id" name="cari_id" class="form-select form-select-sm">
                                <option value="">Tüm Cariler</option>
                                <?php foreach($cariler as $cari): ?>
                                <option value="<?= $cari['id'] ?>" <?= ($filtre_cari_id == $cari['id']) ? 'selected' : '' ?>>
                                    <?= temizle($cari['ad_soyad']) ?>
                                </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                         <div class="col-md-3">
                            <label for="tur" class="form-label">Hareket Türü</label>
                            <select id="tur" name="tur" class="form-select form-select-sm">
                                <option value="">Tüm Türler</option>
                                <option value="giris" <?= ($filtre_tur == 'giris') ? 'selected' : '' ?>>Giriş (Tahsilat vb.)</option>
                                <option value="cikis" <?= ($filtre_tur == 'cikis') ? 'selected' : '' ?>>Çıkış (Ödeme vb.)</option>
                                <option value="transfer" <?= ($filtre_tur == 'transfer') ? 'selected' : '' ?>>Transfer</option>
                            </select>
                        </div>
                        <div class="col-md-9 d-flex align-items-end">
                            <button type="submit" class="btn btn-primary btn-sm me-2">
                                <i class="bi bi-filter"></i> Filtrele
                            </button>
                             <a href="hesap_hareketleri.php" class="btn btn-secondary btn-sm">
                                <i class="bi bi-x-lg"></i> Filtreyi Temizle
                             </a>
                        </div>
                    </form>
                </div>
            </div>
        </div>

        <div class="card shadow-sm">
             <div class="card-body p-0">
                <div class="table-responsive">
                    <table class="table table-hover table-striped mb-0"> <?php // table-striped eklendi ?>
                        <thead class="table-light">
                            <tr>
                                <th>Tarih</th>
                                <th>Hesap</th>
                                <th>Tür</th>
                                <th>Tutar</th>
                                <th>Cari</th>
                                <th>Açıklama</th>
                                <th>İlişkili İşlem</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($hareketler)): ?>
                                <tr>
                                    <td colspan="7" class="text-center text-muted py-4">Seçili kriterlere uygun hesap hareketi bulunamadı.</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach($hareketler as $hareket): ?>
                                <tr>
                                    <td><small><?= date('d.m.Y H:i', strtotime($hareket['tarih'])) ?></small></td>
                                    <td><?= temizle($hareket['hesap_adi']) ?></td>
                                    <td>
                                        <?php if ($hareket['tur'] == 'giris'): ?>
                                            <span class="badge bg-success">Giriş</span>
                                        <?php elseif ($hareket['tur'] == 'cikis'): ?>
                                            <span class="badge bg-danger">Çıkış</span>
                                         <?php elseif ($hareket['tur'] == 'transfer'): ?>
                                            <span class="badge bg-info">Transfer</span>
                                        <?php endif; ?>
                                    </td>
                                    <td class="text-end fw-bold <?= $hareket['tur'] == 'giris' ? 'text-success' : ($hareket['tur'] == 'cikis' ? 'text-danger' : 'text-info') ?>">
                                        <?= $hareket['tur'] == 'giris' ? '+' : ($hareket['tur'] == 'cikis' ? '-' : '') ?>
                                        <?= number_format($hareket['tutar'], 2, ',', '.') ?> ₺
                                    </td>
                                    <td><?= $hareket['cari_ad_soyad'] ? temizle($hareket['cari_ad_soyad']) : '-' ?></td>
                                    <td>
                                        <?= temizle($hareket['aciklama']) ?>
                                        <?php if($hareket['tur'] == 'transfer' && $hareket['transfer_hedef_hesap']): ?>
                                             <small class="text-muted d-block">(Hedef: <?= temizle($hareket['transfer_hedef_hesap']) ?>)</small>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <?php if ($hareket['borc_id']): ?>
                                        <a href="borc_detay.php?id=<?= $hareket['borc_id'] ?>" class="btn btn-xs btn-outline-secondary" title="İlişkili İşlemi Gör">
                                             <?= ucfirst($hareket['borc_tur']) ?> #<?= $hareket['borc_id'] ?>
                                        </a>
                                        <?php else: echo '-'; endif; ?>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
	<?php include("footer.php"); ?>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>