<?php
require_once 'config.php';
yetkili_mi();

$sayfa_baslik = "Hesap Yönetimi";

// HESAP EKLEME
if($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['hesap_ekle'])) {
    if(!csrf_token_dogrula($_POST['csrf_token'])) {
        die("Geçersiz CSRF token!");
    }
    
    $hesap_adi = temizle($_POST['hesap_adi']);
    $hesap_turu = temizle($_POST['hesap_turu']);
    $aciklama = temizle($_POST['aciklama']);
    
    try {
        $db->beginTransaction();
        
        $stmt = $db->prepare("INSERT INTO hesaplar (hesap_adi, hesap_turu, aciklama) VALUES (?, ?, ?)");
        $stmt->execute([$hesap_adi, $hesap_turu, $aciklama]);
        
        $db->commit();
        $_SESSION['mesaj'] = "Hesap başarıyla eklendi!";
    } catch(PDOException $e) {
        $db->rollBack();
        $_SESSION['hata'] = "Hesap ekleme hatası: ".$e->getMessage();
    }
    header("Location: hesaplar.php"); exit();
}

// HESAP SİLME
if(isset($_GET['sil'])) {
    $id = (int)$_GET['sil'];
    
    try {
        $db->beginTransaction();
        
        // Hesapta bakiye kontrolü
        $bakiye = $db->query("SELECT bakiye FROM hesaplar WHERE id = $id")->fetchColumn();
        if($bakiye != 0) {
            $_SESSION['hata'] = "Hesap silinemez! Bakiye sıfır olmalı.";
            header("Location: hesaplar.php"); exit();
        }
        
        $db->exec("DELETE FROM hesaplar WHERE id = $id");
        $db->commit();
        $_SESSION['mesaj'] = "Hesap silindi!";
    } catch(PDOException $e) {
        $db->rollBack();
        $_SESSION['hata'] = "Silme hatası: ".$e->getMessage();
    }
    header("Location: hesaplar.php"); exit();
}

// HESAPLARI LİSTELE
try {
    $hesaplar = $db->query("SELECT * FROM hesaplar ORDER BY hesap_adi")->fetchAll(PDO::FETCH_ASSOC);
} catch(PDOException $e) {
    die("Hata: ".$e->getMessage());
}

$csrf_token = csrf_token_olustur();
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= $sayfa_baslik ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container-xl mt-4">
        <div class="row mb-4">
            <div class="col-md-12">
                <h2><i class="bi bi-wallet2"></i> <?= $sayfa_baslik ?></h2>
                <hr>
            </div>
        </div>

        <?php if(isset($_SESSION['mesaj'])): ?>
            <div class="alert alert-success"><?= $_SESSION['mesaj'] ?></div>
            <?php unset($_SESSION['mesaj']); ?>
        <?php endif; ?>
        
        <?php if(isset($_SESSION['hata'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['hata'] ?></div>
            <?php unset($_SESSION['hata']); ?>
        <?php endif; ?>

        <div class="row">
            <div class="col-md-4 mb-4">
                <div class="card shadow">
                    <div class="card-header bg-primary text-white">
                        <h5 class="mb-0"><i class="bi bi-plus-circle"></i> Yeni Hesap Ekle</h5>
                    </div>
                    <div class="card-body">
                        <form method="post">
                            <input type="hidden" name="csrf_token" value="<?= $csrf_token ?>">
                            
                            <div class="mb-3">
                                <label class="form-label">Hesap Adı</label>
                                <input type="text" name="hesap_adi" class="form-control" required>
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">Hesap Türü</label>
                                <select name="hesap_turu" class="form-select" required>
                                    <option value="banka">Banka</option>
                                    <option value="kasa">Kasa</option>
                                    <option value="kredi_karti">Kredi Kartı</option>
                                </select>
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">Açıklama</label>
                                <textarea name="aciklama" class="form-control" rows="2"></textarea>
                            </div>
                            
                            <button type="submit" name="hesap_ekle" class="btn btn-success w-100">
                                <i class="bi bi-save"></i> Hesap Ekle
                            </button>
                        </form>
                    </div>
                </div>
            </div>

            <div class="col-md-8">
                <div class="card shadow">
                    <div class="card-header bg-secondary text-white">
                        <h5 class="mb-0"><i class="bi bi-list-task"></i> Hesap Listesi</h5>
                    </div>
                    <div class="card-body p-0">
                        <div class="table-responsive">
                            <table class="table table-hover mb-0">
                                <thead class="table-light">
                                    <tr>
                                        <th>Hesap Adı</th>
                                        <th>Tür</th>
                                        <th class="text-end">Bakiye</th>
                                        <th>İşlemler</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach($hesaplar as $hesap): ?>
                                    <tr>
                                        <td><?= temizle($hesap['hesap_adi']) ?></td>
                                        <td><?= ucfirst(str_replace('_', ' ', $hesap['hesap_turu'])) ?></td>
                                        <td class="text-end <?= $hesap['bakiye'] >=0 ? 'text-success' : 'text-danger' ?>">
                                            <?= number_format($hesap['bakiye'], 2) ?> ₺
                                        </td>
                                        <td>
                                            <a href="hesap_duzenle.php?id=<?= $hesap['id'] ?>" class="btn btn-sm btn-warning">
                                                <i class="bi bi-pencil"></i>
                                            </a>
                                            <a href="hesaplar.php?sil=<?= $hesap['id'] ?>" 
                                               class="btn btn-sm btn-danger" 
                                               onclick="return confirm('Bu hesabı silmek istediğinize emin misiniz?')">
                                                <i class="bi bi-trash"></i>
                                            </a>
											<a href="hesap_hareketleri.php?hesap_id=<?= $hesap['id'] ?>" class="btn btn-sm btn-info" title="Detay">
                                                <i class="bi bi-eye"></i>
                                            </a>
											
                                        </td>
                                    </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
	<?php include("footer.php"); ?>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>