<?php
require_once 'config.php';
yetkili_mi();

$sayfa_baslik = "Ana Panel";

// İSTATİSTİKLER
try {
    // GENEL CARİ VERİLERİ
    $toplam_cari = $db->query("SELECT COUNT(*) FROM cariler")->fetchColumn();
    // Müşterilerin bize borcu (toplam_borc sütunundan)
    $toplam_musteri_borcu = $db->query("SELECT SUM(toplam_borc) FROM cariler")->fetchColumn() ?: 0.0;
    // Bizim tedarikçilere borcumuz (toplam_alacak sütunundan)
    $toplam_tedarikci_alacagi = $db->query("SELECT SUM(toplam_alacak) FROM cariler")->fetchColumn() ?: 0.0;
    // Net Bakiye (Bizim alacaklarımız - Bizim borçlarımız)
    // Dikkat: Bu, carilerin bakiyelerinin toplamıdır. Kasa/Banka hariç durumu gösterir.
    $net_cari_bakiye = $toplam_tedarikci_alacagi - $toplam_musteri_borcu; // Alacaklarımız (+) , Borçlarımız (-) gibi düşünülürse bakiye = alacak - borc


    // HESAP ÖZETLERİ
    $hesap_bakiyeleri = $db->query("
        SELECT id, hesap_adi, hesap_turu, bakiye
        FROM hesaplar
        ORDER BY hesap_adi ASC
    ")->fetchAll(PDO::FETCH_ASSOC);
    $toplam_hesap_bakiye = $db->query("SELECT SUM(bakiye) FROM hesaplar")->fetchColumn() ?: 0.0;

    // SON HAREKETLER (Hesap Hareketleri)
    $son_hesap_hareketleri = $db->query("
        SELECT hh.*, c.ad_soyad, h.hesap_adi, b.tur as borc_tur, b.aciklama as borc_aciklama
        FROM hesap_hareketleri hh
        LEFT JOIN cariler c ON hh.cari_id = c.id
        LEFT JOIN hesaplar h ON hh.hesap_id = h.id
        LEFT JOIN borclar b ON hh.borc_id = b.id -- İlişkili işlemi de alalım
        ORDER BY hh.tarih DESC, hh.id DESC
        LIMIT 10
    ")->fetchAll(PDO::FETCH_ASSOC);

   // VADESİ YAKLAŞAN / GEÇMİŞ BORÇLAR (Müşterilerden Alacaklar - Ödenmemiş)
$vadesi_gelen_satislar = $db->query("
    SELECT b.id, b.cari_id, b.tutar, b.odenen_tutar, b.vade_tarihi, b.aciklama as borc_aciklama, c.ad_soyad,
           DATEDIFF(b.vade_tarihi, CURDATE()) as kalan_gun
    FROM borclar b
    JOIN cariler c ON b.cari_id = c.id
    WHERE b.tur = 'satis'
      AND b.durum != 'odendi' -- Sadece ödenmemiş veya kısmen ödenmişler
      AND b.vade_tarihi IS NOT NULL
    ORDER BY b.vade_tarihi ASC
    LIMIT 7
")->fetchAll(PDO::FETCH_ASSOC);

 // VADESİ YAKLAŞAN / GEÇMİŞ ÖDEMELER (Tedarikçilere Borçlar - Ödenmemiş)
 $vadesi_gelen_alislar = $db->query("
    SELECT b.id, b.cari_id, b.tutar, b.odenen_tutar, b.vade_tarihi, b.aciklama as borc_aciklama, c.ad_soyad,
           DATEDIFF(b.vade_tarihi, CURDATE()) as kalan_gun
    FROM borclar b
    JOIN cariler c ON b.cari_id = c.id
    WHERE b.tur = 'alis'
      AND b.durum != 'odendi' -- Sadece ödenmemiş veya kısmen ödenmişler
      AND b.vade_tarihi IS NOT NULL
    ORDER BY b.vade_tarihi ASC
    LIMIT 7
")->fetchAll(PDO::FETCH_ASSOC);


} catch(PDOException $e) {
     error_log("Ana Panel İstatistik Hatası: ".$e->getMessage());
     $_SESSION['hata'] = "Ana panel verileri yüklenirken bir hata oluştu.";
     // Hata durumunda varsayılan değerler
     $toplam_cari = 0;
     $toplam_musteri_borcu = 0.0;
     $toplam_tedarikci_alacagi = 0.0;
     $net_cari_bakiye = 0.0;
     $hesap_bakiyeleri = [];
     $toplam_hesap_bakiye = 0.0;
     $son_hesap_hareketleri = [];
     $vadesi_gelen_satislar = [];
     $vadesi_gelen_alislar = [];
}
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= temizle($sayfa_baslik) ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <style>
        .stat-card { border: none; border-radius: 0.5rem; box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075); transition: transform 0.2s ease-in-out; }
        .stat-card:hover { transform: translateY(-3px); box-shadow: 0 0.5rem 1rem rgba(0, 0, 0, 0.15); }
        .bakiye-pozitif { color: #198754; }
        .bakiye-negatif { color: #dc3545; }
        .vade-gecmis { background-color: rgba(220, 53, 69, 0.1); }
        .vade-yaklasiyor { background-color: rgba(255, 193, 7, 0.1); }
        .list-group-item-action:hover { background-color: #f8f9fa; }
        
        /* Mobil uyumluluk iyileştirmeleri */
        @media (max-width: 768px) {
            .table-responsive { font-size: 0.85rem; }
            .stat-card h4 { font-size: 1.2rem; }
            .card-title { font-size: 1rem; }
            .container { padding-left: 10px; padding-right: 10px; }
        }
    </style>
</head>
<body style="background-color: #f4f7f6;"> <?php // Hafif arka plan rengi ?>
    <?php include 'navbar.php'; ?>

    <div class="container mt-4">
        <div class="row g-4 mb-4">
            <div class="col-lg-3 col-md-6">
                 <div class="card stat-card h-100">
                    <div class="card-body text-center">
                         <i class="bi bi-people-fill fs-1 text-primary mb-2 d-block"></i>
                         <h6 class="card-subtitle mb-2 text-muted">Toplam Cari</h6>
                         <h4 class="card-title"><?= number_format($toplam_cari) ?></h4>
                    </div>
                </div>
            </div>
            <div class="col-lg-3 col-md-6">
                <div class="card stat-card h-100">
                    <div class="card-body text-center">
                         <i class="bi bi-arrow-down-left-circle-fill fs-1 text-danger mb-2 d-block"></i>
                         <h6 class="card-subtitle mb-2 text-muted">Müşterilerin Borcu</h6>
                         <h4 class="card-title bakiye-negatif"><?= number_format($toplam_musteri_borcu, 2, ',', '.') ?> ₺</h4>
                    </div>
                </div>
            </div>
            <div class="col-lg-3 col-md-6">
                 <div class="card stat-card h-100">
                    <div class="card-body text-center">
                         <i class="bi bi-arrow-up-right-circle-fill fs-1 text-success mb-2 d-block"></i>
                         <h6 class="card-subtitle mb-2 text-muted">Bizim Borcumuz</h6>
                         <h4 class="card-title bakiye-pozitif"><?= number_format($toplam_tedarikci_alacagi, 2, ',', '.') ?> ₺</h4>
                    </div>
                </div>
            </div>
            <div class="col-lg-3 col-md-6">
                 <div class="card stat-card h-100">
                    <div class="card-body text-center">
                         <i class="bi bi-bank fs-1 text-info mb-2 d-block"></i>
                         <h6 class="card-subtitle mb-2 text-muted">Toplam Hesap Bakiyesi</h6>
                         <h4 class="card-title <?= $toplam_hesap_bakiye >= 0 ? 'bakiye-pozitif' : 'bakiye-negatif' ?>">
                            <?= number_format($toplam_hesap_bakiye, 2, ',', '.') ?> ₺
                         </h4>
                    </div>
                </div>
            </div>
        </div>
        


        <div class="row g-4">
            <div class="col-lg-7">
                 <div class="card shadow-sm mb-4">
                    <div class="card-header bg-light">
                        <h5 class="mb-0"><i class="bi bi-wallet2 me-2 text-primary"></i>Hesap Bakiyeleri</h5>
                    </div>
                    <div class="card-body">
                         <?php if (empty($hesap_bakiyeleri)): ?>
                             <p class="text-muted">Henüz hesap eklenmemiş.</p>
                         <?php else: ?>
                             <ul class="list-group list-group-flush">
                                <?php foreach($hesap_bakiyeleri as $hesap): ?>
                                <li class="list-group-item d-flex justify-content-between align-items-center">
                                    <div>
                                        <i class="bi bi-<?= $hesap['hesap_turu'] == 'banka' ? 'bank' : ($hesap['hesap_turu'] == 'kasa' ? 'cash-stack' : 'credit-card') ?> me-2 text-secondary"></i>
                                        <a href="hesap_hareketleri.php?hesap_id=<?= $hesap['id'] ?>" class="text-decoration-none text-dark stretched-link">
                                            <?= temizle($hesap['hesap_adi']) ?>
                                        </a>
                                        <small class="text-muted d-block ms-4"><?= ucfirst(str_replace('_', ' ', $hesap['hesap_turu'])) ?></small>
                                    </div>
                                    <span class="badge fs-6 <?= $hesap['bakiye'] >= 0 ? 'text-success' : 'text-danger' ?>">
                                        <?= number_format($hesap['bakiye'], 2, ',', '.') ?> ₺
                                    </span>
                                </li>
                                <?php endforeach; ?>
                            </ul>
                         <?php endif; ?>
                     </div>
                 </div>

                <div class="card shadow-sm">
                     <div class="card-header bg-light">
                        <h5 class="mb-0"><i class="bi bi-clock-history me-2 text-success"></i>Son Hesap Hareketleri</h5>
                    </div>
                    <div class="card-body p-0">
                         <?php if (empty($son_hesap_hareketleri)): ?>
                             <p class="text-muted p-3">Henüz hesap hareketi kaydedilmemiş.</p>
                         <?php else: ?>
                         <div class="table-responsive">
                             <table class="table table-sm table-hover mb-0">
                                <thead class="table-light">
                                    <tr>
                                        <th>Tarih</th>
                                        <th>Hesap</th>
                                        <th>Tür</th>
                                        <th>Açıklama</th>
                                        <th>Cari</th>
                                        <th class="text-end">Tutar</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach($son_hesap_hareketleri as $hareket): ?>
                                    <tr>
                                        <td><small><?= date('d.m H:i', strtotime($hareket['tarih'])) ?></small></td>
                                        <td><small><?= temizle($hareket['hesap_adi']) ?></small></td>
                                        <td>
                                             <?php if ($hareket['tur'] == 'giris'): ?>
                                                <span class="badge bg-success-light text-success">Giriş</span> <?php // Bootstrap 5.2+ light badges ?>
                                            <?php elseif ($hareket['tur'] == 'cikis'): ?>
                                                 <span class="badge bg-danger-light text-danger">Çıkış</span>
                                             <?php elseif ($hareket['tur'] == 'transfer'): ?>
                                                <span class="badge bg-info-light text-info">Transfer</span>
                                             <?php endif; ?>
                                        </td>
                                         <td><small><?= temizle($hareket['aciklama']) ?></small></td>
                                         <td><small><?= temizle($hareket['ad_soyad'] ?? '-') ?></small></td>
                                        <td class="text-end small <?= $hareket['tur'] == 'giris' ? 'text-success' : ($hareket['tur'] == 'cikis' ? 'text-danger' : '') ?>">
                                             <?= $hareket['tur'] == 'giris' ? '+' : ($hareket['tur'] == 'cikis' ? '-' : '') ?>
                                             <?= number_format($hareket['tutar'], 2, ',', '.') ?> ₺
                                        </td>
                                    </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                        <div class="card-footer text-center bg-white border-top-0">
                            <a href="hesap_hareketleri.php" class="btn btn-outline-secondary btn-sm">Tüm Hareketleri Gör</a>
                        </div>
                         <?php endif; ?>
                    </div>
                </div>
            </div>

            <div class="col-lg-5">
                <div class="card shadow-sm mb-4">
                     <div class="card-header bg-light">
                        <h5 class="mb-0"><i class="bi bi-calendar-check me-2 text-danger"></i>Yaklaşan / Geçmiş Vade (Tahsilatlar)</h5>
                    </div>
                    <div class="card-body p-0">
                        <?php if (empty($vadesi_gelen_satislar)): ?>
                            <p class="text-muted p-3">Vadesi yaklaşan veya geçmiş tahsilat bulunmamaktadır.</p>
                        <?php else: ?>
                        <ul class="list-group list-group-flush">
                             <?php foreach($vadesi_gelen_satislar as $borc):
                                 $kalan_gun = $borc['kalan_gun'];
                                 $vade_class = '';
                                 if ($kalan_gun !== null) {
                                     if ($kalan_gun < 0) $vade_class = 'vade-gecmis';
                                     elseif ($kalan_gun <= 7) $vade_class = 'vade-yaklasiyor';
                                 }
                             ?>
                             <li class="list-group-item list-group-item-action <?= $vade_class ?>">
                                <a href="cari_detay.php?id=<?= $borc['cari_id'] ?>" class="text-decoration-none text-dark stretched-link">
                                    <div class="d-flex w-100 justify-content-between">
                                        <h6 class="mb-1"><?= temizle($borc['ad_soyad']) ?></h6>
                                        <small class="text-muted"><?= date('d.m.Y', strtotime($borc['vade_tarihi'])) ?></small>
                                    </div>
                                    <p class="mb-1 small text-muted"><?= temizle($borc['borc_aciklama'] ?: 'Açıklama yok') ?></p>
                                    <div class="d-flex justify-content-between align-items-center">
                                        <small class="text-danger fw-bold"><?= number_format($borc['tutar'], 2, ',', '.') ?> ₺</small>
                                         <?php if ($kalan_gun !== null): ?>
                                            <small class="badge rounded-pill <?= $kalan_gun < 0 ? 'bg-danger' : ($kalan_gun <= 7 ? 'bg-warning text-dark' : 'bg-secondary') ?>">
                                                 <?= $kalan_gun < 0 ? abs($kalan_gun) . ' gün geçti' : ($kalan_gun == 0 ? 'Bugün Vade' : $kalan_gun . ' gün kaldı') ?>
                                             </small>
                                        <?php endif; ?>
                                    </div>
                                </a>
                            </li>
                            <?php endforeach; ?>
                        </ul>
                        <?php endif; ?>
                    </div>
                </div>

                <div class="card shadow-sm">
                    <div class="card-header bg-light">
                        <h5 class="mb-0"><i class="bi bi-calendar-x me-2 text-success"></i>Yaklaşan / Geçmiş Vade (Ödemeler)</h5>
                    </div>
                     <div class="card-body p-0">
                         <?php if (empty($vadesi_gelen_alislar)): ?>
                            <p class="text-muted p-3">Vadesi yaklaşan veya geçmiş ödeme bulunmamaktadır.</p>
                        <?php else: ?>
                        <ul class="list-group list-group-flush">
                             <?php foreach($vadesi_gelen_alislar as $borc):
                                 $kalan_gun = $borc['kalan_gun'];
                                 $vade_class = '';
                                 if ($kalan_gun !== null) {
                                     if ($kalan_gun < 0) $vade_class = 'vade-gecmis';
                                     elseif ($kalan_gun <= 7) $vade_class = 'vade-yaklasiyor';
                                 }
                             ?>
                             <li class="list-group-item list-group-item-action <?= $vade_class ?>">
                                <a href="cari_detay.php?id=<?= $borc['cari_id'] ?>" class="text-decoration-none text-dark stretched-link">
                                    <div class="d-flex w-100 justify-content-between">
                                        <h6 class="mb-1"><?= temizle($borc['ad_soyad']) ?></h6>
                                        <small class="text-muted"><?= date('d.m.Y', strtotime($borc['vade_tarihi'])) ?></small>
                                    </div>
                                    <p class="mb-1 small text-muted"><?= temizle($borc['borc_aciklama'] ?: 'Açıklama yok') ?></p>
                                    <div class="d-flex justify-content-between align-items-center">
                                        <small class="text-success fw-bold"><?= number_format($borc['tutar'], 2, ',', '.') ?> ₺</small>
                                         <?php if ($kalan_gun !== null): ?>
                                            <small class="badge rounded-pill <?= $kalan_gun < 0 ? 'bg-danger' : ($kalan_gun <= 7 ? 'bg-warning text-dark' : 'bg-secondary') ?>">
                                                 <?= $kalan_gun < 0 ? abs($kalan_gun) . ' gün geçti' : ($kalan_gun == 0 ? 'Bugün Vade' : $kalan_gun . ' gün kaldı') ?>
                                             </small>
                                        <?php endif; ?>
                                    </div>
                                </a>
                            </li>
                            <?php endforeach; ?>
                        </ul>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
		
	<?php include("footer.php"); ?>
		
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    
    <script>
        // Aylık Gelir-Gider Grafiği
        document.addEventListener('DOMContentLoaded', function() {
            const ctx = document.getElementById('gelirGiderChart').getContext('2d');
            
            // Son 6 ay için örnek veri
            const labels = [];
            const gelirData = [];
            const giderData = [];
            
            // Son 6 ayın etiketlerini oluştur
            for (let i = 5; i >= 0; i--) {
                const date = new Date();
                date.setMonth(date.getMonth() - i);
                const monthName = date.toLocaleString('tr-TR', { month: 'long' });
                labels.push(monthName);
                
                // Rastgele veriler (gerçek veriler için AJAX ile sunucudan çekilebilir)
                gelirData.push(Math.floor(Math.random() * 20000) + 5000);
                giderData.push(Math.floor(Math.random() * 15000) + 3000);
            }
            
            const myChart = new Chart(ctx, {
                type: 'bar',
                data: {
                    labels: labels,
                    datasets: [
                        {
                            label: 'Gelir',
                            data: gelirData,
                            backgroundColor: 'rgba(40, 167, 69, 0.7)',
                            borderColor: 'rgba(40, 167, 69, 1)',
                            borderWidth: 1
                        },
                        {
                            label: 'Gider',
                            data: giderData,
                            backgroundColor: 'rgba(220, 53, 69, 0.7)',
                            borderColor: 'rgba(220, 53, 69, 1)',
                            borderWidth: 1
                        }
                    ]
                },
                options: {
                    responsive: true,
                    scales: {
                        y: {
                            beginAtZero: true,
                            ticks: {
                                callback: function(value) {
                                    return value.toLocaleString('tr-TR') + ' ₺';
                                }
                            }
                        }
                    },
                    plugins: {
                        tooltip: {
                            callbacks: {
                                label: function(context) {
                                    return context.dataset.label + ': ' + context.raw.toLocaleString('tr-TR') + ' ₺';
                                }
                            }
                        }
                    }
                }
            });
        });
    </script>
</body>
</html>