<?php
/**
 * ArEsnaf Kurulum Dosyası
 * Headers already sent hatasını önlemek için tüm PHP kodu en başta
 */

// AJAX bağlantı testi - En başta olmalı
if (isset($_POST['action']) && $_POST['action'] == 'test_connection') {
    header('Content-Type: application/json');
    
    $db_host = $_POST['db_host'] ?? 'localhost';
    $db_name = $_POST['db_name'] ?? '';
    $db_user = $_POST['db_user'] ?? '';
    $db_pass = $_POST['db_pass'] ?? '';
    
    // Hata raporlamayı etkinleştir
    error_reporting(E_ALL);
    ini_set('display_errors', 1);
    
    $debug_info = [];
    $debug_info['php_version'] = PHP_VERSION;
    $debug_info['pdo_available'] = extension_loaded('pdo');
    $debug_info['pdo_mysql_available'] = extension_loaded('pdo_mysql');
    $debug_info['host'] = $db_host;
    $debug_info['database'] = $db_name;
    $debug_info['username'] = $db_user;
    
    try {
        // PDO eklentisi kontrolü
        if (!extension_loaded('pdo')) {
            throw new Exception('PDO eklentisi yüklü değil!');
        }
        
        if (!extension_loaded('pdo_mysql')) {
            throw new Exception('PDO MySQL eklentisi yüklü değil!');
        }
        
        $debug_info['step1'] = 'PDO eklentileri kontrol edildi';
        
        // Önce veritabanı olmadan bağlan
        $dsn = "mysql:host=$db_host;charset=utf8mb4";
        $debug_info['dsn_without_db'] = $dsn;
        
        $pdo = new PDO($dsn, $db_user, $db_pass, [
            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
            PDO::ATTR_TIMEOUT => 10
        ]);
        
        $debug_info['step2'] = 'Veritabanı sunucusuna bağlantı başarılı';
        
        // MySQL sürümünü kontrol et
        $version = $pdo->query('SELECT VERSION()')->fetchColumn();
        $debug_info['mysql_version'] = $version;
        
        // Veritabanını oluştur (varsa hata vermez)
        $create_db_sql = "CREATE DATABASE IF NOT EXISTS `$db_name` CHARACTER SET utf8mb4 COLLATE utf8mb4_turkish_ci";
        $pdo->exec($create_db_sql);
        
        $debug_info['step3'] = "Veritabanı '$db_name' oluşturuldu/kontrol edildi";
        
        // Şimdi veritabanına bağlan
        $dsn_with_db = "mysql:host=$db_host;dbname=$db_name;charset=utf8mb4";
        $debug_info['dsn_with_db'] = $dsn_with_db;
        
        $pdo = new PDO($dsn_with_db, $db_user, $db_pass, [
            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
            PDO::ATTR_TIMEOUT => 10
        ]);
        
        $debug_info['step4'] = 'Veritabanına bağlantı başarılı';
        
        // Basit bir test sorgusu çalıştır
        $test_query = $pdo->query('SELECT 1 as test');
        $test_result = $test_query->fetchColumn();
        
        if ($test_result == 1) {
            $debug_info['step5'] = 'Test sorgusu başarılı';
        }
        
        echo json_encode([
            'success' => true,
            'message' => "✅ Veritabanı bağlantısı başarılı! Veritabanı '$db_name' hazır.",
            'debug' => $debug_info
        ]);
        
    } catch (PDOException $e) {
        $error_code = $e->getCode();
        $error_message = $e->getMessage();
        
        // Yaygın hata kodları için özel mesajlar
        $user_friendly_message = '';
        switch ($error_code) {
            case 1045:
                $user_friendly_message = 'Kullanıcı adı veya şifre hatalı!';
                break;
            case 2002:
                $user_friendly_message = 'Veritabanı sunucusuna bağlanılamıyor! Host adresini kontrol edin.';
                break;
            case 1049:
                $user_friendly_message = 'Belirtilen veritabanı bulunamadı! (Otomatik oluşturulmaya çalışılacak)';
                break;
            case 1044:
                $user_friendly_message = 'Veritabanı oluşturma izniniz yok! Hosting sağlayıcınızdan yardım alın.';
                break;
            default:
                $user_friendly_message = 'Veritabanı bağlantı hatası!';
        }
        
        echo json_encode([
            'success' => false,
            'message' => "$user_friendly_message (Hata Kodu: $error_code)",
            'technical_error' => $error_message,
            'error_code' => $error_code,
            'debug' => $debug_info
        ]);
        
    } catch (Exception $e) {
        echo json_encode([
            'success' => false,
            'message' => 'Genel hata: ' . $e->getMessage(),
            'debug' => $debug_info
        ]);
    }
    
    exit;
}

// Session başlat
session_start();

// Kurulum tamamlandıysa yönlendir
if (file_exists('config.php') && !isset($_GET['force'])) {
    $config_content = file_get_contents('config.php');
    if (strpos($config_content, 'KURULUM_TAMAMLANDI') !== false) {
       
    }
}

$step = isset($_POST['step']) ? (int)$_POST['step'] : 1;
$errors = [];
$success = [];

// Adım işlemleri
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $step > 1) {
    
    // Adım 2: Bağlantı Testi ve Veritabanı Oluşturma
    if ($step == 2) {
        $db_host = $_POST['db_host'] ?? 'localhost';
        $db_name = $_POST['db_name'] ?? 'arEsnaf';
        $db_user = $_POST['db_user'] ?? 'root';
        $db_pass = $_POST['db_pass'] ?? '';
        
        try {
            // Önce veritabanı olmadan bağlan
            $pdo = new PDO("mysql:host=$db_host;charset=utf8mb4", $db_user, $db_pass);
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            
            // Veritabanını oluştur (varsa hata vermez)
            $pdo->exec("CREATE DATABASE IF NOT EXISTS `$db_name` CHARACTER SET utf8mb4 COLLATE utf8mb4_turkish_ci");
            
            // Şimdi veritabanına bağlan
            $pdo = new PDO("mysql:host=$db_host;dbname=$db_name;charset=utf8mb4", $db_user, $db_pass);
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            
            $_SESSION['db_config'] = [
                'host' => $db_host,
                'name' => $db_name,
                'user' => $db_user,
                'pass' => $db_pass
            ];
            
            $success[] = "Veritabanı bağlantısı başarılı!";
            $success[] = "Veritabanı '$db_name' hazır.";
            
        } catch (PDOException $e) {
            $errors[] = "Veritabanı bağlantı hatası: " . $e->getMessage();
        }
    }
    
    // Adım 3: SQL Dosyasını Yükle - YENİ VE GELİŞTİRİLMİŞ
    elseif ($step == 3) {
        if (!isset($_SESSION['db_config'])) {
            header('Location: install.php');
            exit;
        }
        
        $config = $_SESSION['db_config'];
        
        try {
            $pdo = new PDO("mysql:host={$config['host']};dbname={$config['name']};charset=utf8mb4", 
                          $config['user'], $config['pass']);
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            
            // SQL dosyasını oku
            $sql_file = 'datebase.sql';
            if (!file_exists($sql_file)) {
                throw new Exception("SQL dosyası bulunamadı: $sql_file");
            }
            
            $sql_content = file_get_contents($sql_file);
            if ($sql_content === false) {
                throw new Exception("SQL dosyası okunamadı!");
            }
            
            // SQL içeriğini temizle ve hazırla
            $sql_content = str_replace(["\r\n", "\r"], "\n", $sql_content);
            
            // Çok satırlı SQL komutlarını doğru şekilde ayır
            $statements = [];
            $current_statement = '';
            $lines = explode("\n", $sql_content);
            
            foreach ($lines as $line) {
                $line = trim($line);
                
                // Boş satırları ve yorumları atla
                if (empty($line) || 
                    substr($line, 0, 2) === '--' || 
                    substr($line, 0, 2) === '/*' ||
                    substr($line, 0, 4) === '/*!4') {
                    continue;
                }
                
                // SET, START, COMMIT komutlarını atla
                if (preg_match('/^(SET|START|COMMIT)/i', $line)) {
                    continue;
                }
                
                $current_statement .= $line . ' ';
                
                // Satır ';' ile bitiyorsa komut tamamlandı
                if (substr($line, -1) === ';') {
                    $statement = trim($current_statement);
                    if (!empty($statement)) {
                        $statements[] = $statement;
                    }
                    $current_statement = '';
                }
            }
            
            // Kalan statement varsa ekle
            if (!empty(trim($current_statement))) {
                $statements[] = trim($current_statement);
            }
            
            $executed_commands = 0;
            $failed_commands = [];
            
            // Her SQL komutunu çalıştır
            foreach ($statements as $statement) {
                if (empty($statement)) continue;
                
                try {
                    $pdo->exec($statement);
                    $executed_commands++;
                } catch (PDOException $e) {
                    // Tablo zaten varsa hatayı yok say
                    if (strpos($e->getMessage(), 'already exists') === false && 
                        strpos($e->getMessage(), 'Duplicate entry') === false) {
                        $failed_commands[] = [
                            'statement' => substr($statement, 0, 100) . '...',
                            'error' => $e->getMessage()
                        ];
                    }
                }
            }
            
            if (!empty($failed_commands)) {
                $error_details = "Bazı SQL komutları başarısız:\n";
                foreach ($failed_commands as $fc) {
                    $error_details .= "- " . $fc['statement'] . "\n  Hata: " . $fc['error'] . "\n";
                }
                throw new Exception($error_details);
            }
            
            $success[] = "Veritabanı tabloları başarıyla oluşturuldu!";
            $success[] = "$executed_commands SQL komutu çalıştırıldı.";
            
            // Tabloların oluştuğunu kontrol et
            $tables = $pdo->query("SHOW TABLES")->fetchAll(PDO::FETCH_COLUMN);
            $success[] = count($tables) . " tablo oluşturuldu: " . implode(', ', $tables);
            
        } catch (Exception $e) {
            $errors[] = "SQL yükleme hatası: " . $e->getMessage();
        }
    }
    
    // Adım 4: Yönetici Hesabı Oluştur ve Kurulumu Tamamla
    elseif ($step == 4) {
        if (!isset($_SESSION['db_config'])) {
            header('Location: install.php');
            exit;
        }
        
        $config = $_SESSION['db_config'];
        $admin_user = $_POST['admin_user'] ?? 'admin';
        $admin_pass = $_POST['admin_pass'] ?? '';
        $admin_name = $_POST['admin_name'] ?? 'Sistem Yöneticisi';
        
        if (empty($admin_pass)) {
            $errors[] = "Şifre boş olamaz!";
        }
        
        if (empty($errors)) {
            try {
                $pdo = new PDO("mysql:host={$config['host']};dbname={$config['name']};charset=utf8mb4", 
                              $config['user'], $config['pass']);
                $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
                
                // Kullanıcılar tablosunun varlığını kontrol et
                $tables = $pdo->query("SHOW TABLES LIKE 'kullanicilar'")->fetchAll();
                if (empty($tables)) {
                    throw new Exception("kullanicilar tablosu bulunamadı! SQL dosyası doğru yüklenmemiş olabilir.");
                }
                
                // Mevcut admin kullanıcısını güncelle veya yeni oluştur
                $hashed_password = password_hash($admin_pass, PASSWORD_DEFAULT);
                
                $stmt = $pdo->prepare("SELECT id FROM kullanicilar WHERE kullanici_adi = ?");
                $stmt->execute([$admin_user]);
                
                if ($stmt->fetch()) {
                    // Güncelle
                    $stmt = $pdo->prepare("UPDATE kullanicilar SET sifre = ?, ad_soyad = ? WHERE kullanici_adi = ?");
                    $stmt->execute([$hashed_password, $admin_name, $admin_user]);
                    $success[] = "Yönetici hesabı güncellendi!";
                } else {
                    // Yeni oluştur
                    $stmt = $pdo->prepare("INSERT INTO kullanicilar (kullanici_adi, sifre, ad_soyad) VALUES (?, ?, ?)");
                    $stmt->execute([$admin_user, $hashed_password, $admin_name]);
                    $success[] = "Yönetici hesabı oluşturuldu!";
                }
                
                // Config dosyasını oluştur
                $config_content = "<?php
// Veritabanı bağlantı bilgileri
\$host = \"{$config['host']}\";
\$dbname = \"{$config['name']}\";
\$username = \"{$config['user']}\";
\$password = \"{$config['pass']}\";

// Hata raporlama
ini_set('display_errors', 0);
ini_set('log_errors', 1);
ini_set('error_log', __DIR__ . '/php_errors.log');
error_reporting(E_ALL);

// PDO bağlantısı
try {
    \$db = new PDO(\"mysql:host=\$host;dbname=\$dbname;charset=utf8mb4\", \$username, \$password);
    \$db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    \$db->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
    \$db->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_ASSOC);
} catch(PDOException \$e) {
    error_log(\"Veritabanı bağlantı hatası: \" . \$e->getMessage());
    die(\"Sistem şu anda kullanılamıyor. Lütfen daha sonra tekrar deneyin.\");
}

// Oturum ayarları
session_name('ESNAF_YONETIM_SID');
session_set_cookie_params([
    'lifetime' => 86400,
    'path' => '/',
    'domain' => \$_SERVER['HTTP_HOST'],
    'secure' => isset(\$_SERVER['HTTPS']),
    'httponly' => true,
    'samesite' => 'Strict'
]);

if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

// Güvenlik başlıkları
header(\"X-Frame-Options: DENY\");
header(\"X-Content-Type-Options: nosniff\");
header(\"Referrer-Policy: strict-origin-when-cross-origin\");
header(\"Content-Security-Policy: default-src 'self'; script-src 'self' https://cdn.jsdelivr.net 'unsafe-inline'; style-src 'self' https://cdn.jsdelivr.net 'unsafe-inline'; font-src 'self' https://cdn.jsdelivr.net; img-src 'self' data:;\");

// CSRF koruması
function csrf_token_olustur() {
    if(empty(\$_SESSION['csrf_token'])) {
        \$_SESSION['csrf_token'] = bin2hex(random_bytes(32));
    }
    return \$_SESSION['csrf_token'];
}

function csrf_token_dogrula(\$token) {
    if (empty(\$token) || empty(\$_SESSION['csrf_token'])) {
        return false;
    }
    return hash_equals(\$_SESSION['csrf_token'], \$token);
}

// Yetki kontrolü
function yetkili_mi() {
    if(!isset(\$_SESSION['kullanici_id'])) {
        \$_SESSION['login_redirect'] = \$_SERVER['REQUEST_URI'];
        header(\"Location: login.php\");
        exit();
    }

    if(isset(\$_SESSION['login_time']) && (time() - \$_SESSION['login_time'] > 86400)) {
        session_unset();
        session_destroy();
        header(\"Location: login.php?timeout=1\");
        exit();
    }
    \$_SESSION['login_time'] = time();

    if(!isset(\$_SESSION['user_agent'])) {
        \$_SESSION['user_agent'] = \$_SERVER['HTTP_USER_AGENT'] ?? 'unknown';
    } elseif(\$_SESSION['user_agent'] !== (\$_SERVER['HTTP_USER_AGENT'] ?? 'unknown')) {
        session_unset();
        session_destroy();
        header(\"Location: login.php?hacking=1\");
        exit();
    }

    if (!isset(\$_SESSION['last_regen']) || time() - \$_SESSION['last_regen'] > 1800) {
        session_regenerate_id(true);
        \$_SESSION['last_regen'] = time();
    }
}

// Veri temizleme fonksiyonları
function temizle(\$data) {
    if(is_array(\$data)) {
        return array_map('temizle', \$data);
    }
    return htmlspecialchars(trim((string)\$data), ENT_QUOTES | ENT_SUBSTITUTE, 'UTF-8');
}

function tamsayi(\$value) {
    return filter_var(\$value, FILTER_VALIDATE_INT);
}

function ondalik(\$value) {
    \$value = str_replace(',', '.', (string)\$value);
    return filter_var(\$value, FILTER_VALIDATE_FLOAT);
}

// Brute-force koruması
function brute_force_kontrol() {
    \$max_deneme = 5;
    \$bekleme_suresi = 300;

    if (!isset(\$_SESSION['login_attempts'])) {
        \$_SESSION['login_attempts'] = 0;
    }
    if (!isset(\$_SESSION['last_attempt_time'])) {
        \$_SESSION['last_attempt_time'] = 0;
    }

    if(\$_SESSION['login_attempts'] >= \$max_deneme) {
        if(time() - \$_SESSION['last_attempt_time'] < \$bekleme_suresi) {
            \$kalan_sure = \$bekleme_suresi - (time() - \$_SESSION['last_attempt_time']);
            \$_SESSION['hata'] = \"Çok fazla hatalı giriş denemesi. Lütfen \" . ceil(\$kalan_sure/60) . \" dakika sonra tekrar deneyin.\";
            return false;
        } else {
            \$_SESSION['login_attempts'] = 0;
            unset(\$_SESSION['last_attempt_time']);
        }
    }
    return true;
}

function brute_force_log_attempt() {
    if (!isset(\$_SESSION['login_attempts'])) {
        \$_SESSION['login_attempts'] = 0;
    }
    \$_SESSION['login_attempts']++;
    \$_SESSION['last_attempt_time'] = time();
}

function brute_force_reset() {
    unset(\$_SESSION['login_attempts']);
    unset(\$_SESSION['last_attempt_time']);
}

// Yardımcı Fonksiyonlar
function hesapBakiyeGuncelle(PDO \$db, int \$hesap_id, float \$degisim): bool {
    try {
        \$stmt = \$db->prepare(\"UPDATE hesaplar SET bakiye = bakiye + :degisim WHERE id = :hesap_id\");
        \$stmt->bindParam(':degisim', \$degisim, PDO::PARAM_STR);
        \$stmt->bindParam(':hesap_id', \$hesap_id, PDO::PARAM_INT);
        return \$stmt->execute();
    } catch (PDOException \$e) {
        error_log(\"Hesap Bakiye Güncelleme Hatası (Hesap ID: {\$hesap_id}): \" . \$e->getMessage());
        return false;
    }
}

function cariBakiyeGuncelle(PDO \$db, int \$cari_id, float \$borc_degisim = 0.0, float \$alacak_degisim = 0.0): bool {
    try {
        \$sql = \"UPDATE cariler SET
                    toplam_borc = toplam_borc + :borc_degisim,
                    toplam_alacak = toplam_alacak + :alacak_degisim,
                    bakiye = (toplam_alacak + :alacak_degisim_tekrar) - (toplam_borc + :borc_degisim_tekrar)
                WHERE id = :cari_id\";

        \$stmt = \$db->prepare(\$sql);
        \$params = [
            ':borc_degisim' => \$borc_degisim,
            ':alacak_degisim' => \$alacak_degisim,
            ':borc_degisim_tekrar' => \$borc_degisim,
            ':alacak_degisim_tekrar' => \$alacak_degisim,
            ':cari_id' => \$cari_id
        ];
        return \$stmt->execute(\$params);
    } catch (PDOException \$e) {
        error_log(\"Cari Bakiye Güncelleme Hatası (Cari ID: {\$cari_id}) - Hata: \" . \$e->getMessage());
        return false;
    }
}

function hesapHareketiEkle(PDO \$db, int \$hesap_id, string \$tur, float \$tutar, string \$aciklama, ?int \$cari_id = null, ?int \$borc_id = null, ?int \$baglanti_id = null): bool {
    try {
        \$sql = \"INSERT INTO hesap_hareketleri (hesap_id, tur, tutar, aciklama, cari_id, borc_id, baglanti_id, tarih)
                VALUES (:hesap_id, :tur, :tutar, :aciklama, :cari_id, :borc_id, :baglanti_id, NOW())\";
        \$stmt = \$db->prepare(\$sql);
        \$stmt->bindParam(':hesap_id', \$hesap_id, PDO::PARAM_INT);
        \$stmt->bindParam(':tur', \$tur, PDO::PARAM_STR);
        \$stmt->bindParam(':tutar', \$tutar, PDO::PARAM_STR);
        \$stmt->bindParam(':aciklama', \$aciklama, PDO::PARAM_STR);
        \$stmt->bindParam(':cari_id', \$cari_id, PDO::PARAM_INT);
        \$stmt->bindParam(':borc_id', \$borc_id, PDO::PARAM_INT);
        \$stmt->bindParam(':baglanti_id', \$baglanti_id, PDO::PARAM_INT);
        return \$stmt->execute();
    } catch (PDOException \$e) {
        error_log(\"Hesap Hareketi Ekleme Hatası (Hesap ID: {\$hesap_id}, Tutar: {\$tutar}): \" . \$e->getMessage());
        return false;
    }
}

// KURULUM TAMAMLANDI - Bu satırı silmeyin!
define('KURULUM_TAMAMLANDI', true);
?>";
                
                file_put_contents('config.php', $config_content);
                
                $success[] = "Yapılandırma dosyası oluşturuldu!";
                $success[] = "Kurulum başarıyla tamamlandı!";
                
                // Session temizle
                unset($_SESSION['db_config']);
                
            } catch (Exception $e) {
                $errors[] = "Yönetici hesabı oluşturma hatası: " . $e->getMessage();
            }
        }
    }
}

// HTML çıktısı başlıyor
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ArEsnaf Kurulum</title>
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }
        
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            min-height: 100vh;
            display: flex;
            align-items: center;
            justify-content: center;
            padding: 20px;
        }
        
        .container {
            background: white;
            border-radius: 15px;
            box-shadow: 0 20px 40px rgba(0,0,0,0.1);
            padding: 40px;
            max-width: 600px;
            width: 100%;
        }
        
        .header {
            text-align: center;
            margin-bottom: 30px;
        }
        
        .header h1 {
            color: #333;
            font-size: 2.5em;
            margin-bottom: 10px;
        }
        
        .header p {
            color: #666;
            font-size: 1.1em;
        }
        
        .step {
            margin-bottom: 30px;
        }
        
        .step-title {
            background: #f8f9fa;
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
            border-left: 4px solid #667eea;
        }
        
        .step-title h3 {
            color: #333;
            margin-bottom: 5px;
        }
        
        .step-title p {
            color: #666;
            font-size: 0.9em;
        }
        
        .form-group {
            margin-bottom: 20px;
        }
        
        .form-group label {
            display: block;
            margin-bottom: 8px;
            color: #333;
            font-weight: 500;
        }
        
        .form-group input, .form-group select {
            width: 100%;
            padding: 12px;
            border: 2px solid #e1e5e9;
            border-radius: 8px;
            font-size: 16px;
            transition: border-color 0.3s;
        }
        
        .form-group input:focus, .form-group select:focus {
            outline: none;
            border-color: #667eea;
        }
        
        .btn {
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            color: white;
            padding: 15px 30px;
            border: none;
            border-radius: 8px;
            font-size: 16px;
            cursor: pointer;
            transition: transform 0.2s;
            width: 100%;
        }
        
        .btn:hover {
            transform: translateY(-2px);
        }
        
        .btn:disabled {
            opacity: 0.6;
            cursor: not-allowed;
            transform: none;
        }
        
        .alert {
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
        }
        
        .alert-success {
            background: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }
        
        .alert-error {
            background: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }
        
        .alert-warning {
            background: #fff3cd;
            color: #856404;
            border: 1px solid #ffeaa7;
        }
        
        .progress {
            background: #e9ecef;
            border-radius: 10px;
            height: 20px;
            margin-bottom: 20px;
            overflow: hidden;
        }
        
        .progress-bar {
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            height: 100%;
            transition: width 0.3s;
        }
        
        .hidden {
            display: none;
        }
        
        .loading {
            display: inline-block;
            width: 20px;
            height: 20px;
            border: 3px solid #f3f3f3;
            border-top: 3px solid #667eea;
            border-radius: 50%;
            animation: spin 1s linear infinite;
            margin-right: 10px;
        }
        
        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
        
        .test-result {
            padding: 10px;
            border-radius: 5px;
            margin-top: 10px;
            font-size: 14px;
        }
        
        .test-success {
            background: #d4edda;
            color: #155724;
        }
        
        .test-error {
            background: #f8d7da;
            color: #721c24;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>🏪 ArEsnaf</h1>
            <p>Esnaf Yönetim Sistemi Kurulumu</p>
        </div>

        <div class="progress">
            <div class="progress-bar" id="progressBar" style="width: <?= min($step * 25, 100) ?>%"></div>
        </div>

        <?php
        // Adım 1: Veritabanı Bilgileri
        if ($step == 1) {
            ?>
            <div class="step">
                <div class="step-title">
                    <h3>Adım 1: Veritabanı Bilgileri</h3>
                    <p>Lütfen MySQL/MariaDB veritabanı bağlantı bilgilerinizi girin</p>
                </div>
                
                <form method="POST" id="dbForm">
                    <input type="hidden" name="step" value="2">
                    
                    <div class="form-group">
                        <label for="db_host">Veritabanı Sunucusu:</label>
                        <input type="text" id="db_host" name="db_host" value="localhost" required>
                    </div>
                    
                    <div class="form-group">
                        <label for="db_name">Veritabanı Adı:</label>
                        <input type="text" id="db_name" name="db_name" value="arEsnaf" required>
                    </div>
                    
                    <div class="form-group">
                        <label for="db_user">Kullanıcı Adı:</label>
                        <input type="text" id="db_user" name="db_user" value="root" required>
                    </div>
                    
                    <div class="form-group">
                        <label for="db_pass">Şifre:</label>
                        <input type="password" id="db_pass" name="db_pass" value="">
                    </div>
                    
                    <button type="button" class="btn" onclick="testConnection()" id="testBtn">
                        Bağlantıyı Test Et
                    </button>
                    
                    <div id="testResult"></div>
                    
                    <button type="submit" class="btn hidden" id="continueBtn" style="margin-top: 15px;">
                        Devam Et
                    </button>
                </form>
            </div>
            <?php
        }
        
        // Adım 2: Bağlantı Testi ve Veritabanı Oluşturma
        elseif ($step == 2) {
            if (empty($errors)) {
                ?>
                <div class="step">
                    <div class="step-title">
                        <h3>Adım 2: Veritabanı Tabloları</h3>
                        <p>Veritabanı tabloları oluşturuluyor...</p>
                    </div>
                    
                    <?php foreach ($success as $msg): ?>
                        <div class="alert alert-success"><?= htmlspecialchars($msg) ?></div>
                    <?php endforeach; ?>
                    
                    <form method="POST">
                        <input type="hidden" name="step" value="3">
                        <button type="submit" class="btn">Tabloları Oluştur</button>
                    </form>
                </div>
                <?php
            } else {
                ?>
                <div class="step">
                    <div class="step-title">
                        <h3>Hata!</h3>
                        <p>Veritabanı bağlantısında sorun oluştu</p>
                    </div>
                    
                    <?php foreach ($errors as $error): ?>
                        <div class="alert alert-error"><?= htmlspecialchars($error) ?></div>
                    <?php endforeach; ?>
                    
                    <form method="POST">
                        <input type="hidden" name="step" value="1">
                        <button type="submit" class="btn">Geri Dön</button>
                    </form>
                </div>
                <?php
            }
        }
        
        // Adım 3: SQL Dosyasını Yükle
        elseif ($step == 3) {
            if (empty($errors)) {
                ?>
                <div class="step">
                    <div class="step-title">
                        <h3>Adım 3: Yönetici Hesabı</h3>
                        <p>Sisteme giriş yapacak yönetici hesabını oluşturun</p>
                    </div>
                    
                    <?php foreach ($success as $msg): ?>
                        <div class="alert alert-success"><?= htmlspecialchars($msg) ?></div>
                    <?php endforeach; ?>
                    
                    <form method="POST">
                        <input type="hidden" name="step" value="4">
                        
                        <div class="form-group">
                            <label for="admin_user">Kullanıcı Adı:</label>
                            <input type="text" id="admin_user" name="admin_user" value="admin" required>
                        </div>
                        
                        <div class="form-group">
                            <label for="admin_pass">Şifre:</label>
                            <input type="password" id="admin_pass" name="admin_pass" required minlength="6">
                        </div>
                        
                        <div class="form-group">
                            <label for="admin_name">Ad Soyad:</label>
                            <input type="text" id="admin_name" name="admin_name" value="Sistem Yöneticisi" required>
                        </div>
                        
                        <button type="submit" class="btn">Yönetici Hesabını Oluştur</button>
                    </form>
                </div>
                <?php
            } else {
                ?>
                <div class="step">
                    <div class="step-title">
                        <h3>Hata!</h3>
                        <p>Veritabanı tabloları oluşturulamadı</p>
                    </div>
                    
                    <?php foreach ($errors as $error): ?>
                        <div class="alert alert-error"><?= htmlspecialchars($error) ?></div>
                    <?php endforeach; ?>
                    
                    <form method="POST">
                        <input type="hidden" name="step" value="2">
                        <button type="submit" class="btn">Tekrar Dene</button>
                    </form>
                </div>
                <?php
            }
        }
        
        // Adım 4: Yönetici Hesabı Oluştur ve Kurulumu Tamamla
        elseif ($step == 4) {
            if (empty($errors)) {
                ?>
                <div class="step">
                    <div class="step-title">
                        <h3>🎉 Kurulum Tamamlandı!</h3>
                        <p>ArEsnaf sistemi başarıyla kuruldu</p>
                    </div>
                    
                    <?php foreach ($success as $msg): ?>
                        <div class="alert alert-success"><?= htmlspecialchars($msg) ?></div>
                    <?php endforeach; ?>
                    
                    <div class="alert alert-warning">
                        <strong>Güvenlik Uyarısı:</strong> Kurulum tamamlandıktan sonra install.php dosyasını sunucudan silin veya yeniden adlandırın.
                    </div>
                    
                    <div style="text-align: center; margin-top: 30px;">
                        <a href="index.php" class="btn" style="text-decoration: none; display: inline-block;">
                            Sisteme Giriş Yap
                        </a>
                    </div>
                    
                    <div style="margin-top: 20px; padding: 15px; background: #f8f9fa; border-radius: 8px;">
                        <h4>Giriş Bilgileri:</h4>
                        <p><strong>Kullanıcı Adı:</strong> <?= htmlspecialchars($_POST['admin_user'] ?? 'admin') ?></p>
                        <p><strong>Şifre:</strong> (Belirlediğiniz şifre)</p>
                    </div>
                </div>
                <?php
            } else {
                ?>
                <div class="step">
                    <div class="step-title">
                        <h3>Hata!</h3>
                        <p>Yönetici hesabı oluşturulamadı</p>
                    </div>
                    
                    <?php foreach ($errors as $error): ?>
                        <div class="alert alert-error"><?= htmlspecialchars($error) ?></div>
                    <?php endforeach; ?>
                    
                    <form method="POST">
                        <input type="hidden" name="step" value="3">
                        <button type="submit" class="btn">Geri Dön</button>
                    </form>
                </div>
                <?php
            }
        }
        ?>
    </div>

    <script>
        function testConnection() {
            const btn = document.getElementById('testBtn');
            const result = document.getElementById('testResult');
            const continueBtn = document.getElementById('continueBtn');
            
            btn.innerHTML = '<span class="loading"></span>Test ediliyor...';
            btn.disabled = true;
            
            const formData = new FormData();
            formData.append('action', 'test_connection');
            formData.append('db_host', document.getElementById('db_host').value);
            formData.append('db_name', document.getElementById('db_name').value);
            formData.append('db_user', document.getElementById('db_user').value);
            formData.append('db_pass', document.getElementById('db_pass').value);
            
            fetch('install.php', {
                method: 'POST',
                body: formData
            })
            .then(response => {
                if (!response.ok) {
                    throw new Error('HTTP ' + response.status + ': ' + response.statusText);
                }
                return response.text();
            })
            .then(text => {
                try {
                    const data = JSON.parse(text);
                    if (data.success) {
                        result.innerHTML = '<div class="test-result test-success">✅ ' + data.message + '</div>';
                        
                        // Debug bilgilerini göster (geliştirme amaçlı)
                        if (data.debug) {
                            let debugHtml = '<details style="margin-top: 10px;"><summary>Debug Bilgileri (Teknik)</summary><pre style="font-size: 12px; background: #f8f9fa; padding: 10px; border-radius: 5px; margin-top: 5px;">';
                            debugHtml += JSON.stringify(data.debug, null, 2);
                            debugHtml += '</pre></details>';
                            result.innerHTML += debugHtml;
                        }
                        
                        continueBtn.classList.remove('hidden');
                    } else {
                        let errorHtml = '<div class="test-result test-error">❌ ' + data.message + '</div>';
                        
                        // Teknik hata detayını göster
                        if (data.technical_error) {
                            errorHtml += '<details style="margin-top: 10px;"><summary>Teknik Hata Detayı</summary>';
                            errorHtml += '<div style="font-size: 12px; background: #f8f9fa; padding: 10px; border-radius: 5px; margin-top: 5px;">';
                            errorHtml += '<strong>Hata Kodu:</strong> ' + (data.error_code || 'Bilinmiyor') + '<br>';
                            errorHtml += '<strong>Teknik Mesaj:</strong> ' + data.technical_error;
                            errorHtml += '</div></details>';
                        }
                        
                        // Debug bilgilerini göster
                        if (data.debug) {
                            errorHtml += '<details style="margin-top: 10px;"><summary>Debug Bilgileri</summary><pre style="font-size: 12px; background: #f8f9fa; padding: 10px; border-radius: 5px; margin-top: 5px;">';
                            errorHtml += JSON.stringify(data.debug, null, 2);
                            errorHtml += '</pre></details>';
                        }
                        
                        result.innerHTML = errorHtml;
                        continueBtn.classList.add('hidden');
                    }
                } catch (parseError) {
                    result.innerHTML = '<div class="test-result test-error">❌ Sunucu yanıtı işlenirken hata oluştu</div>';
                    result.innerHTML += '<details style="margin-top: 10px;"><summary>Ham Sunucu Yanıtı</summary><pre style="font-size: 12px; background: #f8f9fa; padding: 10px; border-radius: 5px; margin-top: 5px;">' + text + '</pre></details>';
                    continueBtn.classList.add('hidden');
                }
            })
            .catch(error => {
                result.innerHTML = '<div class="test-result test-error">❌ Bağlantı testi sırasında hata oluştu: ' + error.message + '</div>';
                result.innerHTML += '<div style="margin-top: 10px; font-size: 12px; color: #666;">Bu hata genellikle sunucu yapılandırması veya ağ bağlantısı sorunlarından kaynaklanır.</div>';
                continueBtn.classList.add('hidden');
            })
            .finally(() => {
                btn.innerHTML = 'Bağlantıyı Test Et';
                btn.disabled = false;
            });
        }
    </script>
</body>
</html>

