<?php
require_once 'config.php';
yetkili_mi();

$sayfa_baslik = "Kategori Yönetimi";

// Kategori ekleme
if($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['kategori_ekle'])) {
    if(!csrf_token_dogrula($_POST['csrf_token'])) {
        die("Geçersiz CSRF token!");
    }
    
    $kategori_adi = temizle($_POST['kategori_adi']);
    
    try {
        $stmt = $db->prepare("INSERT INTO kategoriler (kategori_adi) VALUES (?)");
        $stmt->execute([$kategori_adi]);
        
        $_SESSION['mesaj'] = "Kategori başarıyla eklendi.";
        header("Location: kategoriler.php");
        exit();
    } catch(PDOException $e) {
        error_log("Kategori ekleme hatası: " . $e->getMessage());
        $_SESSION['hata'] = "Bu kategori zaten mevcut!";
        header("Location: kategoriler.php");
        exit();
    }
}

// Kategori silme
if(isset($_GET['sil'])) {
    if(!csrf_token_dogrula($_GET['csrf_token'])) {
        die("Geçersiz CSRF token!");
    }
    
    $id = (int)$_GET['sil'];
    
    try {
        // Kategori kullanılıyor mu kontrol et
        $kullanilan = $db->prepare("SELECT COUNT(*) FROM borclar WHERE kategori_id = ?");
        $kullanilan->execute([$id]);
        $kullanilan = $kullanilan->fetchColumn();
        
        if($kullanilan > 0) {
            $_SESSION['hata'] = "Bu kategori kullanıldığı için silinemez!";
        } else {
            $stmt = $db->prepare("DELETE FROM kategoriler WHERE id = ?");
            $stmt->execute([$id]);
            $_SESSION['mesaj'] = "Kategori başarıyla silindi.";
        }
        
        header("Location: kategoriler.php");
        exit();
    } catch(PDOException $e) {
        error_log("Kategori silme hatası: " . $e->getMessage());
        $_SESSION['hata'] = "Kategori silinirken hata oluştu.";
        header("Location: kategoriler.php");
        exit();
    }
}

// Kategorileri listele
try {
    $kategoriler = $db->query("SELECT * FROM kategoriler ORDER BY kategori_adi")->fetchAll(PDO::FETCH_ASSOC);
} catch(PDOException $e) {
    error_log("Kategori listeleme hatası: " . $e->getMessage());
    die("Kategori listesi alınırken hata oluştu. Lütfen daha sonra tekrar deneyin.");
}

$csrf_token = csrf_token_olustur();
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= $sayfa_baslik ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container-xl">
        <div class="row mb-4">
            <div class="col-md-12">
                <h2><i class="bi bi-tags"></i> <?= $sayfa_baslik ?></h2>
                <hr>
            </div>
        </div>
        
        <?php if(isset($_SESSION['mesaj'])): ?>
            <div class="alert alert-success"><?= $_SESSION['mesaj'] ?></div>
            <?php unset($_SESSION['mesaj']); ?>
        <?php endif; ?>
        
        <?php if(isset($_SESSION['hata'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['hata'] ?></div>
            <?php unset($_SESSION['hata']); ?>
        <?php endif; ?>
        
        <div class="row mb-4">
            <div class="col-md-12">
                <div class="card shadow">
                    <div class="card-header">
                        <h5 class="card-title mb-0"><i class="bi bi-plus-circle"></i> Yeni Kategori Ekle</h5>
                    </div>
                    <div class="card-body">
                        <form method="post">
                            <input type="hidden" name="csrf_token" value="<?= $csrf_token ?>">
                            <div class="row">
                                <div class="col-md-8 mb-3">
                                    <label for="kategori_adi" class="form-label">Kategori Adı</label>
                                    <input type="text" class="form-control" id="kategori_adi" name="kategori_adi" required>
                                </div>
                                <div class="col-md-4 mb-3 d-flex align-items-end">
                                    <button type="submit" name="kategori_ekle" class="btn btn-primary w-100">
                                        <i class="bi bi-save"></i> Kaydet
                                    </button>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
        
        <div class="row">
            <div class="col-md-12">
                <div class="card shadow">
                    <div class="card-header">
                        <h5 class="card-title mb-0"><i class="bi bi-list-ul"></i> Kategori Listesi</h5>
                    </div>
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-hover">
                                <thead class="table-light">
                                    <tr>
                                        <th>Kategori Adı</th>
                                        <th>İşlemler</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach($kategoriler as $kategori): ?>
                                    <tr>
                                        <td><?= temizle($kategori['kategori_adi']) ?></td>
                                        <td>
                                            <a href="kategoriler.php?sil=<?= $kategori['id'] ?>&csrf_token=<?= $csrf_token ?>" 
                                               class="btn btn-sm btn-danger" 
                                               title="Sil" 
                                               onclick="return confirm('Bu kategoriyi silmek istediğinize emin misiniz?')">
                                                <i class="bi bi-trash"></i>
                                            </a>
                                        </td>
                                    </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
	<?php include("footer.php"); ?>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>