<?php
require_once 'config.php';

// Hata ayıklama başlangıcı
error_log("Login sayfasına erişim: " . date('Y-m-d H:i:s'));
error_log("POST verileri: " . print_r($_POST, true));

// Zaten giriş yapmışsa yönlendir
if(isset($_SESSION['kullanici_id'])) {
    header("Location: index.php");
    exit();
}

$hata = '';
$kullanici_adi = '';

if($_SERVER['REQUEST_METHOD'] == 'POST' && !empty($_POST['kullanici_adi']) && !empty($_POST['sifre'])) {
    $kullanici_adi = trim($_POST['kullanici_adi']);
    $sifre = $_POST['sifre'];

    // Hata ayıklama
    error_log("Giriş denemesi - Kullanıcı: " . $kullanici_adi);

    // Brute-force koruması
    if (!brute_force_kontrol()) {
        $hata = $_SESSION['hata'] ?? "Çok fazla hatalı giriş denemesi."; // Kontrol başarısızsa hata mesajını al
    } else {
        try {
            $stmt = $db->prepare("SELECT id, kullanici_adi, ad_soyad, sifre FROM kullanicilar WHERE kullanici_adi = ? AND aktif = 1");
            $stmt->execute([$kullanici_adi]);
            $kullanici = $stmt->fetch();

            if($kullanici) {
                error_log("Veritabanındaki hash: " . $kullanici['sifre']);

                if(password_verify($sifre, $kullanici['sifre'])) {
                    error_log("Şifre doğrulaması: Başarılı");

                    // Başarılı giriş
                    brute_force_reset(); // Başarılı girişte sayaçları sıfırla
                    session_regenerate_id(true); // Oturum ID'sini yenile

                    $_SESSION['kullanici_id'] = $kullanici['id'];
                    $_SESSION['kullanici_adi'] = $kullanici['kullanici_adi'];
                    $_SESSION['ad_soyad'] = $kullanici['ad_soyad'];
                    $_SESSION['login_time'] = time();
                    $_SESSION['user_agent'] = $_SERVER['HTTP_USER_AGENT'] ?? 'unknown';
                    $_SESSION['last_regen'] = time(); // Son yenileme zamanı

                    // Son giriş bilgilerini güncelle
                    $ip = $_SERVER['REMOTE_ADDR'];
                    $stmt = $db->prepare("UPDATE kullanicilar SET son_giris = NOW(), son_ip = ? WHERE id = ?");
                    $stmt->execute([$ip, $kullanici['id']]);

                    // Yönlendirme
                    $redirect = isset($_SESSION['login_redirect']) ? $_SESSION['login_redirect'] : 'index.php';
                    unset($_SESSION['login_redirect']);
                    header("Location: " . $redirect);
                    exit();
                } else {
                    error_log("Şifre doğrulaması: Başarısız");
                    brute_force_log_attempt(); // Başarısız denemeyi logla
                    $hata = "Kullanıcı adı veya şifre hatalı!";
                }
            } else {
                error_log("Kullanıcı bulunamadı");
                brute_force_log_attempt(); // Başarısız denemeyi logla
                $hata = "Kullanıcı adı veya şifre hatalı!";
            }

        } catch(PDOException $e) {
            error_log("Giriş hatası: " . $e->getMessage());
            $hata = "Sistem hatası oluştu. Lütfen daha sonra tekrar deneyin.";
        }
    }
} elseif($_SERVER['REQUEST_METHOD'] == 'POST') {
    $hata = "Kullanıcı adı ve şifre alanları boş bırakılamaz!";
}
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - Giriş</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
    <style>
        html, body {
            height: 100%;
        }

        body {
            display: flex;
            align-items: center;
            justify-content: center;
            padding-top: 40px;
            padding-bottom: 40px;
            background-color: #f8f9fa;
            background-image: linear-gradient(135deg, #f5f7fa 0%, #e4ecf9 100%);
        }

        .form-signin {
            width: 100%;
            max-width: 430px;
            padding: 35px;
            margin: auto;
            background-color: #fff;
            border: none;
            border-radius: 0.75rem;
            box-shadow: 0 0.5rem 1.5rem rgba(0, 0, 0, 0.15);
            transition: all 0.3s ease;
        }
        
        .form-signin:hover {
            box-shadow: 0 0.7rem 2rem rgba(0, 0, 0, 0.18);
        }

        .form-signin .form-floating:focus-within {
            z-index: 2;
        }

        .form-signin input[type="text"] {
            margin-bottom: -1px;
            border-bottom-right-radius: 0;
            border-bottom-left-radius: 0;
            border-width: 2px;
        }

        .form-signin input[type="password"] {
            margin-bottom: 15px;
            border-top-left-radius: 0;
            border-top-right-radius: 0;
            border-width: 2px;
            border-top: none;
        }

        .brand-header {
            text-align: center;
            margin-bottom: 2rem;
        }

        .brand-title {
            font-size: 2rem;
            font-weight: 700;
            color: #333;
            margin-bottom: 0.5rem;
            letter-spacing: -0.5px;
        }

        .brand-icon {
            font-size: 3.5rem;
            color: #0d6efd;
            margin-bottom: 1rem;
            display: inline-block;
            background: rgba(13, 110, 253, 0.1);
            width: 80px;
            height: 80px;
            line-height: 80px;
            border-radius: 50%;
            text-align: center;
        }

        .brand-subtitle {
            color: #6c757d;
            font-size: 1rem;
            font-weight: 500;
            margin-bottom: 1rem;
        }

        .btn-primary {
            padding: 0.8rem 1.2rem;
            font-weight: 600;
            border-radius: 0.5rem;
            box-shadow: 0 0.25rem 0.5rem rgba(13, 110, 253, 0.3);
            transition: all 0.2s ease;
        }
        
        .btn-primary:hover {
            transform: translateY(-2px);
            box-shadow: 0 0.35rem 0.7rem rgba(13, 110, 253, 0.4);
        }
        
        .btn-primary:active {
            transform: translateY(0);
        }

        .additional-links {
            margin-top: 1.5rem;
            text-align: center;
            font-size: 0.9rem;
        }
        
        .additional-links a {
            color: #0d6efd;
            text-decoration: none;
            font-weight: 500;
            transition: all 0.2s ease;
        }
        
        .additional-links a:hover {
            color: #0a58ca;
            text-decoration: underline;
        }
        
        .form-floating {
            margin-bottom: 1rem;
        }
        
        .form-floating label {
            color: #6c757d;
        }
        
        .form-control:focus {
            border-color: #0d6efd;
            box-shadow: 0 0 0 0.25rem rgba(13, 110, 253, 0.25);
        }
        
        .text-muted {
            font-size: 0.85rem;
        }
    </style>
</head>
<body>
    <main class="form-signin">
        <form method="post" autocomplete="off">
            <div class="brand-header">
                <i class="bi bi-shop brand-icon"></i>
                <h1 class="brand-title">Esnaf Yönetim</h1>
                <p class="brand-subtitle">İşletme Yönetim Paneli Girişi</p>
            </div>

            <?php if(isset($_GET['timeout'])): ?>
                <div class="alert alert-warning alert-dismissible fade show" role="alert">
                    <i class="bi bi-exclamation-triangle-fill me-2"></i> Oturum süreniz doldu. Lütfen tekrar giriş yapın.
                    <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                </div>
            <?php endif; ?>

            <?php if(isset($_GET['hacking'])): ?>
                <div class="alert alert-danger alert-dismissible fade show" role="alert">
                    <i class="bi bi-shield-exclamation me-2"></i> Güvenlik nedeniyle oturumunuz sonlandırıldı.
                    <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                </div>
            <?php endif; ?>

            <?php if($hata): ?>
                <div class="alert alert-danger alert-dismissible fade show" role="alert">
                    <i class="bi bi-exclamation-circle-fill me-2"></i> <?= htmlspecialchars($hata) ?>
                    <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                </div>
            <?php endif; ?>

            <div class="form-floating mb-2">
                <input type="text" class="form-control" id="kullanici_adi" name="kullanici_adi"
                    value="<?= htmlspecialchars($kullanici_adi) ?>" placeholder="Kullanıcı Adı" required autofocus>
                <label for="kullanici_adi"><i class="bi bi-person me-1"></i> Kullanıcı Adı</label>
            </div>
            <div class="form-floating mb-3">
                <input type="password" class="form-control" id="sifre" name="sifre"
                    placeholder="Şifre" required>
                <label for="sifre"><i class="bi bi-key me-1"></i> Şifre</label>
            </div>

            <button class="w-100 btn btn-lg btn-primary" type="submit">
                <i class="bi bi-box-arrow-in-right me-2"></i>Giriş Yap
            </button>

            <div class="additional-links">
                <a href="#"><i class="bi bi-question-circle me-1"></i>Şifremi Unuttum?</a>
            </div>

            <?php include("footer.php"); ?>
        </form>
    </main>
	
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>