<?php
require_once 'config.php';
yetkili_mi();

$sayfa_baslik = "Ödeme Yapma";

// Form gönderildiğinde
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (!csrf_token_dogrula($_POST['csrf_token'] ?? '')) {
        $_SESSION['hata'] = "Geçersiz form gönderimi!";
        header("Location: odeme_yap.php");
        exit();
    }

    // Form verilerini al
    $cari_id = filter_input(INPUT_POST, 'cari_id', FILTER_VALIDATE_INT); // Tedarikçi
    $hesap_id = filter_input(INPUT_POST, 'hesap_id', FILTER_VALIDATE_INT); // Para çıkan hesap
    $tutar_str = str_replace(',', '.', $_POST['tutar'] ?? '0');
    $tutar = filter_var($tutar_str, FILTER_VALIDATE_FLOAT);
    $aciklama = temizle($_POST['aciklama'] ?? '');
    $tarih = filter_input(INPUT_POST, 'tarih', FILTER_SANITIZE_SPECIAL_CHARS);
    $borc_id = filter_input(INPUT_POST, 'borc_id', FILTER_VALIDATE_INT); // Hangi alış borcuna karşılık? (Opsiyonel)
    $borc_id = empty($borc_id) ? null : $borc_id;
    $pesin_odendi = isset($_POST['pesin_odendi']) && $_POST['pesin_odendi'] == '1';
	
	
    // Veri doğrulama
    $hatalar = [];
    if (empty($cari_id)) $hatalar[] = "Ödeme yapılacak cari (Tedarikçi) seçimi zorunludur.";
    if ($pesin_odendi && empty($hesap_id)) $hatalar[] = "Peşin ödeme için hesap seçimi zorunludur.";
    if ($tutar === false || $tutar <= 0) $hatalar[] = "Geçerli bir tutar giriniz (0'dan büyük).";
    if (empty($tarih) || !preg_match("/^\d{4}-\d{2}-\d{2}$/", $tarih)) $hatalar[] = "Geçerli bir ödeme tarihi giriniz (YYYY-AA-GG).";
    if (!empty($borc_id) && $borc_id <= 0) $hatalar[] = "Geçersiz borç referansı.";
    $borc_id = empty($borc_id) ? null : $borc_id;

    // Hesapta yeterli bakiye var mı kontrolü
    if ($pesin_odendi && !empty($hesap_id)) {
        $stmt_bakiye = $db->prepare("SELECT bakiye FROM hesaplar WHERE id = ?");
        $stmt_bakiye->execute([$hesap_id]);
        $hesap_bakiye = $stmt_bakiye->fetchColumn();
        
        if ($hesap_bakiye === false || $hesap_bakiye < $tutar) {
            $hatalar[] = "Ödeme yapılacak hesapta yeterli bakiye yok! (Mevcut: ".number_format($hesap_bakiye ?: 0, 2, ',', '.')." ₺)";
        }
    }


     if (empty($hatalar)) {
        try {
            $db->beginTransaction();

            // 1. Hesap bakiyesini düşür
            if (!hesapBakiyeGuncelle($db, $hesap_id, -$tutar)) { // Negatif değer
                 throw new Exception("Hesap bakiyesi güncellenemedi.");
            }

            // 2. Hesap hareketi ekle ('cikis' olarak)
            $hareket_aciklama = "Ödeme: " . $aciklama;
            if ($borc_id) {
                 $hareket_aciklama .= " (Alış No: #{$borc_id})";
            }
            if (!hesapHareketiEkle($db, $hesap_id, 'cikis', $tutar, $hareket_aciklama, $cari_id, $borc_id)) {
                throw new Exception("Hesap hareketi eklenemedi.");
            }

            // 3. Cari'ye olan borcumuzu azalt (toplam_alacak azalır)
            if (!cariBakiyeGuncelle($db, $cari_id, 0.0, -$tutar)) { // Alacak azalıyor
                 throw new Exception("Cari bakiyesi güncellenemedi.");
            }

            // 4. EĞER BELİRLİ BİR BORCA (ALIŞA) KARŞILIK ÖDEME YAPILDIYSA, BORCU GÜNCELLE
            if ($borc_id) {
                // Önce mevcut borç bilgilerini al
                $stmt_borc_get = $db->prepare("SELECT tutar, odenen_tutar FROM borclar WHERE id = ? AND tur = 'alis'");
                $stmt_borc_get->execute([$borc_id]);
                $mevcut_borc = $stmt_borc_get->fetch();

                if ($mevcut_borc) {
                    $yeni_odenen_tutar = ($mevcut_borc['odenen_tutar'] ?? 0.0) + $tutar;
                    $kalan_borc = $mevcut_borc['tutar'] - $yeni_odenen_tutar;

                    // Yeni durumu belirle
                    $yeni_durum = 'kismen_odendi';
                     if ($kalan_borc <= 0.01) { // Küçük kuruş farklarını tolere et
                        $yeni_durum = 'odendi';
                         $yeni_odenen_tutar = $mevcut_borc['tutar']; // Tam ödendiyse eşitle
                    }

                    // Borç kaydını güncelle
                    $stmt_borc_update = $db->prepare("UPDATE borclar SET odenen_tutar = ?, durum = ? WHERE id = ?");
                    if (!$stmt_borc_update->execute([$yeni_odenen_tutar, $yeni_durum, $borc_id])) {
                         throw new Exception("İlişkili alış kaydı ödeme durumu güncellenemedi.");
                    }
                } else {
                    error_log("Ödeme Yapma: İlişkili alış kaydı bulunamadı veya türü yanlış (Borc ID: {$borc_id}). Cari bakiye güncellendi.");
                }
            }
            // ---- Bitiş: Borç Güncelleme ----

            $db->commit();
            $_SESSION['mesaj'] = "Ödeme başarıyla kaydedildi.";
            header("Location: odeme_yap.php");
            exit();

        } catch (Exception $e) {
            $db->rollBack();
            error_log("Ödeme yapma hatası: " . $e->getMessage());
            $_SESSION['hata'] = "Ödeme yapılırken bir hata oluştu: " . $e->getMessage();
            $_SESSION['form_verileri_odeme_yap'] = $_POST;
            header("Location: odeme_yap.php");
            exit();
        }
    } else {
         $_SESSION['form_hatalari_odeme_yap'] = $hatalar;
         $_SESSION['form_verileri_odeme_yap'] = $_POST;
         header("Location: odeme_yap.php");
         exit();
    }
}

// Formu göstermek için carileri, hesapları ve ödenmemiş alış borçlarını getir
try {
    $cariler = $db->query("SELECT id, ad_soyad FROM cariler ORDER BY ad_soyad")->fetchAll(PDO::FETCH_ASSOC);
    $hesaplar = $db->query("SELECT id, hesap_adi, bakiye FROM hesaplar ORDER BY hesap_adi")->fetchAll(PDO::FETCH_ASSOC);

    // Sadece durumu 'odendi' OLMAYAN 'alis' türündeki borçları listele
    $odenmemis_alislar = $db->query("
        SELECT b.id, b.tarih, b.tutar, b.odenen_tutar, b.aciklama, c.ad_soyad
        FROM borclar b
        JOIN cariler c ON b.cari_id = c.id
        WHERE b.tur = 'alis' AND b.durum != 'odendi'
        ORDER BY c.ad_soyad, b.tarih DESC
    ")->fetchAll(PDO::FETCH_ASSOC);

} catch (PDOException $e) {
    error_log("Ödeme Yapma sayfası veri çekme hatası: " . $e->getMessage());
    $_SESSION['hata'] = "Gerekli veriler yüklenirken bir hata oluştu.";
    $cariler = []; $hesaplar = []; $odenmemis_alislar = [];
}

// URL'den cari_id parametresini kontrol et
$url_cari_id = filter_input(INPUT_GET, 'cari_id', FILTER_VALIDATE_INT);

$csrf_token = csrf_token_olustur();
$form_hatalari = $_SESSION['form_hatalari_odeme_yap'] ?? [];
$form_verileri = $_SESSION['form_verileri_odeme_yap'] ?? [];

// Eğer URL'den cari_id geldiyse ve form verileri yoksa (ilk yükleme) cari_id'yi ayarla
if ($url_cari_id && empty($form_verileri)) {
    $form_verileri['cari_id'] = $url_cari_id;
}

unset($_SESSION['form_hatalari_odeme_yap'], $_SESSION['form_verileri_odeme_yap']);
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= temizle($sayfa_baslik) ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container mt-4">
        <h2><i class="bi bi-arrow-up-circle"></i> <?= temizle($sayfa_baslik) ?></h2>
        <hr>

         <?php if (!empty($form_hatalari)): ?>
             <div class="alert alert-danger alert-dismissible fade show" role="alert">
                <strong><i class="bi bi-exclamation-triangle-fill me-2"></i> Lütfen hataları düzeltin:</strong>
                <ul>
                    <?php foreach ($form_hatalari as $hata): ?>
                        <li><?= htmlspecialchars($hata) ?></li>
                    <?php endforeach; ?>
                </ul>
                 <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <form method="post">
            <input type="hidden" name="csrf_token" value="<?= $csrf_token ?>">
             <div class="card shadow-sm">
                 <div class="card-body">
                     <div class="row g-3">
                        <div class="col-md-6">
                            <label for="cari_arama" class="form-label">Tedarikçi (Cari) <span class="text-danger">*</span></label>
                            <div class="input-group">
                                <input type="text" class="form-control" id="cari_arama" placeholder="Cari adı yazın..." autocomplete="off">
                                <button type="button" class="btn btn-outline-primary" data-bs-toggle="modal" data-bs-target="#yeniCariModal">
                                    <i class="bi bi-plus-circle"></i> Yeni Cari
                                </button>
                            </div>
                            <div id="cariSonuclar" class="list-group position-absolute w-75 shadow-sm" style="z-index: 1000; display: none; max-height: 200px; overflow-y: auto;"></div>
                            <input type="hidden" id="cari_id" name="cari_id" value="<?= htmlspecialchars($form_verileri['cari_id'] ?? '') ?>" required>
                            <div id="seciliCari" class="form-text mt-2">
                                <?php if (isset($form_verileri['cari_id']) && !empty($form_verileri['cari_id'])): 
                                    $secili_cari_id = $form_verileri['cari_id'];
                                    $secili_cari = array_filter($cariler, function($c) use ($secili_cari_id) { 
                                        return $c['id'] == $secili_cari_id; 
                                    });
                                    $secili_cari = reset($secili_cari);
                                    if ($secili_cari): ?>
                                        <span class="badge bg-primary">
                                            <?= temizle($secili_cari['ad_soyad']) ?>
                                            <i class="bi bi-check-circle-fill ms-1"></i>
                                        </span>
                                    <?php endif; ?>
                                <?php else: ?>
                                    <span class="text-muted">Henüz cari seçilmedi</span>
                                <?php endif; ?>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <label class="form-label">Ödeme Durumu</label>
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" value="1" id="pesin_odendi" name="pesin_odendi"
                                       <?= (isset($form_verileri['pesin_odendi']) && $form_verileri['pesin_odendi'] == '1') ? 'checked' : '' ?>>
                                <label class="form-check-label" for="pesin_odendi">
                                    Ödeme peşin yapıldı mı?
                                </label>
                            </div>
                        </div>
                        <div id="pesin_alanlar" class="col-md-6 <?= !(isset($form_verileri['pesin_odendi']) && $form_verileri['pesin_odendi'] == '1') ? 'hidden' : '' ?>">
                            <label for="hesap_id" class="form-label">Ödemenin Yapılacağı Hesap <span class="text-danger">*</span></label>
                            <select class="form-select" id="hesap_id" name="hesap_id">
                                <option value="">-- Hesap Seçin --</option>
                                <?php foreach ($hesaplar as $hesap): ?>
                                    <option value="<?= $hesap['id'] ?>" <?= (isset($form_verileri['hesap_id']) && $form_verileri['hesap_id'] == $hesap['id']) ? 'selected' : '' ?>>
                                        <?= temizle($hesap['hesap_adi']) ?> (<?= number_format($hesap['bakiye'], 2, ',', '.') ?> ₺)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="col-md-6">
                            <label for="tutar" class="form-label">Ödenecek Tutar (₺) <span class="text-danger">*</span></label>
                            <input type="text" inputmode="decimal" class="form-control" id="tutar" name="tutar" required
                                    value="<?= htmlspecialchars($form_verileri['tutar'] ?? '', ENT_QUOTES) ?>">
                        </div>
                        <div class="col-md-6">
                            <label for="tarih" class="form-label">Ödeme Tarihi <span class="text-danger">*</span></label>
                            <input type="date" class="form-control" id="tarih" name="tarih" required
                                   value="<?= htmlspecialchars($form_verileri['tarih'] ?? date('Y-m-d'), ENT_QUOTES) ?>">
                        </div>
                         <div class="col-md-12">
                            <label for="borc_id" class="form-label">Hangi Alışa Karşılık? (Opsiyonel)</label>
                            <select class="form-select" id="borc_id" name="borc_id">
                                <option value="">-- Genel Ödeme / Seçiniz --</option>
                                <?php foreach ($odenmemis_alislar as $borc):
                                    $kalan = $borc['tutar'] - $borc['odenen_tutar'];
                                ?>
                                <option value="<?= $borc['id'] ?>" <?= (isset($form_verileri['borc_id']) && $form_verileri['borc_id'] == $borc['id']) ? 'selected' : '' ?>>
                                    <?= temizle($borc['ad_soyad']) ?> - <?= date('d.m.Y', strtotime($borc['tarih'])) ?> - Kalan: <?= number_format($kalan, 2, ',', '.') ?> ₺ (ID: <?= $borc['id'] ?>)
                                </option>
                                <?php endforeach; ?>
                            </select>
                             <small class="text-muted">Bir alış seçerseniz, ödeme o alışla ilişkilendirilir ve kalan borcu azaltır.</small>
                        </div>
                        <div class="col-12">
                            <label for="aciklama" class="form-label">Açıklama</label>
                            <textarea class="form-control" id="aciklama" name="aciklama" rows="2"><?= htmlspecialchars($form_verileri['aciklama'] ?? '', ENT_QUOTES) ?></textarea>
                        </div>
                        <div class="col-12">
                            <button type="submit" class="btn btn-danger">
                                <i class="bi bi-send-check me-2"></i> Ödemeyi Kaydet
                            </button>
                        </div>
                     </div>
                 </div>
             </div>
        </form>
    </div>
	<?php include("footer.php"); ?>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    
    <!-- Yeni Cari Ekleme Modal -->
    <div class="modal fade" id="yeniCariModal" tabindex="-1" aria-labelledby="yeniCariModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="yeniCariModalLabel">Yeni Cari Ekle</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <form id="yeniCariForm">
                        <div class="mb-3">
                            <label for="yeni_ad_soyad" class="form-label">Ad Soyad / Firma Adı <span class="text-danger">*</span></label>
                            <input type="text" class="form-control" id="yeni_ad_soyad" required>
                        </div>
                        <div class="mb-3">
                            <label for="yeni_telefon" class="form-label">Telefon</label>
                            <input type="tel" class="form-control" id="yeni_telefon">
                        </div>
                        <div class="mb-3">
                            <label for="yeni_eposta" class="form-label">E-posta</label>
                            <input type="email" class="form-control" id="yeni_eposta">
                        </div>
                        <div class="mb-3">
                            <label for="yeni_adres" class="form-label">Adres</label>
                            <textarea class="form-control" id="yeni_adres" rows="2"></textarea>
                        </div>
                    </form>
                    <div id="cariEkleMessage" class="alert d-none"></div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">İptal</button>
                    <button type="button" class="btn btn-primary" id="cariEkleBtn">
                        <i class="bi bi-plus-circle me-1"></i> Cari Ekle
                    </button>
                </div>
            </div>
        </div>
    </div>
    
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const pesinCheckbox = document.getElementById('pesin_odendi');
            const pesinAlanlar = document.getElementById('pesin_alanlar');
            const hesapInput = document.getElementById('hesap_id');

            function toggleAlanlar() {
                if (pesinCheckbox.checked) {
                    pesinAlanlar.classList.remove('hidden');
                    hesapInput.required = true;
                } else {
                    pesinAlanlar.classList.add('hidden');
                    hesapInput.required = false;
                }
            }

            pesinCheckbox.addEventListener('change', toggleAlanlar);
            toggleAlanlar();
            
            // Cari arama ve otomatik tamamlama
            const cariArama = document.getElementById('cari_arama');
            const cariSonuclar = document.getElementById('cariSonuclar');
            const cariIdInput = document.getElementById('cari_id');
            const seciliCariDiv = document.getElementById('seciliCari');
            
            // Tüm carileri JavaScript dizisine aktar
            const cariler = [
                <?php foreach ($cariler as $cari): ?>
                {id: <?= $cari['id'] ?>, ad_soyad: "<?= addslashes(temizle($cari['ad_soyad'])) ?>"},
                <?php endforeach; ?>
            ];
            
            // URL'den veya form verilerinden seçili cari varsa, arama kutusuna adını yaz
            <?php if (isset($form_verileri['cari_id']) && !empty($form_verileri['cari_id'])): ?>
                const seciliCariId = <?= $form_verileri['cari_id'] ?>;
                const seciliCari = cariler.find(c => c.id === seciliCariId);
                if (seciliCari) {
                    cariArama.value = seciliCari.ad_soyad;
                }
            <?php endif; ?>
            
            cariArama.addEventListener('input', function() {
                const aramaTermi = this.value.toLowerCase().trim();
                
                if (aramaTermi.length < 2) {
                    cariSonuclar.style.display = 'none';
                    return;
                }
                
                // Arama terimine göre filtreleme
                const filtrelenmisCariler = cariler.filter(cari => 
                    cari.ad_soyad.toLowerCase().includes(aramaTermi)
                );
                
                // Sonuçları göster
                cariSonuclar.innerHTML = '';
                
                if (filtrelenmisCariler.length === 0) {
                    const sonucYok = document.createElement('a');
                    sonucYok.className = 'list-group-item list-group-item-action disabled';
                    sonucYok.textContent = `"${aramaTermi}" için sonuç bulunamadı`;
                    cariSonuclar.appendChild(sonucYok);
                } else {
                    filtrelenmisCariler.forEach(cari => {
                        const sonucItem = document.createElement('a');
                        sonucItem.className = 'list-group-item list-group-item-action';
                        sonucItem.textContent = cari.ad_soyad;
                        sonucItem.href = '#';
                        sonucItem.addEventListener('click', function(e) {
                            e.preventDefault();
                            cariSec(cari.id, cari.ad_soyad);
                        });
                        cariSonuclar.appendChild(sonucItem);
                    });
                }
                
                cariSonuclar.style.display = 'block';
            });
            
            // Cari seçme fonksiyonu
            function cariSec(id, adSoyad) {
                cariIdInput.value = id;
                cariArama.value = adSoyad;
                seciliCariDiv.innerHTML = `<span class="badge bg-primary">${adSoyad} <i class="bi bi-check-circle-fill ms-1"></i></span>`;
                cariSonuclar.style.display = 'none';
            }
            
            // Dışarı tıklandığında sonuçları gizle
            document.addEventListener('click', function(e) {
                if (e.target !== cariArama && e.target !== cariSonuclar) {
                    cariSonuclar.style.display = 'none';
                }
            });
            
            // Cari arama kutusuna tekrar tıklandığında sonuçları göster
            cariArama.addEventListener('click', function() {
                if (this.value.length >= 2) {
                    cariSonuclar.style.display = 'block';
                }
            });
            
            // Cari arama kutusundan çıkıldığında, eğer geçerli bir cari seçilmediyse değeri temizle
            cariArama.addEventListener('blur', function() {
                setTimeout(() => {
                    if (!cariIdInput.value) {
                        this.value = '';
                        seciliCariDiv.innerHTML = '<span class="text-muted">Henüz cari seçilmedi</span>';
                    }
                }, 200); // Tıklama işleminin tamamlanması için kısa bir gecikme
            });
            
            // Yeni cari ekleme işlemi
            const cariEkleBtn = document.getElementById('cariEkleBtn');
            const cariEkleMessage = document.getElementById('cariEkleMessage');
            
            cariEkleBtn.addEventListener('click', function() {
                // Form verilerini al
                const adSoyad = document.getElementById('yeni_ad_soyad').value.trim();
                const telefon = document.getElementById('yeni_telefon').value.trim();
                const eposta = document.getElementById('yeni_eposta').value.trim();
                const adres = document.getElementById('yeni_adres').value.trim();
                
                // Basit doğrulama
                if (!adSoyad) {
                    showMessage('Lütfen ad soyad / firma adı giriniz.', 'danger');
                    return;
                }
                
                // Yükleniyor durumu
                cariEkleBtn.disabled = true;
                cariEkleBtn.innerHTML = '<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Ekleniyor...';
                
                // AJAX isteği
                fetch('cari_ekle_ajax.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: `ad_soyad=${encodeURIComponent(adSoyad)}&telefon=${encodeURIComponent(telefon)}&eposta=${encodeURIComponent(eposta)}&adres=${encodeURIComponent(adres)}`
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        // Başarılı mesajı göster
                        showMessage(data.message, 'success');
                        
                        // Yeni cariyi listeye ekle ve seç
                        const yeniCari = {id: parseInt(data.cari_id), ad_soyad: adSoyad};
                        cariler.push(yeniCari);
                        cariSec(yeniCari.id, yeniCari.ad_soyad);
                        
                        // Formu sıfırla
                        document.getElementById('yeniCariForm').reset();
                        
                        // 2 saniye sonra modalı kapat
                        setTimeout(() => {
                            const modal = bootstrap.Modal.getInstance(document.getElementById('yeniCariModal'));
                            modal.hide();
                            cariEkleMessage.classList.add('d-none');
                        }, 2000);
                    } else {
                        showMessage(data.message || 'Cari eklenirken bir hata oluştu.', 'danger');
                    }
                })
                .catch(error => {
                    console.error('Hata:', error);
                    showMessage('Bir hata oluştu. Lütfen tekrar deneyin.', 'danger');
                })
                .finally(() => {
                    // Buton durumunu sıfırla
                    cariEkleBtn.disabled = false;
                    cariEkleBtn.innerHTML = '<i class="bi bi-plus-circle me-1"></i> Cari Ekle';
                });
            });
            
            function showMessage(message, type) {
                cariEkleMessage.textContent = message;
                cariEkleMessage.className = `alert alert-${type}`;
                cariEkleMessage.classList.remove('d-none');
            }
        });
    </script>
</body>
</html>
