<?php
// Gerekli dosyaları ve ayarları dahil et
require_once 'config.php'; 
// Kullanıcının yetkili olup olmadığını kontrol et (Bu fonksiyonun tanımlı olduğunu varsayıyoruz)
yetkili_mi(); 

// Sayfa başlığını ayarla
$sayfa_baslik = "Profil Yönetimi";
// Mesaj ve hata değişkenlerini başlangıçta boş olarak ayarla
$mesaj = '';
$hata = '';
// Kullanıcı bilgilerini tutacak dizi
$kullanici = [];

// Oturumda mesaj varsa al ve temizle
if(isset($_SESSION['mesaj'])) {
    $mesaj = $_SESSION['mesaj'];
    unset($_SESSION['mesaj']);
}

// Veritabanından mevcut kullanıcı bilgilerini çek
try {
    // Oturumdaki kullanıcı ID'sine göre kullanıcıyı seçmek için sorgu hazırla
    $stmt = $db->prepare("SELECT id, ad_soyad, kullanici_adi, sifre FROM kullanicilar WHERE id = ?");
    // Sorguyu oturumdaki kullanıcı ID'si ile çalıştır
    $stmt->execute([$_SESSION['kullanici_id']]);
    // Sonucu ilişkisel dizi olarak al
    $kullanici = $stmt->fetch(PDO::FETCH_ASSOC);

    // Kullanıcı bulunamazsa hata ver (Normalde yetkili_mi kontrolü bunu engellemeli)
    if (!$kullanici) {
        die("Kullanıcı bulunamadı!");
    }
} catch(PDOException $e) {
    // Veritabanı hatası olursa işlemi durdur ve hata mesajını göster
    die("Veritabanı hatası: " . $e->getMessage());
}

// --- Form İşlemleri ---

// Eğer istek POST metodu ile geldiyse ve 'bilgi_guncelle' butonu tıklandıysa
if($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['bilgi_guncelle'])) {
    // CSRF token kontrolü yap
    if(!csrf_token_dogrula($_POST['csrf_token'])) {
        die("Geçersiz CSRF token!");
    }
    
    // Formdan gelen ad_soyad ve kullanici_adi değerlerini temizle (temizle fonksiyonu varsayılıyor)
    $ad_soyad = temizle($_POST['ad_soyad']);
    $kullanici_adi = temizle($_POST['kullanici_adi']);
    
    // Ad Soyad ve Kullanıcı Adı boş olamaz kontrolü
    if (empty($ad_soyad) || empty($kullanici_adi)) {
        $hata = "Ad Soyad ve Kullanıcı Adı boş bırakılamaz!";
    } else {
        // Bilgileri güncellemek için veritabanı işlemi
        try {
            // Kullanıcı bilgilerini güncellemek için sorgu hazırla
            $stmt = $db->prepare("UPDATE kullanicilar SET ad_soyad = ?, kullanici_adi = ? WHERE id = ?");
            // Sorguyu yeni bilgiler ve kullanıcı ID'si ile çalıştır
            $stmt->execute([$ad_soyad, $kullanici_adi, $_SESSION['kullanici_id']]);
            
            // Başarı mesajını oturuma kaydet ve sayfayı yeniden yükle
            $_SESSION['mesaj'] = "Bilgileriniz başarıyla güncellendi!";
            header("Location: profil.php");
            exit();
        } catch(PDOException $e) {
            // Güncelleme sırasında hata olursa hata mesajını ayarla
            // Kullanıcı adının benzersiz olması gibi durumlar için özel hata kontrolü eklenebilir (örn: $e->getCode() == 23000)
            if ($e->getCode() == 23000) { // Benzersizlik kısıtlaması hatası (örnek)
                 $hata = "Bu kullanıcı adı zaten kullanılıyor. Lütfen farklı bir kullanıcı adı seçin.";
            } else {
                 $hata = "Bilgi güncelleme sırasında bir hata oluştu: " . $e->getMessage();
            }
        }
    }
}

// Eğer istek POST metodu ile geldiyse ve 'sifre_guncelle' butonu tıklandıysa
if($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['sifre_guncelle'])) {
    // CSRF token kontrolü yap
    if(!csrf_token_dogrula($_POST['csrf_token'])) {
        die("Geçersiz CSRF token!");
    }
    
    // Formdan gelen şifreleri al
    $eski_sifre = $_POST['eski_sifre'];
    $yeni_sifre = $_POST['yeni_sifre'];
    $yeni_sifre_tekrar = $_POST['yeni_sifre_tekrar'];
    
    // --- Şifre Doğrulamaları ---
    // Eski şifre veritabanındaki hash ile uyuşmuyor mu kontrol et
    if (!password_verify($eski_sifre, $kullanici['sifre'])) {
        $hata = "Girilen eski şifre hatalı!";
    // Yeni şifreler birbiriyle uyuşmuyor mu kontrol et
    } elseif ($yeni_sifre !== $yeni_sifre_tekrar) {
        $hata = "Yeni şifreler birbiriyle uyuşmuyor!";
    // Yeni şifre yeterince uzun mu kontrol et (örneğin en az 6 karakter)
    } elseif (strlen($yeni_sifre) < 6) {
        $hata = "Yeni şifre en az 6 karakter uzunluğunda olmalıdır!";
    // Tüm doğrulamalar başarılıysa şifreyi güncelle
    } else {
        try {
            // Yeni şifreyi güvenli bir şekilde hash'le
            $yeni_sifre_hash = password_hash($yeni_sifre, PASSWORD_DEFAULT);
            // Şifreyi güncellemek için sorgu hazırla
            $stmt = $db->prepare("UPDATE kullanicilar SET sifre = ? WHERE id = ?");
            // Sorguyu yeni hash ve kullanıcı ID'si ile çalıştır
            $stmt->execute([$yeni_sifre_hash, $_SESSION['kullanici_id']]);
            
            // Başarı mesajını oturuma kaydet ve sayfayı yeniden yükle
            $_SESSION['mesaj'] = "Şifreniz başarıyla değiştirildi!";
            header("Location: profil.php");
            exit();
        } catch(PDOException $e) {
            // Şifre güncelleme sırasında hata olursa hata mesajını ayarla
            $hata = "Şifre değiştirme sırasında bir hata oluştu: " . $e->getMessage();
        }
    }
}

// Yeni bir CSRF token oluştur
$csrf_token = csrf_token_olustur(); 
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= htmlspecialchars($sayfa_baslik) // XSS önlemi ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-T3c6CoIi6uLrA9TneNEoa7RxnatzjcDSCmG1MXxSR1GAsXEV/Dwwykc2MPK8M2HN" crossorigin="anonymous">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.min.css">
    <style>
        body {
            background-color: #f8f9fa; /* Hafif gri arka plan */
        }
        .card {
            border: none; /* Kart kenarlıklarını kaldır */
            border-radius: 0.75rem; /* Daha yuvarlak köşeler */
        }
        .card-header {
            border-top-left-radius: 0.75rem;
            border-top-right-radius: 0.75rem;
            font-weight: 500; /* Başlık fontunu biraz kalınlaştır */
        }
        .btn i {
            margin-right: 0.5rem; /* Buton ikonları ile yazı arasına boşluk */
        }
        /* Başarı ve Hata mesajları için stil */
        .alert {
             border-radius: 0.5rem;
        }
    </style>
</head>
<body>
    <?php include 'navbar.php'; // Navbar'ı dahil et ?>

    <div class="container py-5">
        <h2 class="text-center mb-4"><?= htmlspecialchars($sayfa_baslik) ?></h2>

        <?php if (!empty($mesaj)): ?>
            <div class="alert alert-success alert-dismissible fade show shadow-sm" role="alert">
                <i class="bi bi-check-circle-fill me-2"></i><?= htmlspecialchars($mesaj) ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>
        
        <?php if (!empty($hata)): ?>
            <div class="alert alert-danger alert-dismissible fade show shadow-sm" role="alert">
                <i class="bi bi-exclamation-triangle-fill me-2"></i><?= htmlspecialchars($hata) ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <div class="row justify-content-center g-4"> 
            <div class="col-lg-6">
                <div class="card shadow-sm">
                    <div class="card-header bg-primary text-white">
                        <h5 class="mb-0"><i class="bi bi-person-lines-fill"></i> Genel Bilgiler</h5>
                    </div>
                    <div class="card-body p-4">
                        <form method="post" action="profil.php">
                            <input type="hidden" name="csrf_token" value="<?= $csrf_token ?>">
                            
                            <div class="mb-3">
                                <label for="ad_soyad" class="form-label">Ad Soyad</label>
                                <input type="text" class="form-control" id="ad_soyad" 
                                       name="ad_soyad" 
                                       value="<?= htmlspecialchars($kullanici['ad_soyad'] ?? '') // Değer yoksa boş göster ?>" 
                                       required>
                            </div>

                            <div class="mb-3">
                                <label for="kullanici_adi" class="form-label">Kullanıcı Adı</label>
                                <input type="text" class="form-control" id="kullanici_adi" 
                                       name="kullanici_adi" 
                                       value="<?= htmlspecialchars($kullanici['kullanici_adi'] ?? '') ?>" 
                                       required>
                            </div>

                            <div class="d-grid">
                                <button type="submit" name="bilgi_guncelle" class="btn btn-primary btn-lg">
                                    <i class="bi bi-save"></i> Bilgileri Güncelle
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>

            <div class="col-lg-6">
                <div class="card shadow-sm">
                    <div class="card-header bg-warning text-dark">
                         <h5 class="mb-0"><i class="bi bi-shield-lock-fill"></i> Şifre Değiştir</h5>
                    </div>
                    <div class="card-body p-4">
                        <form method="post" action="profil.php">
                            <input type="hidden" name="csrf_token" value="<?= $csrf_token ?>">
                            
                            <div class="mb-3">
                                <label for="eski_sifre" class="form-label">Eski Şifre</label>
                                <input type="password" class="form-control" id="eski_sifre" 
                                       name="eski_sifre" required>
                            </div>

                            <div class="mb-3">
                                <label for="yeni_sifre" class="form-label">Yeni Şifre</label>
                                <input type="password" class="form-control" id="yeni_sifre" 
                                       name="yeni_sifre" minlength="6" required>
                                <div class="form-text">Şifreniz en az 6 karakter olmalıdır.</div>
                            </div>

                            <div class="mb-3">
                                <label for="yeni_sifre_tekrar" class="form-label">Yeni Şifre (Tekrar)</label>
                                <input type="password" class="form-control" id="yeni_sifre_tekrar" 
                                       name="yeni_sifre_tekrar" minlength="6" required>
                            </div>

                            <div class="d-grid">
                                <button type="submit" name="sifre_guncelle" class="btn btn-warning btn-lg">
                                    <i class="bi bi-key-fill"></i> Şifreyi Değiştir
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div> </div> 
		<?php include("footer.php"); ?>
		<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/js/bootstrap.bundle.min.js" integrity="sha384-C6RzsynM9kWDrMNeT87bh95OGNyZPhcTNXj1NW7RuBCsyN/o0jlpcV8Qyq46cDfL" crossorigin="anonymous"></script>
</body>
</html>
