<?php
require_once 'config.php';
yetkili_mi();

$sayfa_baslik = "Raporlar";

// Tarih aralığı filtreleme için varsayılan değerler
$baslangic_tarihi = isset($_GET['baslangic_tarihi']) ? $_GET['baslangic_tarihi'] : date('Y-m-01'); // Ayın başı
$bitis_tarihi = isset($_GET['bitis_tarihi']) ? $_GET['bitis_tarihi'] : date('Y-m-d'); // Bugün

// Kategori bazında borç raporu
try {
    // Tarih aralığına göre filtrelenmiş kategori borçları
    $stmt_kategori = $db->prepare("
        SELECT k.kategori_adi, COALESCE(SUM(b.tutar), 0) as toplam_borc
        FROM kategoriler k
        LEFT JOIN borclar b ON k.id = b.kategori_id AND b.tarih BETWEEN ? AND ?
        GROUP BY k.kategori_adi
        ORDER BY toplam_borc DESC
    ");
    $stmt_kategori->execute([$baslangic_tarihi, $bitis_tarihi]);
    $kategori_borclari = $stmt_kategori->fetchAll(PDO::FETCH_ASSOC);
    
    // Cari grup bazında bakiye raporu
    $grup_bakiyeleri = $db->query("
        SELECT g.grup_adi, COALESCE(SUM(c.bakiye), 0) as toplam_bakiye
        FROM cari_gruplari g
        LEFT JOIN cariler c ON g.id = c.grup_id
        GROUP BY g.grup_adi
        ORDER BY toplam_bakiye DESC
    ")->fetchAll(PDO::FETCH_ASSOC);
    
    // Aylık gelir-gider raporu
    $stmt_gelir_gider = $db->prepare("
        SELECT 
            SUM(CASE WHEN h.tur = 'giris' THEN h.tutar ELSE 0 END) as toplam_gelir,
            SUM(CASE WHEN h.tur = 'cikis' THEN h.tutar ELSE 0 END) as toplam_gider
        FROM hesap_hareketleri h
        WHERE h.tarih BETWEEN ? AND ?
    ");
    $stmt_gelir_gider->execute([$baslangic_tarihi, $bitis_tarihi]);
    $gelir_gider = $stmt_gelir_gider->fetch(PDO::FETCH_ASSOC);
    
    // Hesap bazında bakiye raporu
    $hesap_bakiyeleri = $db->query("
        SELECT h.hesap_adi, h.bakiye, h.hesap_turu
        FROM hesaplar h
        ORDER BY h.bakiye DESC
    ")->fetchAll(PDO::FETCH_ASSOC);
    
    // Vadesi geçmiş borç/alacak raporu
    $bugun = date('Y-m-d');
    $stmt_vadesi_gecmis = $db->prepare("
        SELECT 
            b.id, b.tur, b.tutar, b.tarih, b.vade_tarihi, b.aciklama,
            c.ad_soyad as cari_adi
        FROM borclar b
        JOIN cariler c ON b.cari_id = c.id
        WHERE b.vade_tarihi < ? AND b.durum != 'odendi'
        ORDER BY b.vade_tarihi ASC
    ");
    $stmt_vadesi_gecmis->execute([$bugun]);
    $vadesi_gecmis = $stmt_vadesi_gecmis->fetchAll(PDO::FETCH_ASSOC);
    
} catch(PDOException $e) {
    error_log("Rapor hatası: " . $e->getMessage());
    die("Raporlar alınırken hata oluştu. Lütfen daha sonra tekrar deneyin.");
}
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= $sayfa_baslik ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container-xl">
        <div class="row mb-4">
            <div class="col-md-12">
                <h2><i class="bi bi-graph-up"></i> <?= $sayfa_baslik ?></h2>
                <div class="d-flex justify-content-between align-items-center">
                    <hr class="flex-grow-1 me-3">
                    <a href="pdf_export.php?type=raporlar&baslangic_tarihi=<?= $baslangic_tarihi ?>&bitis_tarihi=<?= $bitis_tarihi ?>" class="btn btn-sm btn-outline-primary">
                        <i class="bi bi-file-pdf"></i> PDF İndir
                    </a>
                </div>
                
                <!-- Tarih Aralığı Filtreleme -->
                <div class="card shadow-sm mb-4">
                    <div class="card-header">
                        <h5 class="card-title mb-0"><i class="bi bi-calendar-range"></i> Tarih Aralığı Filtreleme</h5>
                    </div>
                    <div class="card-body">
                        <form method="get" class="row g-3">
                            <div class="col-md-4">
                                <label for="baslangic_tarihi" class="form-label">Başlangıç Tarihi</label>
                                <input type="date" class="form-control" id="baslangic_tarihi" name="baslangic_tarihi" 
                                       value="<?= htmlspecialchars($baslangic_tarihi) ?>">
                            </div>
                            <div class="col-md-4">
                                <label for="bitis_tarihi" class="form-label">Bitiş Tarihi</label>
                                <input type="date" class="form-control" id="bitis_tarihi" name="bitis_tarihi" 
                                       value="<?= htmlspecialchars($bitis_tarihi) ?>">
                            </div>
                            <div class="col-md-4 d-flex align-items-end">
                                <button type="submit" class="btn btn-primary">
                                    <i class="bi bi-filter"></i> Filtrele
                                </button>
                                <a href="raporlar.php" class="btn btn-outline-secondary ms-2">
                                    <i class="bi bi-x-circle"></i> Filtreyi Temizle
                                </a>
                            </div>
                        </form>
                    </div>
                </div>
                
                <!-- Gelir-Gider Özeti -->
                <div class="card shadow-sm mb-4">
                    <div class="card-header">
                        <h5 class="card-title mb-0"><i class="bi bi-cash-stack"></i> Gelir-Gider Özeti (<?= date('d.m.Y', strtotime($baslangic_tarihi)) ?> - <?= date('d.m.Y', strtotime($bitis_tarihi)) ?>)</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-4">
                                <div class="card bg-success text-white">
                                    <div class="card-body">
                                        <h5 class="card-title">Toplam Gelir</h5>
                                        <h3><?= number_format($gelir_gider['toplam_gelir'] ?? 0, 2, ',', '.') ?> ₺</h3>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="card bg-danger text-white">
                                    <div class="card-body">
                                        <h5 class="card-title">Toplam Gider</h5>
                                        <h3><?= number_format($gelir_gider['toplam_gider'] ?? 0, 2, ',', '.') ?> ₺</h3>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="card <?= (($gelir_gider['toplam_gelir'] ?? 0) - ($gelir_gider['toplam_gider'] ?? 0)) >= 0 ? 'bg-primary' : 'bg-warning text-dark' ?> text-white">
                                    <div class="card-body">
                                        <h5 class="card-title">Net Durum</h5>
                                        <h3><?= number_format(($gelir_gider['toplam_gelir'] ?? 0) - ($gelir_gider['toplam_gider'] ?? 0), 2, ',', '.') ?> ₺</h3>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        
        <div class="row">
            <div class="col-md-6 mb-4">
                <div class="card shadow">
                    <div class="card-header">
                        <h5 class="card-title mb-0"><i class="bi bi-pie-chart"></i> Kategori Bazında Borçlar</h5>
                    </div>
                    <div class="card-body">
                        <canvas id="kategoriChart" height="300"></canvas>
                    </div>
                </div>
            </div>
            
            <div class="col-md-6 mb-4">
                <div class="card shadow">
                    <div class="card-header">
                        <h5 class="card-title mb-0"><i class="bi bi-bar-chart"></i> Cari Grup Bazında Bakiyeler</h5>
                    </div>
                    <div class="card-body">
                        <canvas id="grupChart" height="300"></canvas>
                    </div>
                </div>
            </div>
        </div>
        
        <!-- Hesap Bakiyeleri -->
        <div class="row">
            <div class="col-md-12 mb-4">
                <div class="card shadow">
                    <div class="card-header">
                        <h5 class="card-title mb-0"><i class="bi bi-bank"></i> Hesap Bakiyeleri</h5>
                    </div>
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-hover">
                                <thead class="table-light">
                                    <tr>
                                        <th>Hesap Adı</th>
                                        <th>Hesap Türü</th>
                                        <th>Bakiye</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach($hesap_bakiyeleri as $hesap): ?>
                                    <tr>
                                        <td><?= temizle($hesap['hesap_adi']) ?></td>
                                        <td>
                                            <?php 
                                            $hesap_turu_text = "Diğer";
                                            switch($hesap['hesap_turu']) {
                                                case 'nakit': $hesap_turu_text = "Nakit"; break;
                                                case 'banka': $hesap_turu_text = "Banka"; break;
                                                case 'kredi_karti': $hesap_turu_text = "Kredi Kartı"; break;
                                            }
                                            echo $hesap_turu_text;
                                            ?>
                                        </td>
                                        <td class="<?= $hesap['bakiye'] >= 0 ? 'text-success' : 'text-danger' ?>">
                                            <?= number_format($hesap['bakiye'], 2, ',', '.') ?> ₺
                                        </td>
                                    </tr>
                                    <?php endforeach; ?>
                                </tbody>
                                <tfoot class="table-light">
                                    <tr>
                                        <th colspan="2">Toplam Bakiye</th>
                                        <th class="<?= array_sum(array_column($hesap_bakiyeleri, 'bakiye')) >= 0 ? 'text-success' : 'text-danger' ?>">
                                            <?= number_format(array_sum(array_column($hesap_bakiyeleri, 'bakiye')), 2, ',', '.') ?> ₺
                                        </th>
                                    </tr>
                                </tfoot>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        
        <!-- Vadesi Geçmiş Borçlar/Alacaklar -->
        <div class="row">
            <div class="col-md-12 mb-4">
                <div class="card shadow">
                    <div class="card-header">
                        <h5 class="card-title mb-0"><i class="bi bi-exclamation-triangle"></i> Vadesi Geçmiş Borçlar/Alacaklar</h5>
                    </div>
                    <div class="card-body">
                        <?php if (empty($vadesi_gecmis)): ?>
                            <div class="alert alert-success">
                                <i class="bi bi-check-circle"></i> Vadesi geçmiş borç veya alacak bulunmamaktadır.
                            </div>
                        <?php else: ?>
                            <div class="table-responsive">
                                <table class="table table-hover">
                                    <thead class="table-light">
                                        <tr>
                                            <th>Tür</th>
                                            <th>Cari</th>
                                            <th>Tutar</th>
                                            <th>Vade Tarihi</th>
                                            <th>Gecikme</th>
                                            <th>Açıklama</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach($vadesi_gecmis as $vade): 
                                            $gecikme_gun = floor((strtotime($bugun) - strtotime($vade['vade_tarihi'])) / (60 * 60 * 24));
                                        ?>
                                        <tr>
                                            <td>
                                                <?php if ($vade['tur'] == 'satis'): ?>
                                                    <span class="badge bg-success">Alacak</span>
                                                <?php else: ?>
                                                    <span class="badge bg-danger">Borç</span>
                                                <?php endif; ?>
                                            </td>
                                            <td><?= temizle($vade['cari_adi']) ?></td>
                                            <td><?= number_format($vade['tutar'], 2, ',', '.') ?> ₺</td>
                                            <td><?= date('d.m.Y', strtotime($vade['vade_tarihi'])) ?></td>
                                            <td>
                                                <span class="badge bg-warning text-dark"><?= $gecikme_gun ?> gün</span>
                                            </td>
                                            <td><?= temizle($vade['aciklama']) ?></td>
                                        </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
        
        <div class="row">
            <div class="col-md-6 mb-4">
                <div class="card shadow">
                    <div class="card-header">
                        <h5 class="card-title mb-0"><i class="bi bi-table"></i> Kategori Borç Detayları</h5>
                    </div>
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-hover">
                                <thead class="table-light">
                                    <tr>
                                        <th>Kategori</th>
                                        <th>Toplam Borç</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach($kategori_borclari as $borc): ?>
                                    <tr>
                                        <td><?= temizle($borc['kategori_adi']) ?></td>
                                        <td class="text-danger"><?= number_format($borc['toplam_borc'], 2) ?> ₺</td>
                                    </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
            
            <div class="col-md-6 mb-4">
                <div class="card shadow">
                    <div class="card-header">
                        <h5 class="card-title mb-0"><i class="bi bi-table"></i> Cari Grup Bakiye Detayları</h5>
                    </div>
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-hover">
                                <thead class="table-light">
                                    <tr>
                                        <th>Grup</th>
                                        <th>Toplam Bakiye</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach($grup_bakiyeleri as $bakiye): ?>
                                    <tr>
                                        <td><?= temizle($bakiye['grup_adi']) ?></td>
                                        <td class="<?= $bakiye['toplam_bakiye'] >= 0 ? 'text-success' : 'text-danger' ?>">
                                            <?= number_format($bakiye['toplam_bakiye'], 2) ?> ₺
                                        </td>
                                    </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
	<?php include("footer.php"); ?>
    <script>
        // Kategori grafiği
        const kategoriCtx = document.getElementById('kategoriChart').getContext('2d');
        const kategoriChart = new Chart(kategoriCtx, {
            type: 'pie',
            data: {
                labels: [<?= implode(',', array_map(function($item) { return "'" . addslashes($item['kategori_adi']) . "'"; }, $kategori_borclari)) ?>],
                datasets: [{
                    label: 'Toplam Borç (₺)',
                    data: [<?= implode(',', array_column($kategori_borclari, 'toplam_borc')) ?>],
                    backgroundColor: [
                        'rgba(255, 99, 132, 0.7)',
                        'rgba(54, 162, 235, 0.7)',
                        'rgba(255, 206, 86, 0.7)',
                        'rgba(75, 192, 192, 0.7)',
                        'rgba(153, 102, 255, 0.7)',
                        'rgba(255, 159, 64, 0.7)'
                    ],
                    borderColor: [
                        'rgba(255, 99, 132, 1)',
                        'rgba(54, 162, 235, 1)',
                        'rgba(255, 206, 86, 1)',
                        'rgba(75, 192, 192, 1)',
                        'rgba(153, 102, 255, 1)',
                        'rgba(255, 159, 64, 1)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                plugins: {
                    legend: {
                        position: 'right',
                    }
                }
            }
        });
        
        // Grup grafiği
        const grupCtx = document.getElementById('grupChart').getContext('2d');
        const grupChart = new Chart(grupCtx, {
            type: 'bar',
            data: {
                labels: [<?= implode(',', array_map(function($item) { return "'" . addslashes($item['grup_adi']) . "'"; }, $grup_bakiyeleri)) ?>],
                datasets: [{
                    label: 'Toplam Bakiye (₺)',
                    data: [<?= implode(',', array_column($grup_bakiyeleri, 'toplam_bakiye')) ?>],
                    backgroundColor: [
                        'rgba(54, 162, 235, 0.7)',
                        'rgba(255, 206, 86, 0.7)',
                        'rgba(75, 192, 192, 0.7)'
                    ],
                    borderColor: [
                        'rgba(54, 162, 235, 1)',
                        'rgba(255, 206, 86, 1)',
                        'rgba(75, 192, 192, 1)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                scales: {
                    y: {
                        beginAtZero: true
                    }
                }
            }
        });
    </script>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>