<?php
require_once 'config.php';
yetkili_mi();

$sayfa_baslik = "Satış İşlemi";

// Form gönderildiğinde
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (!csrf_token_dogrula($_POST['csrf_token'] ?? '')) {
        $_SESSION['hata'] = "Geçersiz form gönderimi!";
        header("Location: satis.php");
        exit();
    }

    // Form verilerini al
    $cari_id = filter_input(INPUT_POST, 'cari_id', FILTER_VALIDATE_INT);
    $kategori_id = filter_input(INPUT_POST, 'kategori_id', FILTER_VALIDATE_INT);
    $tutar_str = str_replace(',', '.', $_POST['tutar'] ?? '0'); // Virgülü noktaya çevir
    $tutar = filter_var($tutar_str, FILTER_VALIDATE_FLOAT);
    $aciklama = temizle($_POST['aciklama'] ?? '');
    $tarih = filter_input(INPUT_POST, 'tarih', FILTER_SANITIZE_SPECIAL_CHARS);
    $vade_tarihi = filter_input(INPUT_POST, 'vade_tarihi', FILTER_SANITIZE_SPECIAL_CHARS);
    $pesin_odendi = isset($_POST['pesin_odendi']) && $_POST['pesin_odendi'] == '1';
    $hesap_id = filter_input(INPUT_POST, 'hesap_id', FILTER_VALIDATE_INT);

    // Veri doğrulama
    $hatalar = [];
    if (empty($cari_id)) $hatalar[] = "Cari seçimi zorunludur.";
    if (empty($kategori_id)) $hatalar[] = "Kategori seçimi zorunludur.";
    if ($tutar === false || $tutar <= 0) $hatalar[] = "Geçerli bir tutar giriniz (0'dan büyük).";
    if (empty($tarih) || !preg_match("/^\d{4}-\d{2}-\d{2}$/", $tarih)) $hatalar[] = "Geçerli bir işlem tarihi giriniz (YYYY-AA-GG).";
    if (!$pesin_odendi && !empty($vade_tarihi) && !preg_match("/^\d{4}-\d{2}-\d{2}$/", $vade_tarihi)) {
        $hatalar[] = "Geçerli bir vade tarihi giriniz (YYYY-AA-GG) veya boş bırakınız.";
    }
     if ($pesin_odendi && empty($hesap_id)) $hatalar[] = "Peşin ödeme için hesap seçimi zorunludur.";

     // Vade tarihi boşsa null yap
     $vade_tarihi = empty($vade_tarihi) ? null : $vade_tarihi;

    // Hata yoksa işlem yap
    if (empty($hatalar)) {
        try {
            $db->beginTransaction();

            // 1. Satış işlemini (borç olarak) kaydet
            $stmt_borc = $db->prepare("INSERT INTO borclar
                (cari_id, tur, kategori_id, tutar, aciklama, tarih, vade_tarihi, olusturulma_tarihi)
                VALUES (?, 'satis', ?, ?, ?, ?, ?, NOW())");
            $stmt_borc->execute([$cari_id, $kategori_id, $tutar, $aciklama, $tarih, $vade_tarihi]);
            $borc_id = $db->lastInsertId();

            if ($pesin_odendi) {
                // 2a. Peşin ödendiyse: Hesap hareketini ve bakiye güncellemelerini yap
                // Hesap bakiyesini artır
                if (!hesapBakiyeGuncelle($db, $hesap_id, $tutar)) {
                     throw new Exception("Hesap bakiyesi güncellenemedi.");
                }

                // Hesap hareketi ekle ('giris' olarak)
                $hareket_aciklama = "Satış (#{$borc_id}): " . $aciklama;
                if (!hesapHareketiEkle($db, $hesap_id, 'giris', $tutar, $hareket_aciklama, $cari_id, $borc_id)) {
                    throw new Exception("Hesap hareketi eklenemedi.");
                }

                // Cari bakiye güncellemesi GEREKMEZ (toplam_borc artmaz çünkü peşin ödendi)
                 $_SESSION['mesaj'] = "Satış işlemi ve peşin tahsilat başarıyla kaydedildi.";

            } else {
                // 2b. Vadeli ise: Cari borcunu artır
                if (!cariBakiyeGuncelle($db, $cari_id, $tutar, 0.0)) { // Borç artıyor
                     throw new Exception("Cari bakiyesi güncellenemedi.");
                }
                 $_SESSION['mesaj'] = "Vadeli satış işlemi başarıyla kaydedildi.";
            }

            $db->commit();
            header("Location: satis.php");
            exit();

        } catch (Exception $e) {
            $db->rollBack();
            error_log("Satış ekleme hatası: " . $e->getMessage());
            $_SESSION['hata'] = "Satış eklenirken bir hata oluştu: " . $e->getMessage();
            // Hatalı form verilerini session'a kaydet (opsiyonel)
            $_SESSION['form_verileri_satis'] = $_POST;
            header("Location: satis.php");
            exit();
        }
    } else {
         // Hata varsa, hataları ve girilen verileri session'a kaydet ve formu tekrar göster
         $_SESSION['form_hatalari_satis'] = $hatalar;
         $_SESSION['form_verileri_satis'] = $_POST;
         header("Location: satis.php");
         exit();
    }
}

// Formu göstermek için carileri, kategorileri ve hesapları getir
try {
    $cariler = $db->query("SELECT id, ad_soyad FROM cariler ORDER BY ad_soyad")->fetchAll(PDO::FETCH_ASSOC);
    $kategoriler = $db->query("SELECT id, kategori_adi FROM kategoriler ORDER BY kategori_adi")->fetchAll(PDO::FETCH_ASSOC);
    $hesaplar = $db->query("SELECT id, hesap_adi, bakiye FROM hesaplar WHERE hesap_turu != 'kredi_karti' ORDER BY hesap_adi")->fetchAll(PDO::FETCH_ASSOC); // Kredi kartı hariç
} catch (PDOException $e) {
    error_log("Satış sayfası veri çekme hatası: " . $e->getMessage());
    $_SESSION['hata'] = "Gerekli veriler yüklenirken bir hata oluştu.";
    // die() yerine hata mesajı gösterip formu boş getirebiliriz veya session ile hata gösteririz.
    $cariler = []; $kategoriler = []; $hesaplar = []; // Hata durumunda boş diziler
}

$csrf_token = csrf_token_olustur();

// Session'dan hataları ve eski form verilerini al (varsa)
$form_hatalari = $_SESSION['form_hatalari_satis'] ?? [];
$form_verileri = $_SESSION['form_verileri_satis'] ?? [];
unset($_SESSION['form_hatalari_satis'], $_SESSION['form_verileri_satis']);
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= temizle($sayfa_baslik) ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
    <style>
        .hidden { display: none; }
    </style>
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container mt-4">
        <h2><i class="bi bi-cart-plus"></i> <?= temizle($sayfa_baslik) ?></h2>
        <hr>

        <?php if (!empty($form_hatalari)): ?>
            <div class="alert alert-danger alert-dismissible fade show" role="alert">
                <strong><i class="bi bi-exclamation-triangle-fill me-2"></i> Lütfen hataları düzeltin:</strong>
                <ul>
                    <?php foreach ($form_hatalari as $hata): ?>
                        <li><?= htmlspecialchars($hata) ?></li>
                    <?php endforeach; ?>
                </ul>
                 <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <form method="post" id="satisForm">
            <input type="hidden" name="csrf_token" value="<?= $csrf_token ?>">
            <div class="card shadow-sm">
                <div class="card-body">
                    <div class="row g-3">
                        <div class="col-md-4">
                            <label for="cari_arama" class="form-label">Cari Seçin <span class="text-danger">*</span></label>
                            <div class="input-group">
                                <input type="text" class="form-control" id="cari_arama" placeholder="Cari adı yazın..." autocomplete="off">
                                <button type="button" class="btn btn-outline-primary" data-bs-toggle="modal" data-bs-target="#yeniCariModal">
                                    <i class="bi bi-plus-circle"></i> Yeni Cari
                                </button>
                            </div>
                            <div id="cariSonuclar" class="list-group position-absolute w-75 shadow-sm" style="z-index: 1000; display: none; max-height: 200px; overflow-y: auto;"></div>
                            <input type="hidden" id="cari_id" name="cari_id" value="<?= htmlspecialchars($form_verileri['cari_id'] ?? '') ?>" required>
                            <div id="seciliCari" class="form-text mt-2">
                                <?php if (isset($form_verileri['cari_id']) && !empty($form_verileri['cari_id'])): 
                                    $secili_cari_id = $form_verileri['cari_id'];
                                    $secili_cari = array_filter($cariler, function($c) use ($secili_cari_id) { 
                                        return $c['id'] == $secili_cari_id; 
                                    });
                                    $secili_cari = reset($secili_cari);
                                    if ($secili_cari): ?>
                                        <span class="badge bg-primary">
                                            <?= temizle($secili_cari['ad_soyad']) ?>
                                            <i class="bi bi-check-circle-fill ms-1"></i>
                                        </span>
                                    <?php endif; ?>
                                <?php else: ?>
                                    <span class="text-muted">Henüz cari seçilmedi</span>
                                <?php endif; ?>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <label for="kategori_id" class="form-label">Kategori <span class="text-danger">*</span></label>
                            <select class="form-select" id="kategori_id" name="kategori_id" required>
                                <option value="">-- Kategori Seçin --</option>
                                <?php foreach ($kategoriler as $kategori): ?>
                                     <option value="<?= $kategori['id'] ?>" <?= (isset($form_verileri['kategori_id']) && $form_verileri['kategori_id'] == $kategori['id']) ? 'selected' : '' ?>>
                                        <?= temizle($kategori['kategori_adi']) ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="col-md-4">
                            <label for="tutar" class="form-label">Tutar (₺) <span class="text-danger">*</span></label>
                            <input type="text" inputmode="decimal" class="form-control" id="tutar" name="tutar" required
                                   value="<?= htmlspecialchars($form_verileri['tutar'] ?? '', ENT_QUOTES) ?>">
                        </div>

                         <div class="col-md-6">
                            <label for="tarih" class="form-label">İşlem Tarihi <span class="text-danger">*</span></label>
                            <input type="date" class="form-control" id="tarih" name="tarih" required
                                   value="<?= htmlspecialchars($form_verileri['tarih'] ?? date('Y-m-d'), ENT_QUOTES) ?>">
                        </div>

                        <div class="col-md-6">
                            <label class="form-label">Ödeme Durumu</label>
                             <div class="form-check">
                                <input class="form-check-input" type="checkbox" value="1" id="pesin_odendi" name="pesin_odendi"
                                       <?= (isset($form_verileri['pesin_odendi']) && $form_verileri['pesin_odendi'] == '1') ? 'checked' : '' ?>>
                                <label class="form-check-label" for="pesin_odendi">
                                    Ödeme peşin alındı mı?
                                </label>
                            </div>
                        </div>

                        <div id="vadeli_alanlar" class="col-md-6">
                            <label for="vade_tarihi" class="form-label">Vade Tarihi</label>
                            <input type="date" class="form-control" id="vade_tarihi" name="vade_tarihi"
                                   value="<?= htmlspecialchars($form_verileri['vade_tarihi'] ?? '', ENT_QUOTES) ?>">
                        </div>

                       <div id="pesin_alanlar" class="col-md-6 hidden">
                             <label for="hesap_id" class="form-label">Ödemenin Alındığı Hesap <span class="text-danger">*</span></label>
                            <select class="form-select" id="hesap_id" name="hesap_id">
                                <option value="">-- Hesap Seçin --</option>
                                <?php foreach ($hesaplar as $hesap): ?>
                                    <option value="<?= $hesap['id'] ?>" <?= (isset($form_verileri['hesap_id']) && $form_verileri['hesap_id'] == $hesap['id']) ? 'selected' : '' ?>>
                                        <?= temizle($hesap['hesap_adi']) ?> (<?= number_format($hesap['bakiye'], 2) ?> ₺)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="col-12">
                            <label for="aciklama" class="form-label">Açıklama</label>
                            <textarea class="form-control" id="aciklama" name="aciklama" rows="2"><?= htmlspecialchars($form_verileri['aciklama'] ?? '', ENT_QUOTES) ?></textarea>
                        </div>

                        <div class="col-12">
                            <button type="submit" class="btn btn-primary">
                                <i class="bi bi-save me-2"></i> Satışı Kaydet
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </form>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    
    <!-- Yeni Cari Ekleme Modal -->
    <div class="modal fade" id="yeniCariModal" tabindex="-1" aria-labelledby="yeniCariModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="yeniCariModalLabel">Yeni Cari Ekle</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <form id="yeniCariForm">
                        <div class="mb-3">
                            <label for="yeni_ad_soyad" class="form-label">Ad Soyad / Firma Adı <span class="text-danger">*</span></label>
                            <input type="text" class="form-control" id="yeni_ad_soyad" required>
                        </div>
                        <div class="mb-3">
                            <label for="yeni_telefon" class="form-label">Telefon</label>
                            <input type="tel" class="form-control" id="yeni_telefon">
                        </div>
                        <div class="mb-3">
                            <label for="yeni_eposta" class="form-label">E-posta</label>
                            <input type="email" class="form-control" id="yeni_eposta">
                        </div>
                        <div class="mb-3">
                            <label for="yeni_adres" class="form-label">Adres</label>
                            <textarea class="form-control" id="yeni_adres" rows="2"></textarea>
                        </div>
                    </form>
                    <div id="cariEkleMessage" class="alert d-none"></div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">İptal</button>
                    <button type="button" class="btn btn-primary" id="cariEkleBtn">
                        <i class="bi bi-plus-circle me-1"></i> Cari Ekle
                    </button>
                </div>
            </div>
        </div>
    </div>
    <?php include("footer.php"); ?>
     <script>
        document.addEventListener('DOMContentLoaded', function() {
            const pesinCheckbox = document.getElementById('pesin_odendi');
            const vadeliAlanlar = document.getElementById('vadeli_alanlar');
            const pesinAlanlar = document.getElementById('pesin_alanlar');
            const vadeInput = document.getElementById('vade_tarihi');
            const hesapInput = document.getElementById('hesap_id');

            function toggleAlanlar() {
                if (pesinCheckbox.checked) {
                    vadeliAlanlar.classList.add('hidden');
                    pesinAlanlar.classList.remove('hidden');
                    vadeInput.required = false;
                    hesapInput.required = true;
                } else {
                    vadeliAlanlar.classList.remove('hidden');
                    pesinAlanlar.classList.add('hidden');
                    vadeInput.required = false;
                    hesapInput.required = false;
                }
            }

            pesinCheckbox.addEventListener('change', toggleAlanlar);
            toggleAlanlar();
            
            // Cari arama ve otomatik tamamlama
            const cariArama = document.getElementById('cari_arama');
            const cariSonuclar = document.getElementById('cariSonuclar');
            const cariIdInput = document.getElementById('cari_id');
            const seciliCariDiv = document.getElementById('seciliCari');
            
            // Tüm carileri JavaScript dizisine aktar
            const cariler = [
                <?php foreach ($cariler as $cari): ?>
                {id: <?= $cari['id'] ?>, ad_soyad: "<?= addslashes(temizle($cari['ad_soyad'])) ?>"},
                <?php endforeach; ?>
            ];
            
            // Form verilerinden seçili cari varsa, arama kutusuna adını yaz
            <?php if (isset($form_verileri['cari_id']) && !empty($form_verileri['cari_id'])): ?>
                const seciliCariId = <?= $form_verileri['cari_id'] ?>;
                const seciliCari = cariler.find(c => c.id === seciliCariId);
                if (seciliCari) {
                    cariArama.value = seciliCari.ad_soyad;
                }
            <?php endif; ?>
            
            cariArama.addEventListener('input', function() {
                const aramaTermi = this.value.toLowerCase().trim();
                
                if (aramaTermi.length < 2) {
                    cariSonuclar.style.display = 'none';
                    return;
                }
                
                // Arama terimine göre filtreleme
                const filtrelenmisCariler = cariler.filter(cari => 
                    cari.ad_soyad.toLowerCase().includes(aramaTermi)
                );
                
                // Sonuçları göster
                cariSonuclar.innerHTML = '';
                
                if (filtrelenmisCariler.length === 0) {
                    const sonucYok = document.createElement('a');
                    sonucYok.className = 'list-group-item list-group-item-action disabled';
                    sonucYok.textContent = `"${aramaTermi}" için sonuç bulunamadı`;
                    cariSonuclar.appendChild(sonucYok);
                } else {
                    filtrelenmisCariler.forEach(cari => {
                        const sonucItem = document.createElement('a');
                        sonucItem.className = 'list-group-item list-group-item-action';
                        sonucItem.textContent = cari.ad_soyad;
                        sonucItem.href = '#';
                        sonucItem.addEventListener('click', function(e) {
                            e.preventDefault();
                            cariSec(cari.id, cari.ad_soyad);
                        });
                        cariSonuclar.appendChild(sonucItem);
                    });
                }
                
                cariSonuclar.style.display = 'block';
            });
            
            // Cari seçme fonksiyonu
            function cariSec(id, adSoyad) {
                cariIdInput.value = id;
                cariArama.value = adSoyad;
                seciliCariDiv.innerHTML = `<span class="badge bg-primary">${adSoyad} <i class="bi bi-check-circle-fill ms-1"></i></span>`;
                cariSonuclar.style.display = 'none';
            }
            
            // Dışarı tıklandığında sonuçları gizle
            document.addEventListener('click', function(e) {
                if (e.target !== cariArama && e.target !== cariSonuclar) {
                    cariSonuclar.style.display = 'none';
                }
            });
            
            // Cari arama kutusuna tekrar tıklandığında sonuçları göster
            cariArama.addEventListener('click', function() {
                if (this.value.length >= 2) {
                    cariSonuclar.style.display = 'block';
                }
            });
            
            // Cari arama kutusundan çıkıldığında, eğer geçerli bir cari seçilmediyse değeri temizle
            cariArama.addEventListener('blur', function() {
                setTimeout(() => {
                    if (!cariIdInput.value) {
                        this.value = '';
                        seciliCariDiv.innerHTML = '<span class="text-muted">Henüz cari seçilmedi</span>';
                    }
                }, 200); // Tıklama işleminin tamamlanması için kısa bir gecikme
            });
            
            // Yeni cari ekleme işlemi
            const cariEkleBtn = document.getElementById('cariEkleBtn');
            const cariEkleMessage = document.getElementById('cariEkleMessage');
            
            cariEkleBtn.addEventListener('click', function() {
                // Form verilerini al
                const adSoyad = document.getElementById('yeni_ad_soyad').value.trim();
                const telefon = document.getElementById('yeni_telefon').value.trim();
                const eposta = document.getElementById('yeni_eposta').value.trim();
                const adres = document.getElementById('yeni_adres').value.trim();
                
                // Basit doğrulama
                if (!adSoyad) {
                    showMessage('Lütfen ad soyad / firma adı giriniz.', 'danger');
                    return;
                }
                
                // Yükleniyor durumu
                cariEkleBtn.disabled = true;
                cariEkleBtn.innerHTML = '<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Ekleniyor...';
                
                // AJAX isteği
                fetch('cari_ekle_ajax.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: `ad_soyad=${encodeURIComponent(adSoyad)}&telefon=${encodeURIComponent(telefon)}&eposta=${encodeURIComponent(eposta)}&adres=${encodeURIComponent(adres)}`
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        // Başarılı mesajı göster
                        showMessage(data.message, 'success');
                        
                        // Yeni cariyi listeye ekle ve seç
                        const yeniCari = {id: parseInt(data.cari_id), ad_soyad: adSoyad};
                        cariler.push(yeniCari);
                        cariSec(yeniCari.id, yeniCari.ad_soyad);
                        
                        // Formu sıfırla
                        document.getElementById('yeniCariForm').reset();
                        
                        // 2 saniye sonra modalı kapat
                        setTimeout(() => {
                            const modal = bootstrap.Modal.getInstance(document.getElementById('yeniCariModal'));
                            modal.hide();
                            cariEkleMessage.classList.add('d-none');
                        }, 2000);
                    } else {
                        showMessage(data.message || 'Cari eklenirken bir hata oluştu.', 'danger');
                    }
                })
                .catch(error => {
                    console.error('Hata:', error);
                    showMessage('Bir hata oluştu. Lütfen tekrar deneyin.', 'danger');
                })
                .finally(() => {
                    // Buton durumunu sıfırla
                    cariEkleBtn.disabled = false;
                    cariEkleBtn.innerHTML = '<i class="bi bi-plus-circle me-1"></i> Cari Ekle';
                });
            });
            
            function showMessage(message, type) {
                cariEkleMessage.textContent = message;
                cariEkleMessage.className = `alert alert-${type}`;
                cariEkleMessage.classList.remove('d-none');
            }
        });
    </script>
</body>
</html>
