<?php
require_once 'config.php';
yetkili_mi();

$sayfa_baslik = "Para Transferi";

// FORM GÖNDERİLDİĞİNDE
if($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['transfer_ekle'])) {
    if(!csrf_token_dogrula($_POST['csrf_token'])) die("Geçersiz token!");
    
    $kaynak_hesap = (int)$_POST['kaynak_hesap'];
    $hedef_hesap = (int)$_POST['hedef_hesap'];
    $tutar = (float)$_POST['tutar'];
    $tarih = $_POST['tarih'];
    $aciklama = temizle($_POST['aciklama']);
    
    try {
        $db->beginTransaction();
        
        // 1. Validasyonlar
        if($kaynak_hesap == $hedef_hesap) 
            throw new Exception("Aynı hesaplar arası transfer yapılamaz!");
            
        if($tutar <= 0) 
            throw new Exception("Tutar 0'dan büyük olmalı!");
            
        // 2. Kaynak hesap bakiyesini kontrol et
        $bakiye = $db->query("SELECT bakiye FROM hesaplar WHERE id = $kaynak_hesap")->fetchColumn();
        if($bakiye < $tutar) 
            throw new Exception("Yetersiz bakiye! Mevcut bakiye: ".number_format($bakiye,2)." ₺");
        
        // 3. Hareketleri kaydet
        // Kaynaktan çıkış
        $db->prepare("INSERT INTO hesap_hareketleri 
            (hesap_id, tur, tutar, aciklama, tarih, baglanti_id) 
            VALUES (?, 'transfer', ?, ?, ?, ?)")
           ->execute([$kaynak_hesap, -$tutar, $aciklama, $tarih, $hedef_hesap]);
        
        // Hedefe giriş
        $db->prepare("INSERT INTO hesap_hareketleri 
            (hesap_id, tur, tutar, aciklama, tarih, baglanti_id) 
            VALUES (?, 'transfer', ?, ?, ?, ?)")
           ->execute([$hedef_hesap, $tutar, $aciklama, $tarih, $kaynak_hesap]);
        
        // 4. Bakiyeleri güncelle
        $db->prepare("UPDATE hesaplar SET bakiye = bakiye - ? WHERE id = ?")
           ->execute([$tutar, $kaynak_hesap]);
           
        $db->prepare("UPDATE hesaplar SET bakiye = bakiye + ? WHERE id = ?")
           ->execute([$tutar, $hedef_hesap]);
        
        $db->commit();
        $_SESSION['mesaj'] = "Transfer başarıyla tamamlandı!";
    } catch(Exception $e) {
        $db->rollBack();
        $_SESSION['hata'] = $e->getMessage();
    }
    header("Location: transfer_ekle.php"); exit();
}

// HESAPLARI GETİR
try {
    $hesaplar = $db->query("SELECT * FROM hesaplar ORDER BY hesap_adi")->fetchAll();
} catch(PDOException $e) {
    die("Hata: ".$e->getMessage());
}

$csrf_token = csrf_token_olustur();
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Esnaf Yönetim - <?= $sayfa_baslik ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
</head>
<body>
    <?php include 'navbar.php'; ?>

    <div class="container-xl mt-4">
        <div class="row">
            <div class="col-md-6 mx-auto">
                <div class="card shadow">
                    <div class="card-header bg-primary text-white">
                        <h5 class="mb-0"><i class="bi bi-arrow-left-right"></i> Para Transferi</h5>
                    </div>
                    <div class="card-body">
                        <form method="post">
                            <input type="hidden" name="csrf_token" value="<?= $csrf_token ?>">
                            
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <label>Kaynak Hesap</label>
                                    <select name="kaynak_hesap" class="form-select" required>
                                        <?php foreach($hesaplar as $hesap): ?>
                                        <option value="<?= $hesap['id'] ?>">
                                            <?= temizle($hesap['hesap_adi']) ?> 
                                            (<?= number_format($hesap['bakiye'],2) ?> ₺)
                                        </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                <div class="col-md-6">
                                    <label>Hedef Hesap</label>
                                    <select name="hedef_hesap" class="form-select" required>
                                        <?php foreach($hesaplar as $hesap): ?>
                                        <option value="<?= $hesap['id'] ?>">
                                            <?= temizle($hesap['hesap_adi']) ?>
                                        </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                            
                            <div class="mb-3">
                                <label>Tutar (₺)</label>
                                <input type="number" step="0.01" min="0.01" 
                                       name="tutar" class="form-control" required>
                            </div>
                            
                            <div class="mb-3">
                                <label>Tarih</label>
                                <input type="date" name="tarih" 
                                       value="<?= date('Y-m-d') ?>" class="form-control" required>
                            </div>
                            
                            <div class="mb-3">
                                <label>Açıklama</label>
                                <textarea name="aciklama" class="form-control" rows="2"></textarea>
                            </div>
                            
                            <button type="submit" name="transfer_ekle" 
                                    class="btn btn-primary w-100">
                                <i class="bi bi-send-check"></i> Transfer Yap
                            </button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
	<?php include("footer.php"); ?>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>